/************************************************************************
* Essential Device Characteristics Database Script
*
* This SQL script creates a device database for use with the
* Serial Bootloader PC application. To add support for a new device,
* the Device Database utility can be used to generate new SQL script
* to be added here from a *.PIC XML file, or you can manually enter
* the device characteristics by editing this script directly.
*
* After modifying this script to include new devices, you can
* re-generate the binary database file using the "sqlite3.exe"
* command line utility:
*
* sqlite3.exe -init devices.sql -batch devices.db .quit
*
* The resulting "devices.db" file needs to be copied to the same
* folder that you start the PC application's EXE.
*
* SQLite is a public domain SQL database engine available from:
* http://www.sqlite.org/
************************************************************************/
drop table DEVICES;
drop table CONFIGWORDS;
drop table CONFIGSETTINGS;
drop table CONFIGFIELDS;

create table DEVICES (
     DEVICEROWID integer primary key autoincrement,
     DEVICEID integer not null,
     FAMILYID integer not null,
     PARTNAME text not null, 
     BYTESPERWORDFLASH integer,
     WRITEFLASHBLOCKSIZE integer not null,
     ERASEFLASHBLOCKSIZE integer not null,
     STARTFLASH integer,
     ENDFLASH integer,
     STARTEE integer, 
     ENDEE integer, 
     STARTUSER integer,
     ENDUSER integer, 
     STARTCONFIG integer,
     ENDCONFIG integer,
     STARTDEVICEID integer,
     ENDDEVICEID integer,
     DEVICEIDMASK integer,
     STARTGPR integer,
     ENDGPR integer
);

create table CONFIGWORDS (
     ROWID integer primary key autoincrement,
     DEVICEROWID integer not null,
     CONFIGNAME text not null,
     ADDRESS integer not null,
     DEFAULTVALUE integer,
     IMPLEMENTEDBITS integer
);

create table CONFIGFIELDS (
     ROWID integer primary key autoincrement,
     CONFIGWORDID integer not null,
     DEVICEROWID integer not null,
     FIELDCNAME text not null,
     DESCRIPTION text not null
);

create table CONFIGSETTINGS (
     CONFIGFIELDID integer not null,
     DEVICEROWID integer not null,
     SETTINGCNAME text not null,
     DESCRIPTION text not null,
     BITMASK integer not null,
     BITVALUE integer not null
);

pragma read_uncommitted = 1;

begin transaction;

insert into DEVICES values (
     null,
     222,              -- Device ID
     2,                -- Family ID
     'PIC12LF1840',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


-- PIC12F609 does not support self-programming.
-- PIC12F615 does not support self-programming.
insert into DEVICES values (
     null,
     155,              -- Device ID
     2,                -- Family ID
     'PIC12F617',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator: CLKOUT function on RA4/AN3/T1G/OSC2/CLKOUT, RC on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRCIO oscillator: I/O function on RA4/AN3/T1G/OSC2/CLKOUT, RC on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/AN3/T1G/OSC2/CLKOUT, I/O function on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/AN3/T1G/OSC2/CLKOUT, I/O function on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/AN3/T1G/OSC2/CLKOUT, CLKIN on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA5/T1CKI/OSC1/CLKIN and RA4/AN3/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA5/T1CKI/OSC1/CLKIN and RA4/AN3/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA5/T1CKI/OSC1/CLKIN and RA4/AN3/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin is MCLR function and weak internal pull-up is enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin is alternate function, MCLR function is internally disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is external read and write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOSCFS',         -- C Name
     'Internal Oscillator Frequency Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8MHZ',           -- C Name
     '8 MHz',          -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4MHZ',           -- C Name
     '4 MHz',          -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Self Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3072,             -- Bit Mask
     3072              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by PMCON1 control',-- Description
     3072,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by PMCON1 control',-- Description
     3072,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, entire program memory is write protected.',-- Description
     3072,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     124,              -- Device ID
     2,                -- Family ID
     'PIC12F629',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     224               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     12799,            -- Default Value
     12799             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on GP4/OSC2/CLKOUT pin, RC on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RC oscillator: I/O function on GP4/OSC2/CLKOUT pin, RC on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on GP4/OSC2/CLKOUT pin, I/O function on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSC oscillator: I/O function on GP4/OSC2/CLKOUT pin, I/O function on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on GP4/OSC2/CLKOUT pin, CLKIN on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High speed crystal/resonator on GP4/OSC2/CLKOUT and GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on GP4/OSC2/CLKOUT and GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low power crystal on GP4/OSC2/CLKOUT and GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-Up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'GP3/MCLR pin function select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'GP3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'GP3/MCLR pin function is digital I/O, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Detect Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program Memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program Memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     125,              -- Device ID
     2,                -- Family ID
     'PIC12F635',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8191              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/T1G/OSC2/CLKOUT pin, RC on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/T1G/OSC2/CLKOUT pin, RC on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/T1G/OSC2/CLKOUT pin, I/O function on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/T1G/OSC2/CLKOUT pin, I/O function on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/T1G/OSC2/CLKOUT, CLKIN on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin is MCLR function and weak internal pull-up is enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is alternate function, MCLR function is internally disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is external read and write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory is not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory is external read protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled and SBOdEN bit disabled',-- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOD enabled while running and disabled in Sleep. SBODEN bit disabled.',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'SBODEN controls BOD function',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD and SBODEN disabled',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal-External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WURE',           -- C Name
     'Wake-Up Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Standard wake-up and continue enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wake-up and Reset enabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     126,              -- Device ID
     2,                -- Family ID
     'PIC12F675',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     224               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     12799,            -- Default Value
     12799             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on GP4/OSC2/CLKOUT pin, RC on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RC oscillator: I/O function on GP4/OSC2/CLKOUT pin, RC on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on GP4/OSC2/CLKOUT pin, I/O function on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSC oscillator: I/O function on GP4/OSC2/CLKOUT pin, I/O function on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on GP4/OSC2/CLKOUT pin, CLKIN on GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High speed crystal/resonator on GP4/OSC2/CLKOUT and GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on GP4/OSC2/CLKOUT and GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low power crystal on GP4/OSC2/CLKOUT and GP5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-Up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'GP3/MCLR pin function select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'GP3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'GP3/MCLR pin function is digital I/O, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Detect Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program Memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program Memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     35,               -- Device ID
     2,                -- Family ID
     'PIC12F683',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator: External RC on RA5/OSC1/CLKIN, CLKOUT function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRCIO oscillator: External RC on RA5/OSC1/CLKIN, I/O function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKINT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     168,              -- Device ID
     2,                -- Family ID
     'PIC12F752',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16249             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC0',          -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator mode.  CLKIN function on RA5/CLKIN',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INT',            -- C Name
     'Internal oscillator mode.  I/O function on RA5/CLKIN',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Watchdog Timer enabled',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watchdog Timer disabled',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power-up Timer disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power-up Timer enabled',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin is MCLR function with internal weak pullup',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin is alternate function',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Code protection enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EN',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SLEEP_DIS',      -- C Name
     'BOR disabled during Sleep and enabled during run',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'BOR disabled',   -- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Flash self-write protection off',-- Description
     3072,             -- Bit Mask
     3072              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'FOURTH',         -- C Name
     '000h to 0FFh self-write protected',-- Description
     3072,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFh self-write protected',-- Description
     3072,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFh self-write protected',-- Description
     3072,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CKLOUTEN',       -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function disabled.  CLKOUT pin acts as I/O',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function enabled.  CLKOUT pin is CLKOUT',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Debug mode disabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Debug mode enabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     312,              -- Device ID
     2,                -- Family ID
     'PIC12F1822',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     220,              -- Device ID
     2,                -- Family ID
     'PIC12F1840',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


-- PIC12HV609 does not support self-programming.
-- PIC12HV615 does not support self-programming.
insert into DEVICES values (
     null,
     169,              -- Device ID
     2,                -- Family ID
     'PIC12HV752',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16249             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC0',          -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator mode.  CLKIN function on RA5/CLKIN',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INT',            -- C Name
     'Internal oscillator mode.  I/O function on RA5/CLKIN',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Watchdog Timer enabled',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watchdog Timer disabled',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power-up Timer disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power-up Timer enabled',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin is MCLR function with internal weak pullup',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin is alternate function',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Code protection enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EN',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SLEEP_DIS',      -- C Name
     'BOR disabled during Sleep and enabled during run',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'BOR disabled',   -- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Flash self-write protection off',-- Description
     3072,             -- Bit Mask
     3072              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'FOURTH',         -- C Name
     '000h to 0FFh self-write protected',-- Description
     3072,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFh self-write protected',-- Description
     3072,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFh self-write protected',-- Description
     3072,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CKLOUTEN',       -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function disabled.  CLKOUT pin acts as I/O',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function enabled.  CLKOUT pin is CLKOUT',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Debug mode disabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Debug mode enabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     320,              -- Device ID
     2,                -- Family ID
     'PIC12LF1822',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into DEVICES values (
     null,
     301,              -- Device ID
     2,                -- Family ID
     'PIC16LF1947',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     5,                -- Device ID
     2,                -- Family ID
     'PIC16F72',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     95                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All Memory locations code protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     48,               -- Device ID
     2,                -- Family ID
     'PIC16F73',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     95                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All Memory locations code protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     49,               -- Device ID
     2,                -- Family ID
     'PIC16F74',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     95                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All Memory locations code protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     50,               -- Device ID
     2,                -- Family ID
     'PIC16F76',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     95                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All Memory locations code protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     51,               -- Device ID
     2,                -- Family ID
     'PIC16F77',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     95                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All Memory locations code protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     51,               -- Device ID
     2,                -- Family ID
     'PIC16F83',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     512,              -- End of FLASH
     8448,             -- Start of EEPROM
     8512,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     176               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power-up Timer is disabled',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power-up Timer is enabled',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection disabled',-- Description
     16368,            -- Bit Mask
     16368             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All program memory is code protected',-- Description
     16368,            -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     51,               -- Device ID
     2,                -- Family ID
     'PIC16F84',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8512,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     208               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power-up Timer is disabled',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power-up Timer is enabled',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection disabled',-- Description
     16368,            -- Bit Mask
     16368             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All program memory is code protected',-- Description
     16368,            -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     43,               -- Device ID
     2,                -- Family ID
     'PIC16F84A',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8512,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     208               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power-up Timer is disabled',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power-up Timer is enabled',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection disabled',-- Description
     16368,            -- Bit Mask
     16368             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All program memory is code protected',-- Description
     16368,            -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     57,               -- Device ID
     2,                -- Family ID
     'PIC16F87',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator; CLKO function on RA6/OSC2/CLKO',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRC oscillator; port I/O function on RA6/OSC2/CLKO',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator; CLKO function on RA6/OSC2/CLKO pin and port I/O function on RA7/OSC1/CLKI pin',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator; port I/O function on both RA6/OSC2/CLKO pin and RA7/OSC1/CLKI pin',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'ECIO; port I/O function on RA6/OSC2/CLKO',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR/VPP pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR/VPP pin function is digital I/O, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, Low-Voltage Programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EE memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write-protected, 0100h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '0000h to 07FFh write-protected, 0800h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '0000h to 0FFFh write-protected',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCPMX',          -- C Name
     'CCP1 Pin Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB0',            -- C Name
     'CCP1 function on RB0',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP1 function on RB3',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 0FFFh code-protected (all protected)',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     59,               -- Device ID
     2,                -- Family ID
     'PIC16F88',       -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator; CLKO function on RA6/OSC2/CLKO',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRC oscillator; port I/O function on RA6/OSC2/CLKO',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator; CLKO function on RA6/OSC2/CLKO pin and port I/O function on RA7/OSC1/CLKI pin',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator; port I/O function on both RA6/OSC2/CLKO pin and RA7/OSC1/CLKI pin',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'ECIO; port I/O function on RA6/OSC2/CLKO',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR/VPP pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR/VPP pin function is digital I/O, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, Low-Voltage Programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EE memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write-protected, 0100h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '0000h to 07FFh write-protected, 0800h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '0000h to 0FFFh write-protected',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCPMX',          -- C Name
     'CCP1 Pin Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB0',            -- C Name
     'CCP1 function on RB0',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP1 function on RB3',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 0FFFh code-protected (all protected)',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


-- PIC16F610 does not support self-programming.
-- PIC16F616 does not support self-programming.
insert into DEVICES values (
     null,
     61,               -- Device ID
     2,                -- Family ID
     'PIC16F627',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15871             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCLK',          -- C Name
     'ER oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, Resistor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERIO',           -- C Name
     'ER oscillator: I/O function on RA6/OSC2/CLKOUT pin, Resistor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR pin function select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD Reset enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD Reset disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB4/PGM pin has PGM function, low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB4/PGM pin has digital I/O function, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection off',-- Description
     15360,            -- Bit Mask
     15360             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '50',             -- C Name
     'Program memory code protection off',-- Description
     15360,            -- Bit Mask
     10240             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '75',             -- C Name
     '0200h-03FFh code protected',-- Description
     15360,            -- Bit Mask
     5120              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '0000h-03FFh code protected',-- Description
     15360,            -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     130,              -- Device ID
     2,                -- Family ID
     'PIC16F627A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8703              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, Resistor and Capacitor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RC oscillator: I/O function on RA6/OSC2/CLKOUT pin, Resistor and Capacitor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSC oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR/VPP pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR/VPP pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Detect Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB4/PGM pin has PGM function, low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB4/PGM pin has digital I/O function, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 03FFh code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     62,               -- Device ID
     2,                -- Family ID
     'PIC16F628',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15871             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCLK',          -- C Name
     'ER oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, Resistor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERIO',           -- C Name
     'ER oscillator: I/O function on RA6/OSC2/CLKOUT pin, Resistor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR pin function select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD Reset enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD Reset disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB4/PGM pin has PGM function, low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB4/PGM pin has digital I/O function, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection off',-- Description
     15360,            -- Bit Mask
     15360             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '50',             -- C Name
     '0400h-07FFh code protected',-- Description
     15360,            -- Bit Mask
     10240             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '75',             -- C Name
     '0200h-07FFh code protected',-- Description
     15360,            -- Bit Mask
     5120              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '0000h-07FFh code protected',-- Description
     15360,            -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     131,              -- Device ID
     2,                -- Family ID
     'PIC16F628A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8703              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, Resistor and Capacitor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RC oscillator: I/O function on RA6/OSC2/CLKOUT pin, Resistor and Capacitor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSC oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR/VPP pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR/VPP pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Detect Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB4/PGM pin has PGM function, low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB4/PGM pin has digital I/O function, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 07FFh code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     134,              -- Device ID
     2,                -- Family ID
     'PIC16F630',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     224               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     12799             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RC oscillator: I/O function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSC oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA3/MCLR pin function select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3/MCLR pin function is digital I/O, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Detect Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program Memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program Memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     161,              -- Device ID
     2,                -- Family ID
     'PIC16F631',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     133,              -- Device ID
     2,                -- Family ID
     'PIC16F636',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8191              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/T1G/OSC2/CLKOUT pin, RC on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/T1G/OSC2/CLKOUT pin, RC on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/T1G/OSC2/CLKOUT pin, I/O function on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/T1G/OSC2/CLKOUT pin, I/O function on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/T1G/OSC2/CLKOUT, CLKIN on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin is MCLR function and weak internal pull-up is enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is alternate function, MCLR function is internally disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is external read and write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory is not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory is external read protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled and SBOdEN bit disabled',-- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOD enabled while running and disabled in Sleep. SBODEN bit disabled.',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'SBODEN controls BOD function',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD and SBODEN disabled',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal-External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WURE',           -- C Name
     'Wake-Up Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Standard wake-up and continue enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wake-up and Reset enabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     133,              -- Device ID
     2,                -- Family ID
     'PIC16F639',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8191              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/T1G/OSC2/CLKOUT pin, RC on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/T1G/OSC2/CLKOUT pin, RC on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/T1G/OSC2/CLKOUT pin, I/O function on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/T1G/OSC2/CLKOUT pin, I/O function on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/T1G/OSC2/CLKOUT, CLKIN on RA5/T1CKI/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA5/T1CKI/OSC1/CLKIN and RA4/T1G/OSC2/CLKOUT',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin is MCLR function and weak internal pull-up is enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is alternate function, MCLR function is internally disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is external read and write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory is not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory is external read protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled and SBOdEN bit disabled',-- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOD enabled while running and disabled in Sleep. SBODEN bit disabled.',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'SBODEN controls BOD function',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD and SBODEN disabled',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal-External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WURE',           -- C Name
     'Wake-Up Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Standard wake-up and continue enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wake-up and Reset enabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     136,              -- Device ID
     2,                -- Family ID
     'PIC16F648A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8703              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, Resistor and Capacitor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RC oscillator: I/O function on RA6/OSC2/CLKOUT pin, Resistor and Capacitor on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSC oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR/VPP pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR/VPP pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Detect Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB4/PGM pin has PGM function, low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB4/PGM pin has digital I/O function, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 0FFFh code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     135,              -- Device ID
     2,                -- Family ID
     'PIC16F676',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     224               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     12799             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RC oscillator: I/O function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSC oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA3/MCLR pin function select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3/MCLR pin function is digital I/O, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Detect Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOD enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOD disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program Memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program Memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     162,              -- Device ID
     2,                -- Family ID
     'PIC16F677',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     132,              -- Device ID
     2,                -- Family ID
     'PIC16F684',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator: External RC on RA5/OSC1/CLKIN, CLKOUT function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRCIO oscillator: External RC on RA5/OSC1/CLKIN, I/O function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKINT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     37,               -- Device ID
     2,                -- Family ID
     'PIC16F685',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     153,              -- Device ID
     2,                -- Family ID
     'PIC16F687',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     140,              -- Device ID
     2,                -- Family ID
     'PIC16F688',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator: External RC on RA5/OSC1/CLKIN, CLKOUT function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRCIO oscillator: External RC on RA5/OSC1/CLKIN, I/O function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKINT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     154,              -- Device ID
     2,                -- Family ID
     'PIC16F689',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     160,              -- Device ID
     2,                -- Family ID
     'PIC16F690',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, RC on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCCLK',       -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRCIO',        -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     214,              -- Device ID
     2,                -- Family ID
     'PIC16F707',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     14207             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function  on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN pins',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_OSC',         -- C Name
     'EC oscillator: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS_OSC',         -- C Name
     'HS oscillator: High Speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_OSC',         -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKIN and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP_OSC',         -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled (Preconditioned State)',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled (Preconditioned State)',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16 MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'All VCAP pin functions are disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     138,              -- Device ID
     2,                -- Family ID
     'PIC16F716',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8399              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BODENV',         -- C Name
     'Brown-out Reset Voltage bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '40',             -- C Name
     'VBOR set to 4.0V',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     224,              -- Device ID
     2,                -- Family ID
     'PIC16F720',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     13179             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLK',          -- C Name
     'EC oscillator: CLKO function on RA4/CLKO pin, CLKI on RA5/CLKI',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator: I/O function on RA4/CLKO pin, CLKI on RA5/CLKI',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKO function on RA4/CLKO pin, I/O function on RA5/CLKI',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/CLKO pin, I/O function on RA5/CLKI',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA3/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA3/MCLR/VPP pin function is MCLR; Weak pull-up enabled.',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3/MCLR/VPP pin function is digital input; MCLR internally disabled; Weak pull-up disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 07FFh code protection on',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled (Preconditioned State)',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16 MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     19                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTEN',          -- C Name
     'Flash memory self-write protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '0h to 1FFh of flash memory write protected, 200h to FFFh may be modified',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0h to 7FFh of flash memory write protected, 800h to FFFh may be modified',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'FULL',           -- C Name
     '0h to FFFh of flash memory write protected, no address may be modified',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     225,              -- Device ID
     2,                -- Family ID
     'PIC16F721',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     13179             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLK',          -- C Name
     'EC oscillator: CLKO function on RA4/CLKO pin, CLKI on RA5/CLKI',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator: I/O function on RA4/CLKO pin, CLKI on RA5/CLKI',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKO function on RA4/CLKO pin, I/O function on RA5/CLKI',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/CLKO pin, I/O function on RA5/CLKI',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA3/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA3/MCLR/VPP pin function is MCLR; Weak pull-up enabled.',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3/MCLR/VPP pin function is digital input; MCLR internally disabled; Weak pull-up disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 0FFFh code protection on',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled (Preconditioned State)',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16 MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     19                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTEN',          -- C Name
     'Flash memory self-write protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '0h to 1FFh of flash memory write protected, 200h to FFFh may be modified',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0h to 7FFh of flash memory write protected, 800h to FFFh may be modified',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'FULL',           -- C Name
     '0h to FFFh of flash memory write protected, no address may be modified',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     196,              -- Device ID
     2,                -- Family ID
     'PIC16F722',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'All VCAP pin functions are disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     217,              -- Device ID
     2,                -- Family ID
     'PIC16F722A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-circuit debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-circuit debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'All VCAP pin functions are disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     195,              -- Device ID
     2,                -- Family ID
     'PIC16F723',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'All VCAP pin functions are disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     216,              -- Device ID
     2,                -- Family ID
     'PIC16F723A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-circuit debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-circuit debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'All VCAP pin functions are disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     194,              -- Device ID
     2,                -- Family ID
     'PIC16F724',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'All VCAP pin functions are disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     193,              -- Device ID
     2,                -- Family ID
     'PIC16F726',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'All VCAP pin functions are disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     192,              -- Device ID
     2,                -- Family ID
     'PIC16F727',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIS',            -- C Name
     'All VCAP pin functions are disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     93,               -- Device ID
     2,                -- Family ID
     'PIC16F737',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     14847             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator; CLKO function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRC oscillator; port I/O function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator; CLKO function on OSC2/CLKO/RA6 and port I/O function on OSC1/CLKI/RA7',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator; port I/O function on OSC1/CLKI/RA7 and OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EXTCLK; port I/O function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR/VPP/RE3 Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP/RE3 pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP/RE3 pin function is digital input only, MCLR gated to ''1''',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     384,              -- Bit Mask
     384               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     384,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     384,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     384,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'CCP2 is on RC1', -- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP2 is on RB3', -- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 0FFFh code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     67                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORSEN',         -- C Name
     'Brown-out Reset Software Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     95,               -- Device ID
     2,                -- Family ID
     'PIC16F747',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     14847             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator; CLKO function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRC oscillator; port I/O function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator; CLKO function on OSC2/CLKO/RA6 and port I/O function on OSC1/CLKI/RA7',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator; port I/O function on OSC1/CLKI/RA7 and OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EXTCLK; port I/O function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR/VPP/RE3 Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP/RE3 pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP/RE3 pin function is digital input only, MCLR gated to ''1''',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     384,              -- Bit Mask
     384               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     384,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     384,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     384,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'CCP2 is on RC1', -- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP2 is on RB3', -- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 0FFFh code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     67                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORSEN',         -- C Name
     'Brown-out Reset Software Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     117,              -- Device ID
     2,                -- Family ID
     'PIC16F767',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     14847             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator; CLKO function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRC oscillator; port I/O function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator; CLKO function on OSC2/CLKO/RA6 and port I/O function on OSC1/CLKI/RA7',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator; port I/O function on OSC1/CLKI/RA7 and OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EXTCLK; port I/O function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR/VPP/RE3 Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP/RE3 pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP/RE3 pin function is digital input only, MCLR gated to ''1''',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     384,              -- Bit Mask
     384               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     384,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     384,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     384,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'CCP2 is on RC1', -- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP2 is on RB3', -- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 1FFFh code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     67                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORSEN',         -- C Name
     'Brown-out Reset Software Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     111,              -- Device ID
     2,                -- Family ID
     'PIC16F777',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     2,                -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     14847             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator; CLKO function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRC oscillator; port I/O function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator; CLKO function on OSC2/CLKO/RA6 and port I/O function on OSC1/CLKI/RA7',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator; port I/O function on OSC1/CLKI/RA7 and OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EXTCLK; port I/O function on OSC2/CLKO/RA6',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR/VPP/RE3 Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP/RE3 pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP/RE3 pin function is digital input only, MCLR gated to ''1''',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     384,              -- Bit Mask
     384               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     384,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     384,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     384,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'CCP2 is on RC1', -- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP2 is on RB3', -- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 1FFFh code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     67                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORSEN',         -- C Name
     'Brown-out Reset Software Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     144,              -- Device ID
     2,                -- Family ID
     'PIC16F785',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator: External RC on RA5/OSC1/CLKIN, CLKOUT function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRCIO oscillator: External RC on RA5/OSC1/CLKIN, I/O function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKINT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     38,               -- Device ID
     2,                -- Family ID
     'PIC16F818',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     1024,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator; CLKO function on RA6/OSC2/CLKO pin',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRC oscillator; port I/O function on RA6/OSC2/CLKO pin',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator; CLKO function on RA6/OSC2/CLKO pin and port I/O function on RA7/OSC1/CLKI pin',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator; port I/O function on both RA6/OSC2/CLKO pin and RA7/OSC1/CLKI pin',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EXTCLK; port I/O function on RA6/OSC2/CLKO pin',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR/VPP pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR/VPP pin function is digital I/O, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, Low-Voltage Programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3/PGM pin has digital I/O function, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EE memory locations code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '0000h to 01FFh write-protected, 0200h to 03FFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '0000h to 03FFh write-protected',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCPMX',          -- C Name
     'CCP1 Pin Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB2',            -- C Name
     'CCP1 function on RB2',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP1 function on RB3',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All memory locations code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     39,               -- Device ID
     2,                -- Family ID
     'PIC16F819',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator; CLKO function on RA6/OSC2/CLKO pin',-- Description
     19,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRC oscillator; port I/O function on RA6/OSC2/CLKO pin',-- Description
     19,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTRC oscillator; CLKO function on RA6/OSC2/CLKO pin and port I/O function on RA7/OSC1/CLKI pin',-- Description
     19,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTRC oscillator; port I/O function on both RA6/OSC2/CLKO pin and RA7/OSC1/CLKI pin',-- Description
     19,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EXTCLK; port I/O function on RA6/OSC2/CLKO pin',-- Description
     19,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     19,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     19,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     19,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA5/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA5/MCLR/VPP pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5/MCLR/VPP pin function is digital I/O, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, Low-Voltage Programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3/PGM pin has digital I/O function, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EE memory locations code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '0000h to 01FFh write-protected, 0200h to 07FFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '0000h to 03FFh write-protected, 0400h to 07FFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1536',           -- C Name
     '0000h to 05FFh write-protected, 0600h to 07FFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCPMX',          -- C Name
     'CCP1 Pin Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB2',            -- C Name
     'CCP1 function on RB2',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP1 function on RB3',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All memory locations code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     104,              -- Device ID
     2,                -- Family ID
     'PIC16F870',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8512,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15359             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     12336,            -- Bit Mask
     12336             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All memory code protected',-- Description
     12336,            -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code Protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'FLASH Program Memory Write Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     'Unprotected program memory may be written to by EECON control',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Unprotected program memory may not be written to by EECON control',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     105,              -- Device ID
     2,                -- Family ID
     'PIC16F871',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8512,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15359             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     12336,            -- Bit Mask
     12336             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All memory code protected',-- Description
     12336,            -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code Protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'FLASH Program Memory Write Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     'Unprotected program memory may be written to by EECON control',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Unprotected program memory may not be written to by EECON control',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     71,               -- Device ID
     2,                -- Family ID
     'PIC16F872',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8512,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15359             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     12336,            -- Bit Mask
     12336             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All memory code protected',-- Description
     12336,            -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code Protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'FLASH Program Memory Write Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     'Unprotected program memory may be written to by EECON control',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Unprotected program memory may not be written to by EECON control',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     75,               -- Device ID
     2,                -- Family ID
     'PIC16F873',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15359             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     12336,            -- Bit Mask
     12336             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'UPPER_256',      -- C Name
     '0F00h to 0FFFh code protected',-- Description
     12336,            -- Bit Mask
     8224              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0800h to 0FFFh code protected',-- Description
     12336,            -- Bit Mask
     4112              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'All',            -- C Name
     '0000h to 0FFFh code protected',-- Description
     12336,            -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code Protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'FLASH Program Memory Write Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Unprotected program memory may be written to by EECON control',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Unprotected program memory may not be written to by EECON control',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     114,              -- Device ID
     2,                -- Family ID
     'PIC16F873A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     8,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     12239             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage (Single-Supply) In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off; all program memory may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write-protected; 0100h to 0FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 03FFh write-protected; 0400h to 0FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 07FFh write-protected; 0800h to 0FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All program memory code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     73,               -- Device ID
     2,                -- Family ID
     'PIC16F874',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15359             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     12336,            -- Bit Mask
     12336             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'UPPER_256',      -- C Name
     '0F00h to 0FFFh code protected',-- Description
     12336,            -- Bit Mask
     8224              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0800h to 0FFFh code protected',-- Description
     12336,            -- Bit Mask
     4112              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'All',            -- C Name
     '0000h to 0FFFh code protected',-- Description
     12336,            -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code Protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'FLASH Program Memory Write Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Unprotected program memory may be written to by EECON control',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Unprotected program memory may not be written to by EECON control',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     115,              -- Device ID
     2,                -- Family ID
     'PIC16F874A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     8,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     12239             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage (Single-Supply) In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off; all program memory may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write-protected; 0100h to 0FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 03FFh write-protected; 0400h to 0FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 07FFh write-protected; 0800h to 0FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All program memory code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     79,               -- Device ID
     2,                -- Family ID
     'PIC16F876',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15359             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     12336,            -- Bit Mask
     12336             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'UPPER_256',      -- C Name
     '1F00h to 1FFFh code protected',-- Description
     12336,            -- Bit Mask
     8224              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '1000h to 1FFFh code protected',-- Description
     12336,            -- Bit Mask
     4112              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'All',            -- C Name
     '0000h to 1FFFh code protected',-- Description
     12336,            -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code Protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'FLASH Program Memory Write Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Unprotected program memory may be written to by EECON control',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Unprotected program memory may not be written to by EECON control',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     112,              -- Device ID
     2,                -- Family ID
     'PIC16F876A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     8,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     12239             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage (Single-Supply) In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off; all program memory may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write-protected; 0100h to 1FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 07FFh write-protected; 0800h to 1FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 0FFFh write-protected; 1000h to 1FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All program memory code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     77,               -- Device ID
     2,                -- Family ID
     'PIC16F877',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     1,                -- Write FLASH Block Size
     1,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     15359             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'FLASH Program Memory Code Protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     12336,            -- Bit Mask
     12336             -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'UPPER_256',      -- C Name
     '1F00h to 1FFFh code protected',-- Description
     12336,            -- Bit Mask
     8224              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '1000h to 1FFFh code protected',-- Description
     12336,            -- Bit Mask
     4112              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'All',            -- C Name
     '0000h to 1FFFh code protected',-- Description
     12336,            -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code Protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM memory code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'FLASH Program Memory Write Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Unprotected program memory may be written to by EECON control',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Unprotected program memory may not be written to by EECON control',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     113,              -- Device ID
     2,                -- Family ID
     'PIC16F877A',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     8,                -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     12239             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator',  -- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage (Single-Supply) In-Circuit Serial Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function; low-voltage programming enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 is digital I/O, HV on MCLR must be used for programming',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM code protection off',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off; all program memory may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write-protected; 0100h to 1FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 07FFh write-protected; 0800h to 1FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 0FFFh write-protected; 1000h to 1FFFh may be written to by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6 and RB7 are general purpose I/O pins',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6 and RB7 are dedicated to the debugger',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'All program memory code-protected',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     256,              -- Device ID
     2,                -- Family ID
     'PIC16F882',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8576,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_CLKOUT',   -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_NOCLKOUT', -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_CLKOUT',   -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_NOCLKOUT', -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, low voltage programming enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 pin has digital I/O, HV on MCLR must be used for programming',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In_Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     1792              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR4V',          -- C Name
     'Brown-out Reset Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR21V',         -- C Name
     'Brown-out Reset set to 2.1V',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR40V',         -- C Name
     'Brown-out Reset set to 4.0V',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Self Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 03FFh write protected, 0400h to 07FFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 00FFh write protected, 0100h to 07FFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);


insert into DEVICES values (
     null,
     257,              -- Device ID
     2,                -- Family ID
     'PIC16F883',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_CLKOUT',   -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_NOCLKOUT', -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_CLKOUT',   -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_NOCLKOUT', -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, low voltage programming enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 pin has digital I/O, HV on MCLR must be used for programming',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In_Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     1792              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR4V',          -- C Name
     'Brown-out Reset Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR21V',         -- C Name
     'Brown-out Reset set to 2.1V',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR40V',         -- C Name
     'Brown-out Reset set to 4.0V',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Self Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 07FFh write protected, 0800h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 03FFh write protected, 0400h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write protected, 0100h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);


insert into DEVICES values (
     null,
     258,              -- Device ID
     2,                -- Family ID
     'PIC16F884',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_CLKOUT',   -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_NOCLKOUT', -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_CLKOUT',   -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_NOCLKOUT', -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, low voltage programming enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 pin has digital I/O, HV on MCLR must be used for programming',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In_Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     1792              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR4V',          -- C Name
     'Brown-out Reset Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR21V',         -- C Name
     'Brown-out Reset set to 2.1V',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR40V',         -- C Name
     'Brown-out Reset set to 4.0V',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Self Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 07FFh write protected, 0800h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 03FFh write protected, 0400h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write protected, 0100h to 0FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);


insert into DEVICES values (
     null,
     259,              -- Device ID
     2,                -- Family ID
     'PIC16F886',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_CLKOUT',   -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_NOCLKOUT', -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_CLKOUT',   -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_NOCLKOUT', -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, low voltage programming enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 pin has digital I/O, HV on MCLR must be used for programming',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In_Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     1792              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR4V',          -- C Name
     'Brown-out Reset Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR21V',         -- C Name
     'Brown-out Reset set to 2.1V',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR40V',         -- C Name
     'Brown-out Reset set to 4.0V',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Self Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 0FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 07FFh write protected, 0800h to 1FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write protected, 0100h to 1FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);


insert into DEVICES values (
     null,
     260,              -- Device ID
     2,                -- Family ID
     'PIC16F887',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_CLKOUT',   -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC_NOCLKOUT', -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_CLKOUT',   -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTRC_NOCLKOUT', -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Programming Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RB3/PGM pin has PGM function, low voltage programming enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RB3 pin has digital I/O, HV on MCLR must be used for programming',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In_Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     1792              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR4V',          -- C Name
     'Brown-out Reset Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR21V',         -- C Name
     'Brown-out Reset set to 2.1V',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOR40V',         -- C Name
     'Brown-out Reset set to 4.0V',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Program Memory Self Write Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0000h to 0FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1FOURTH',        -- C Name
     '0000h to 07FFh write protected, 0800h to 1FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '0000h to 00FFh write protected, 0100h to 1FFFh may be modified by EECON control',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);


insert into DEVICES values (
     null,
     159,              -- Device ID
     2,                -- Family ID
     'PIC16F913',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8191              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, CLKIN on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power Up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ISCPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     158,              -- Device ID
     2,                -- Family ID
     'PIC16F914',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8191              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, CLKIN on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power Up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ISCPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     157,              -- Device ID
     2,                -- Family ID
     'PIC16F916',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8191              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, CLKIN on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power Up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ISCPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     156,              -- Device ID
     2,                -- Family ID
     'PIC16F917',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8191              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, CLKIN on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power Up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ISCPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     163,              -- Device ID
     2,                -- Family ID
     'PIC16F946',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     8191              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, RC on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, I/O function on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT/T1OSO pin, CLKIN on RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT/T1OSO and RA7/OSC1/CLKIN/T1OSI',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power Up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ISCPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     360,              -- Device ID
     2,                -- Family ID
     'PIC16F1507',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     3835              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'External Clock, High Power Mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'External Clock, Medium Power Mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'External Clock, Low Power Mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal Oscillator, I/O Function on OSC1',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     11779             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOREN',        -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     180,              -- Device ID
     2,                -- Family ID
     'PIC16F1516',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15891             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'VCAP pin function disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'VCAP pin function enabled',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     181,              -- Device ID
     2,                -- Family ID
     'PIC16F1517',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15891             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'VCAP pin function disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'VCAP pin function enabled',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     182,              -- Device ID
     2,                -- Family ID
     'PIC16F1518',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15891             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'VCAP pin function disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'VCAP pin function enabled',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     183,              -- Device ID
     2,                -- Family ID
     'PIC16F1519',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15891             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'VCAP pin function disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'VCAP pin function enabled',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     172,              -- Device ID
     2,                -- Family ID
     'PIC16F1526',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15891             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 2000h to 3FFFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'VCAP pin function disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'VCAP pin function enabled',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '245',            -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.45V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '270',            -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.7 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     173,              -- Device ID
     2,                -- Family ID
     'PIC16F1527',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15891             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 2000h to 3FFFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'VCAP pin function disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'VCAP pin function enabled',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     336,              -- Device ID
     2,                -- Family ID
     'PIC16F1782',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     16179             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN0',        -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Vcap functionality is disabled on RA0.',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Vcap functionality is enabled on RA0 (Vddcore is connected to the pad)',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN1',        -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Vcap functionality is disabled on RA6',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Vcap functionality is enabled on RA6 (Vddcore is connected to the pad)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOREN',        -- C Name
     'Low Power Brown-Out Reset Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'Disabled',       -- C Name
     'Low power brown-out is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'Enabled',        -- C Name
     'Low power brown-out is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     337,              -- Device ID
     2,                -- Family ID
     'PIC16F1783',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     16179             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN0',        -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Vcap functionality is disabled on RA0.',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Vcap functionality is enabled on RA0 (Vddcore is connected to the pad)',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN1',        -- C Name
     ''                -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Vcap finctionality is disabled on RA6',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Vcap functionality is enabled on RA6 (Vddcore is connected to the pad)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOREN',        -- C Name
     'Low Power Brown-Out Reset Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'Disabled',       -- C Name
     'Low power brown-out is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'Enabled',        -- C Name
     'Low power brown-out is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     313,              -- Device ID
     2,                -- Family ID
     'PIC16F1823',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     314,              -- Device ID
     2,                -- Family ID
     'PIC16F1824',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     315,              -- Device ID
     2,                -- Family ID
     'PIC16F1825',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     316,              -- Device ID
     2,                -- Family ID
     'PIC16F1826',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     317,              -- Device ID
     2,                -- Family ID
     'PIC16F1827',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     318,              -- Device ID
     2,                -- Family ID
     'PIC16F1828',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     319,              -- Device ID
     2,                -- Family ID
     'PIC16F1829',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     164,              -- Device ID
     2,                -- Family ID
     'PIC16F1847',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     280,              -- Device ID
     2,                -- Family ID
     'PIC16F1933',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14131             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'All VCAP pin functionality is disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     282,              -- Device ID
     2,                -- Family ID
     'PIC16F1934',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14131             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'All VCAP pin functionality is disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     283,              -- Device ID
     2,                -- Family ID
     'PIC16F1936',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14131             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'All VCAP pin functionality is disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     284,              -- Device ID
     2,                -- Family ID
     'PIC16F1937',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14131             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'All VCAP pin functionality is disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     285,              -- Device ID
     2,                -- Family ID
     'PIC16F1938',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14131             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'All VCAP pin functionality is disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     286,              -- Device ID
     2,                -- Family ID
     'PIC16F1939',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14131             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'All VCAP pin functionality is disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA6',            -- C Name
     'VCAP functionality is enabled on RA6',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'VCAP functionality is enabled on RA5',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA0',            -- C Name
     'VCAP functionality is enabled on RA0',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     296,              -- Device ID
     2,                -- Family ID
     'PIC16F1946',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'VCAP pin functionality is disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'VCAP functionality is enabled on VCAP pin',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     297,              -- Device ID
     2,                -- Family ID
     'PIC16F1947',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VCAPEN',         -- C Name
     'Voltage Regulator Capacitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'VCAP pin functionality is disabled',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'VCAP functionality is enabled on VCAP pin',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


-- PIC16HV610 does not support self-programming.
-- PIC16HV616 does not support self-programming.
insert into DEVICES values (
     null,
     145,              -- Device ID
     2,                -- Family ID
     'PIC16HV785',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     4,                -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     8448,             -- Start of EEPROM
     8704,             -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8200,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     4095              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'EXTRC oscillator: External RC on RA5/OSC1/CLKIN, CLKOUT function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'EXTRCIO oscillator: External RC on RA5/OSC1/CLKIN, I/O function on RA4/OSC2/CLKOUT pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/OSC2/CLKOUT pin, I/O function on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA4/OSC2/CLKOUT pin, CLKIN on RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA4/OSC2/CLKOUT and RA5/OSC1/CLKINT',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA4/OSC2/CLKOUT and RA5/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'BOR controlled by SBOREN bit of the PCON register',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode is enabled',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode is disabled',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enabled bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     215,              -- Device ID
     2,                -- Family ID
     'PIC16LF707',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG',         -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     14207             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function  on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN pins',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_OSC',         -- C Name
     'EC oscillator: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS_OSC',         -- C Name
     'HS oscillator: High Speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_OSC',         -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKIN and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP_OSC',         -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled (Preconditioned State)',-- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled (Preconditioned State)',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16 MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     0                 -- Implemented Bits
);

insert into DEVICES values (
     null,
     226,              -- Device ID
     2,                -- Family ID
     'PIC16LF720',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     13179             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLK',          -- C Name
     'EC oscillator: CLKO function on RA4/CLKO pin, CLKI on RA5/CLKI',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator: I/O function on RA4/CLKO pin, CLKI on RA5/CLKI',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKO function on RA4/CLKO pin, I/O function on RA5/CLKI',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/CLKO pin, I/O function on RA5/CLKI',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA3/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA3/MCLR/VPP pin function is MCLR; Weak pull-up enabled.',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3/MCLR/VPP pin function is digital input; MCLR internally disabled; Weak pull-up disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 07FFh code protection on',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled (Preconditioned State)',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16 MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTEN',          -- C Name
     'Flash memory self-write protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '0h to 1FFh of flash memory write protected, 200h to FFFh may be modified',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0h to 7FFh of flash memory write protected, 800h to FFFh may be modified',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'FULL',           -- C Name
     '0h to FFFh of flash memory write protected, no address may be modified',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     227,              -- Device ID
     2,                -- Family ID
     'PIC16LF721',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     13179             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLK',          -- C Name
     'EC oscillator: CLKO function on RA4/CLKO pin, CLKI on RA5/CLKI',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator: I/O function on RA4/CLKO pin, CLKI on RA5/CLKI',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKO function on RA4/CLKO pin, I/O function on RA5/CLKI',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA4/CLKO pin, I/O function on RA5/CLKI',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RA3/MCLR/VPP Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA3/MCLR/VPP pin function is MCLR; Weak pull-up enabled.',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3/MCLR/VPP pin function is digital input; MCLR internally disabled; Weak pull-up disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '0000h to 0FFFh code protection on',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Code protection off',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled (Preconditioned State)',-- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16 MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTEN',          -- C Name
     'Flash memory self-write protection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '0h to 1FFh of flash memory write protected, 200h to FFFh may be modified',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '0h to 7FFh of flash memory write protected, 800h to FFFh may be modified',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'FULL',           -- C Name
     '0h to FFFh of flash memory write protected, no address may be modified',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     204,              -- Device ID
     2,                -- Family ID
     'PIC16LF722',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);

insert into DEVICES values (
     null,
     219,              -- Device ID
     2,                -- Family ID
     'PIC16LF722A',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-circuit debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-circuit debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);

insert into DEVICES values (
     null,
     203,              -- Device ID
     2,                -- Family ID
     'PIC16LF723',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);

insert into DEVICES values (
     null,
     218,              -- Device ID
     2,                -- Family ID
     'PIC16LF723A',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR Pin Function Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-circuit debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-circuit debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);

insert into DEVICES values (
     null,
     202,              -- Device ID
     2,                -- Family ID
     'PIC16LF724',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);

insert into DEVICES values (
     null,
     201,              -- Device ID
     2,                -- Family ID
     'PIC16LF726',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);

insert into DEVICES values (
     null,
     200,              -- Device ID
     2,                -- Family ID
     'PIC16LF727',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     8192,             -- Start of User ID
     8196,             -- End of User ID
     8199,             -- Start of Config Bits
     8201,             -- End of Config Bits
     8198,             -- Start of Device Id
     8199,             -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     8199,             -- Address
     65535,            -- Default Value
     16255             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCCLK',       -- C Name
     'RC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRCIO',        -- C Name
     'RCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, RC on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCCLK',      -- C Name
     'INTOSC oscillator: CLKOUT function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO',       -- C Name
     'INTOSCIO oscillator: I/O function on RA6/OSC2/CLKOUT pin, I/O function on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC: I/O function on RA6/OSC2/CLKOUT pin, CLKIN on RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator: High-speed crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator: Crystal/resonator on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator: Low-power crystal on RA6/OSC2/CLKOUT and RA7/OSC1/CLKIN',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled and can be enabled by SWDTEN bit of the WDTCON register',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'nPWRTE',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'RE3/MCLR pin function select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3/MCLR pin function is digital input, MCLR internally tied to VDD',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RE3/MCLR pin function is MCLR',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'BOR enabled',    -- Description
     768,              -- Bit Mask
     768               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'BOR enabled during operation and disabled in Sleep',-- Description
     768,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'BOR disabled',   -- Description
     768,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V nominal',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V nominal',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'INTOSC PLLEN Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'INTOSC Frequency is 16MHz (32x)',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTOSC Frequency is 500 kHz',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'In-Circuit Debugger Mode bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'In-Circuit Debugger disabled, RB6/ICSPCLK and RB7/ICSPDAT are general purpose I/O pins',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'In-Circuit Debugger enabled, RB6/ICSPCLK and RB7/ICSPDAT are dedicated to the debugger',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     8200,             -- Address
     65535,            -- Default Value
     48                -- Implemented Bits
);

insert into DEVICES values (
     null,
     360,              -- Device ID
     2,                -- Family ID
     'PIC16LF1507',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     3835              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'External Clock, High Power Mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'External Clock, Medium Power Mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'External Clock, Low Power Mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal Oscillator, I/O function on OSC1',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     3587              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOREN',        -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     188,              -- Device ID
     2,                -- Family ID
     'PIC16LF1516',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     189,              -- Device ID
     2,                -- Family ID
     'PIC16LF1517',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     190,              -- Device ID
     2,                -- Family ID
     'PIC16LF1518',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     191,              -- Device ID
     2,                -- Family ID
     'PIC16LF1519',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     174,              -- Device ID
     2,                -- Family ID
     'PIC16LF1526',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 2000h to 3FFFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     175,              -- Device ID
     2,                -- Family ID
     'PIC16LF1527',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16127             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-20 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 2000h to 3FFFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown Out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     341,              -- Device ID
     2,                -- Family ID
     'PIC16LF1782',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     16131             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOREN',        -- C Name
     'Low Power Brown-Out Reset Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'Disabled',       -- C Name
     'Low power brown-out is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'Enabled',        -- C Name
     'Low power brown-out is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     342,              -- Device ID
     2,                -- Family ID
     'PIC16LF1783',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     16131             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOREN',        -- C Name
     'Low Power Brown-Out Reset Enable Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'Disabled',       -- C Name
     'Low power brown-out is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'Enabled',        -- C Name
     'Low power brown-out is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     321,              -- Device ID
     2,                -- Family ID
     'PIC16LF1823',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     16,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     322,              -- Device ID
     2,                -- Family ID
     'PIC16LF1824',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     323,              -- Device ID
     2,                -- Family ID
     'PIC16LF1825',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     324,              -- Device ID
     2,                -- Family ID
     'PIC16LF1826',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     325,              -- Device ID
     2,                -- Family ID
     'PIC16LF1827',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     326,              -- Device ID
     2,                -- Family ID
     'PIC16LF1828',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     327,              -- Device ID
     2,                -- Family ID
     'PIC16LF1829',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     165,              -- Device ID
     2,                -- Family ID
     'PIC16LF1847',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14099             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     353,              -- Device ID
     2,                -- Family ID
     'PIC16LF1902',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     2048,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     3835              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown-out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     352,              -- Device ID
     2,                -- Family ID
     'PIC16LF1903',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     3835              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown-out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     356,              -- Device ID
     2,                -- Family ID
     'PIC16LF1904',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     3835              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown-out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     355,              -- Device ID
     2,                -- Family ID
     'PIC16LF1906',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     3835              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown-out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     354,              -- Device ID
     2,                -- Family ID
     'PIC16LF1907',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     3835              -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     15875             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 3FFh write protected, 400h to 7FFh may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 7FFh write protected, no addresses may be modified by PMCON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPBOR',          -- C Name
     'Low-Power Brown-out Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Power BOR is disabled',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Power BOR is enabled',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     288,              -- Device ID
     2,                -- Family ID
     'PIC16LF1933',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     290,              -- Device ID
     2,                -- Family ID
     'PIC16LF1934',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 7FFh write protected, 800h to FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     291,              -- Device ID
     2,                -- Family ID
     'PIC16LF1936',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     292,              -- Device ID
     2,                -- Family ID
     'PIC16LF1937',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     293,              -- Device ID
     2,                -- Family ID
     'PIC16LF1938',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     294,              -- Device ID
     2,                -- Family ID
     'PIC16LF1939',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to 1FFFh write protected, 2000h to 3FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 3FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     300,              -- Device ID
     2,                -- Family ID
     'PIC16LF1946',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     32,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     61440,            -- Start of EEPROM
     61696,            -- End of EEPROM
     32768,            -- Start of User ID
     32772,            -- End of User ID
     32775,            -- Start of Config Bits
     32777,            -- End of Config Bits
     32774,            -- Start of Device Id
     32775,            -- End of Device Id
     16352,            -- Device Id Mask
     0,                -- Start of GPR
     4096              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1',        -- Config Name
     32775,            -- Address
     65535,            -- Default Value
     16383             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'ECH, External Clock, High Power Mode (4-32 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'ECM, External Clock, Medium Power Mode (0.5-4 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'ECL, External Clock, Low Power Mode (0-0.5 MHz): device clock supplied to CLKIN pin',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC oscillator: I/O function on CLKIN pin',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTRC',          -- C Name
     'EXTRC oscillator: External RC circuit connected to CLKIN pin',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator, Crystal/resonator connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator, Low-power crystal connected between OSC1 and OSC2 pins',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTE',           -- C Name
     'Watchdog Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'WDT enabled while running and disabled in Sleep',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTEN',         -- C Name
     'WDT controlled by the SWDTEN bit in the WDTCON register',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled',   -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTE',          -- C Name
     'Power-up Timer Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Function Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR/VPP pin function is MCLR',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR/VPP pin function is digital input',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP',             -- C Name
     'Flash Program Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory code protection is disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory code protection is enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data Memory Code Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data memory code protection is disabled',-- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data memory code protection is enabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     1536,             -- Bit Mask
     1536              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NSLEEP',         -- C Name
     'Brown-out Reset enabled while running and disabled in Sleep',-- Description
     1536,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBODEN',         -- C Name
     'Brown-out Reset controlled by the SBOREN bit in the BORCON register',-- Description
     1536,             -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     1536,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOUTEN',       -- C Name
     'Clock Out Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     2048              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKOUT function is enabled on the CLKOUT pin',-- Description
     2048,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode is enabled',-- Description
     4096,             -- Bit Mask
     4096              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode is disabled',-- Description
     4096,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor is enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor is disabled',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2',        -- Config Name
     32776,            -- Address
     65535,            -- Default Value
     14083             -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT',            -- C Name
     'Flash Memory Self-Write Protection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Write protection off',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOOT',           -- C Name
     '000h to 1FFh write protected, 200h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HALF',           -- C Name
     '000h to FFFh write protected, 1000h to 1FFFh may be modified by EECON control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALL',            -- C Name
     '000h to 1FFFh write protected, no addresses may be modified by EECON control',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     'PLL Enable'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '4x PLL enabled', -- Description
     256,              -- Bit Mask
     256               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '4x PLL disabled',-- Description
     256,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Overflow or Underflow will cause a Reset',-- Description
     512,              -- Bit Mask
     512               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Overflow or Underflow will not cause a Reset',-- Description
     512,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 1.9 V',-- Description
     1024,             -- Bit Mask
     1024              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'Brown-out Reset Voltage (VBOR) set to 2.5 V',-- Description
     1024,             -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage Programming Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage programming enabled',-- Description
     8192,             -- Bit Mask
     8192              -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-voltage on MCLR/VPP must be used for programming',-- Description
     8192,             -- Bit Mask
     0                 -- Bit Value
);

insert into DEVICES values (
     null,
     634,              -- Device ID
     4,                -- Family ID
     'PIC18F13K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '111X External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'EC (low)',       -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTL',      -- C Name
     'EC, CLKOUT function on OSC2 (low)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'EC (medium)',    -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTM',      -- C Name
     'EC, CLKOUT function on OSC2 (medium)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCCLKOUT',      -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERC',            -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '0110 External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'EC (high)',      -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTH',      -- C Name
     'EC, CLKOUT function on OSC2 (high)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCCLKOUT',      -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     '4 X PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL is under software control',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PCLKEN',         -- C Name
     'Primary Clock Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock is under software control',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'VBOR set to 1.9 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect.',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     136,              -- Default Value
     136               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RA3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     77                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '1kW boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '512W boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     570,              -- Device ID
     4,                -- Family ID
     'PIC18F13K50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     56                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV4',        -- C Name
     'CPU System Clock divided by 4',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV3',        -- C Name
     'CPU System Clock divided by 3',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV2',        -- C Name
     'CPU System Clock divided by 2',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOCLKDIV',       -- C Name
     'No CPU System Clock divide',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB clock comes from the OSC1/OSC2 divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB clock comes directly from the OSC1/OSC2 oscillator block; no divide',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '111X External RC oscillator, CLKOUT function on OSC2',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'EC (low)',       -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTL',      -- C Name
     'EC, CLKOUT function on OSC2 (low)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'EC (medium)',    -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTM',      -- C Name
     'EC, CLKOUT function on OSC2 (medium)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCCLKOUT',      -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERC',            -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '0110 External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'EC (high)',      -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTH',      -- C Name
     'EC, CLKOUT function on OSC2 (high)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCCLKOUT',      -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     '4 X PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL is under software control',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PCLKEN',         -- C Name
     'Primary Clock Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock is under software control',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     63,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'VBOR set to 1.9 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect.',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     136,              -- Default Value
     136               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RA3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     77                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '1kW boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '512W boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     633,              -- Device ID
     4,                -- Family ID
     'PIC18F14K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '111X External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'EC (low)',       -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTL',      -- C Name
     'EC, CLKOUT function on OSC2 (low)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'EC (medium)',    -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTM',      -- C Name
     'EC, CLKOUT function on OSC2 (medium)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCCLKOUT',      -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERC',            -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '0110 External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'EC (high)',      -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTH',      -- C Name
     'EC, CLKOUT function on OSC2 (high)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCCLKOUT',      -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     '4 X PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL is under software control',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PCLKEN',         -- C Name
     'Primary Clock Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock is under software control',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'VBOR set to 1.9 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect.',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     136,              -- Default Value
     136               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RA3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     77                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '2kW boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '1kW boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     571,              -- Device ID
     4,                -- Family ID
     'PIC18F14K50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV4',        -- C Name
     'CPU System Clock divided by 4',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV3',        -- C Name
     'CPU System Clock divided by 3',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV2',        -- C Name
     'CPU System Clock divided by 2',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOCLKDIV',       -- C Name
     'No CPU System Clock divide',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB clock comes from the OSC1/OSC2 divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB clock comes directly from the OSC1/OSC2 oscillator block; no divide',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '111X External RC oscillator, CLKOUT function on OSC2',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'EC (low)',       -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTL',      -- C Name
     'EC, CLKOUT function on OSC2 (low)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'EC (medium)',    -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTM',      -- C Name
     'EC, CLKOUT function on OSC2 (medium)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCCLKOUT',      -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERC',            -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '0110 External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'EC (high)',      -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTH',      -- C Name
     'EC, CLKOUT function on OSC2 (high)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCCLKOUT',      -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     '4 X PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL is under software control',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PCLKEN',         -- C Name
     'Primary Clock Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock is under software control',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     63,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'VBOR set to 1.9 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect.',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     136,              -- Default Value
     136               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RA3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     77                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '2kW boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '1kW boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     263,              -- Device ID
     4,                -- Family ID
     'PIC18F23K20',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '18',             -- C Name
     'VBOR set to 1.8 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     698,              -- Device ID
     4,                -- Family ID
     'PIC18F23K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC6',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RC6',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P2B is on RB5',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     232,              -- Device ID
     4,                -- Family ID
     'PIC18F24J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16382,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     620,              -- Device ID
     4,                -- Family ID
     'PIC18F24J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16384,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     16382,            -- Address
     207,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     16383,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     608,              -- Device ID
     4,                -- Family ID
     'PIC18F24J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16384,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     247,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     16382,            -- Address
     207,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     16383,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     261,              -- Device ID
     4,                -- Family ID
     'PIC18F24K20',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '18',             -- C Name
     'VBOR set to 1.8 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     690,              -- Device ID
     4,                -- Family ID
     'PIC18F24K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC6',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RC6',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P2B is on RB5',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     224,              -- Device ID
     4,                -- Family ID
     'PIC18F25J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     621,              -- Device ID
     4,                -- Family ID
     'PIC18F25J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32768,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     32766,            -- Address
     223,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     31,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     31,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     31,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     31,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     31,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     31,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     31,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     31,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     31,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     31,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     31,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     31,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     31,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     31,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     31,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     31,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     31,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     31,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     31,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     31,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     31,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     31,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     31,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     31,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     31,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     31,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     31,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     31,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     31,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     31,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     31,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     31,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     32767,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     609,              -- Device ID
     4,                -- Family ID
     'PIC18F25J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32768,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     247,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     32766,            -- Address
     223,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     31,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     31,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     31,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     31,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     31,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     31,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     31,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     31,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     31,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     31,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     31,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     31,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     31,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     31,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     31,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     31,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     31,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     31,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     31,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     31,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     31,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     31,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     31,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     31,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     31,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     31,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     31,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     31,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     31,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     31,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     31,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     31,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     32767,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     259,              -- Device ID
     4,                -- Family ID
     'PIC18F25K20',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '18',             -- C Name
     'VBOR set to 1.8 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     682,              -- Device ID
     4,                -- Family ID
     'PIC18F25K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC6',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RC6',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P2B is on RB5',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     780,              -- Device ID
     4,                -- Family ID
     'PIC18F25K80',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECAN TX and RX pins are located on RC6 and RC7, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     622,              -- Device ID
     4,                -- Family ID
     'PIC18F26J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     713,              -- Device ID
     4,                -- Family ID
     'PIC18F26J13',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     '96MHz PLL Prescaler Selection (PLLSEL=0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLSEL',         -- C Name
     'PLL Selection Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL96',          -- C Name
     'Selects 96MHz PLL',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL4X',          -- C Name
     'Selects 4x PLL', -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     243,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     610,              -- Device ID
     4,                -- Family ID
     'PIC18F26J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     705,              -- Device ID
     4,                -- Family ID
     'PIC18F26J53',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     251,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     251,              -- Default Value
     11                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LS48MHZ',        -- C Name
     'Low Speed USB mode with 48 MHz system clock bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS24X4',        -- C Name
     'System clock at 24 MHz USB CLKEN divide-by is set to 4',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS48X8',        -- C Name
     'System clock at 48 MHz USB CLKEN divide-by is set to 8',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);


insert into DEVICES values (
     null,
     257,              -- Device ID
     4,                -- Family ID
     'PIC18F26K20',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '18',             -- C Name
     'VBOR set to 1.8 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000h-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000h-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     674,              -- Device ID
     4,                -- Family ID
     'PIC18F26K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3896              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC6',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RC6',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P2B is on RB5',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     777,              -- Device ID
     4,                -- Family ID
     'PIC18F26K80',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     141               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECAN TX and RX pins are located on RC6 and RC7, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     715,              -- Device ID
     4,                -- Family ID
     'PIC18F27J13',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     '96MHz PLL Prescaler Selection (PLLSEL=0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLSEL',         -- C Name
     'PLL Selection Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL96',          -- C Name
     'Selects 96MHz PLL',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL4X',          -- C Name
     'Selects 4x PLL', -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     131070,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     127,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     127,              -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     127,              -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     127,              -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     127,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     127,              -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     127,              -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     127,              -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     127,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     127,              -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     127,              -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     127,              -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     127,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     127,              -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     127,              -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     127,              -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     127,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     127,              -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     127,              -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     127,              -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     127,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     127,              -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     127,              -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     127,              -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     127,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     127,              -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     127,              -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     127,              -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     127,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     127,              -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     127,              -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     127,              -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     127,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     127,              -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     127,              -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     127,              -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     127,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     127,              -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     127,              -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     127,              -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     127,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     127,              -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     127,              -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     127,              -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     127,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     127,              -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     127,              -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     127,              -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     127,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     127,              -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     127,              -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     127,              -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     127,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     127,              -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     127,              -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     127,              -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     127,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     127,              -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     127,              -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     127,              -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     127,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     127,              -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     127,              -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     127,              -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_64',        -- C Name
     'Write Protect Program Flash Page 64',-- Description
     127,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_65',        -- C Name
     'Write Protect Program Flash Page 65',-- Description
     127,              -- Bit Mask
     65                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_66',        -- C Name
     'Write Protect Program Flash Page 66',-- Description
     127,              -- Bit Mask
     66                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_67',        -- C Name
     'Write Protect Program Flash Page 67',-- Description
     127,              -- Bit Mask
     67                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_68',        -- C Name
     'Write Protect Program Flash Page 68',-- Description
     127,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_69',        -- C Name
     'Write Protect Program Flash Page 69',-- Description
     127,              -- Bit Mask
     69                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_70',        -- C Name
     'Write Protect Program Flash Page 70',-- Description
     127,              -- Bit Mask
     70                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_71',        -- C Name
     'Write Protect Program Flash Page 71',-- Description
     127,              -- Bit Mask
     71                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_72',        -- C Name
     'Write Protect Program Flash Page 72',-- Description
     127,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_73',        -- C Name
     'Write Protect Program Flash Page 73',-- Description
     127,              -- Bit Mask
     73                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_74',        -- C Name
     'Write Protect Program Flash Page 74',-- Description
     127,              -- Bit Mask
     74                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_75',        -- C Name
     'Write Protect Program Flash Page 75',-- Description
     127,              -- Bit Mask
     75                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_76',        -- C Name
     'Write Protect Program Flash Page 76',-- Description
     127,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_77',        -- C Name
     'Write Protect Program Flash Page 77',-- Description
     127,              -- Bit Mask
     77                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_78',        -- C Name
     'Write Protect Program Flash Page 78',-- Description
     127,              -- Bit Mask
     78                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_79',        -- C Name
     'Write Protect Program Flash Page 79',-- Description
     127,              -- Bit Mask
     79                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_80',        -- C Name
     'Write Protect Program Flash Page 80',-- Description
     127,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_81',        -- C Name
     'Write Protect Program Flash Page 81',-- Description
     127,              -- Bit Mask
     81                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_82',        -- C Name
     'Write Protect Program Flash Page 82',-- Description
     127,              -- Bit Mask
     82                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_83',        -- C Name
     'Write Protect Program Flash Page 83',-- Description
     127,              -- Bit Mask
     83                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_84',        -- C Name
     'Write Protect Program Flash Page 84',-- Description
     127,              -- Bit Mask
     84                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_85',        -- C Name
     'Write Protect Program Flash Page 85',-- Description
     127,              -- Bit Mask
     85                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_86',        -- C Name
     'Write Protect Program Flash Page 86',-- Description
     127,              -- Bit Mask
     86                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_87',        -- C Name
     'Write Protect Program Flash Page 87',-- Description
     127,              -- Bit Mask
     87                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_88',        -- C Name
     'Write Protect Program Flash Page 88',-- Description
     127,              -- Bit Mask
     88                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_89',        -- C Name
     'Write Protect Program Flash Page 89',-- Description
     127,              -- Bit Mask
     89                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_90',        -- C Name
     'Write Protect Program Flash Page 90',-- Description
     127,              -- Bit Mask
     90                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_91',        -- C Name
     'Write Protect Program Flash Page 91',-- Description
     127,              -- Bit Mask
     91                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_92',        -- C Name
     'Write Protect Program Flash Page 92',-- Description
     127,              -- Bit Mask
     92                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_93',        -- C Name
     'Write Protect Program Flash Page 93',-- Description
     127,              -- Bit Mask
     93                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_94',        -- C Name
     'Write Protect Program Flash Page 94',-- Description
     127,              -- Bit Mask
     94                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_95',        -- C Name
     'Write Protect Program Flash Page 95',-- Description
     127,              -- Bit Mask
     95                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_96',        -- C Name
     'Write Protect Program Flash Page 96',-- Description
     127,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_97',        -- C Name
     'Write Protect Program Flash Page 97',-- Description
     127,              -- Bit Mask
     97                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_98',        -- C Name
     'Write Protect Program Flash Page 98',-- Description
     127,              -- Bit Mask
     98                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_99',        -- C Name
     'Write Protect Program Flash Page 99',-- Description
     127,              -- Bit Mask
     99                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_100',       -- C Name
     'Write Protect Program Flash Page 100',-- Description
     127,              -- Bit Mask
     100               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_101',       -- C Name
     'Write Protect Program Flash Page 101',-- Description
     127,              -- Bit Mask
     101               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_102',       -- C Name
     'Write Protect Program Flash Page 102',-- Description
     127,              -- Bit Mask
     102               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_103',       -- C Name
     'Write Protect Program Flash Page 103',-- Description
     127,              -- Bit Mask
     103               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_104',       -- C Name
     'Write Protect Program Flash Page 104',-- Description
     127,              -- Bit Mask
     104               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_105',       -- C Name
     'Write Protect Program Flash Page 105',-- Description
     127,              -- Bit Mask
     105               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_106',       -- C Name
     'Write Protect Program Flash Page 106',-- Description
     127,              -- Bit Mask
     106               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_107',       -- C Name
     'Write Protect Program Flash Page 107',-- Description
     127,              -- Bit Mask
     107               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_108',       -- C Name
     'Write Protect Program Flash Page 108',-- Description
     127,              -- Bit Mask
     108               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_109',       -- C Name
     'Write Protect Program Flash Page 109',-- Description
     127,              -- Bit Mask
     109               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_110',       -- C Name
     'Write Protect Program Flash Page 110',-- Description
     127,              -- Bit Mask
     110               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_111',       -- C Name
     'Write Protect Program Flash Page 111',-- Description
     127,              -- Bit Mask
     111               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_112',       -- C Name
     'Write Protect Program Flash Page 112',-- Description
     127,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_113',       -- C Name
     'Write Protect Program Flash Page 113',-- Description
     127,              -- Bit Mask
     113               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_114',       -- C Name
     'Write Protect Program Flash Page 114',-- Description
     127,              -- Bit Mask
     114               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_115',       -- C Name
     'Write Protect Program Flash Page 115',-- Description
     127,              -- Bit Mask
     115               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_116',       -- C Name
     'Write Protect Program Flash Page 116',-- Description
     127,              -- Bit Mask
     116               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_117',       -- C Name
     'Write Protect Program Flash Page 117',-- Description
     127,              -- Bit Mask
     117               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_118',       -- C Name
     'Write Protect Program Flash Page 118',-- Description
     127,              -- Bit Mask
     118               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_119',       -- C Name
     'Write Protect Program Flash Page 119',-- Description
     127,              -- Bit Mask
     119               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_120',       -- C Name
     'Write Protect Program Flash Page 120',-- Description
     127,              -- Bit Mask
     120               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_121',       -- C Name
     'Write Protect Program Flash Page 121',-- Description
     127,              -- Bit Mask
     121               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_122',       -- C Name
     'Write Protect Program Flash Page 122',-- Description
     127,              -- Bit Mask
     122               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_123',       -- C Name
     'Write Protect Program Flash Page 123',-- Description
     127,              -- Bit Mask
     123               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_124',       -- C Name
     'Write Protect Program Flash Page 124',-- Description
     127,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_125',       -- C Name
     'Write Protect Program Flash Page 125',-- Description
     127,              -- Bit Mask
     125               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_126',       -- C Name
     'Write Protect Program Flash Page 126',-- Description
     127,              -- Bit Mask
     126               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_127',       -- C Name
     'Write Protect Program Flash Page 127',-- Description
     127,              -- Bit Mask
     127               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     131071,           -- Address
     243,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     707,              -- Device ID
     4,                -- Family ID
     'PIC18F27J53',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     251,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     131070,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     127,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     127,              -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     127,              -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     127,              -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     127,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     127,              -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     127,              -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     127,              -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     127,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     127,              -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     127,              -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     127,              -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     127,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     127,              -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     127,              -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     127,              -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     127,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     127,              -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     127,              -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     127,              -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     127,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     127,              -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     127,              -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     127,              -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     127,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     127,              -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     127,              -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     127,              -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     127,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     127,              -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     127,              -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     127,              -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     127,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     127,              -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     127,              -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     127,              -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     127,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     127,              -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     127,              -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     127,              -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     127,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     127,              -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     127,              -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     127,              -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     127,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     127,              -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     127,              -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     127,              -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     127,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     127,              -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     127,              -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     127,              -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     127,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     127,              -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     127,              -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     127,              -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     127,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     127,              -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     127,              -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     127,              -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     127,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     127,              -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     127,              -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     127,              -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_64',        -- C Name
     'Write Protect Program Flash Page 64',-- Description
     127,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_65',        -- C Name
     'Write Protect Program Flash Page 65',-- Description
     127,              -- Bit Mask
     65                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_66',        -- C Name
     'Write Protect Program Flash Page 66',-- Description
     127,              -- Bit Mask
     66                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_67',        -- C Name
     'Write Protect Program Flash Page 67',-- Description
     127,              -- Bit Mask
     67                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_68',        -- C Name
     'Write Protect Program Flash Page 68',-- Description
     127,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_69',        -- C Name
     'Write Protect Program Flash Page 69',-- Description
     127,              -- Bit Mask
     69                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_70',        -- C Name
     'Write Protect Program Flash Page 70',-- Description
     127,              -- Bit Mask
     70                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_71',        -- C Name
     'Write Protect Program Flash Page 71',-- Description
     127,              -- Bit Mask
     71                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_72',        -- C Name
     'Write Protect Program Flash Page 72',-- Description
     127,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_73',        -- C Name
     'Write Protect Program Flash Page 73',-- Description
     127,              -- Bit Mask
     73                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_74',        -- C Name
     'Write Protect Program Flash Page 74',-- Description
     127,              -- Bit Mask
     74                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_75',        -- C Name
     'Write Protect Program Flash Page 75',-- Description
     127,              -- Bit Mask
     75                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_76',        -- C Name
     'Write Protect Program Flash Page 76',-- Description
     127,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_77',        -- C Name
     'Write Protect Program Flash Page 77',-- Description
     127,              -- Bit Mask
     77                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_78',        -- C Name
     'Write Protect Program Flash Page 78',-- Description
     127,              -- Bit Mask
     78                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_79',        -- C Name
     'Write Protect Program Flash Page 79',-- Description
     127,              -- Bit Mask
     79                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_80',        -- C Name
     'Write Protect Program Flash Page 80',-- Description
     127,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_81',        -- C Name
     'Write Protect Program Flash Page 81',-- Description
     127,              -- Bit Mask
     81                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_82',        -- C Name
     'Write Protect Program Flash Page 82',-- Description
     127,              -- Bit Mask
     82                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_83',        -- C Name
     'Write Protect Program Flash Page 83',-- Description
     127,              -- Bit Mask
     83                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_84',        -- C Name
     'Write Protect Program Flash Page 84',-- Description
     127,              -- Bit Mask
     84                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_85',        -- C Name
     'Write Protect Program Flash Page 85',-- Description
     127,              -- Bit Mask
     85                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_86',        -- C Name
     'Write Protect Program Flash Page 86',-- Description
     127,              -- Bit Mask
     86                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_87',        -- C Name
     'Write Protect Program Flash Page 87',-- Description
     127,              -- Bit Mask
     87                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_88',        -- C Name
     'Write Protect Program Flash Page 88',-- Description
     127,              -- Bit Mask
     88                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_89',        -- C Name
     'Write Protect Program Flash Page 89',-- Description
     127,              -- Bit Mask
     89                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_90',        -- C Name
     'Write Protect Program Flash Page 90',-- Description
     127,              -- Bit Mask
     90                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_91',        -- C Name
     'Write Protect Program Flash Page 91',-- Description
     127,              -- Bit Mask
     91                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_92',        -- C Name
     'Write Protect Program Flash Page 92',-- Description
     127,              -- Bit Mask
     92                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_93',        -- C Name
     'Write Protect Program Flash Page 93',-- Description
     127,              -- Bit Mask
     93                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_94',        -- C Name
     'Write Protect Program Flash Page 94',-- Description
     127,              -- Bit Mask
     94                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_95',        -- C Name
     'Write Protect Program Flash Page 95',-- Description
     127,              -- Bit Mask
     95                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_96',        -- C Name
     'Write Protect Program Flash Page 96',-- Description
     127,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_97',        -- C Name
     'Write Protect Program Flash Page 97',-- Description
     127,              -- Bit Mask
     97                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_98',        -- C Name
     'Write Protect Program Flash Page 98',-- Description
     127,              -- Bit Mask
     98                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_99',        -- C Name
     'Write Protect Program Flash Page 99',-- Description
     127,              -- Bit Mask
     99                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_100',       -- C Name
     'Write Protect Program Flash Page 100',-- Description
     127,              -- Bit Mask
     100               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_101',       -- C Name
     'Write Protect Program Flash Page 101',-- Description
     127,              -- Bit Mask
     101               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_102',       -- C Name
     'Write Protect Program Flash Page 102',-- Description
     127,              -- Bit Mask
     102               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_103',       -- C Name
     'Write Protect Program Flash Page 103',-- Description
     127,              -- Bit Mask
     103               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_104',       -- C Name
     'Write Protect Program Flash Page 104',-- Description
     127,              -- Bit Mask
     104               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_105',       -- C Name
     'Write Protect Program Flash Page 105',-- Description
     127,              -- Bit Mask
     105               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_106',       -- C Name
     'Write Protect Program Flash Page 106',-- Description
     127,              -- Bit Mask
     106               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_107',       -- C Name
     'Write Protect Program Flash Page 107',-- Description
     127,              -- Bit Mask
     107               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_108',       -- C Name
     'Write Protect Program Flash Page 108',-- Description
     127,              -- Bit Mask
     108               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_109',       -- C Name
     'Write Protect Program Flash Page 109',-- Description
     127,              -- Bit Mask
     109               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_110',       -- C Name
     'Write Protect Program Flash Page 110',-- Description
     127,              -- Bit Mask
     110               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_111',       -- C Name
     'Write Protect Program Flash Page 111',-- Description
     127,              -- Bit Mask
     111               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_112',       -- C Name
     'Write Protect Program Flash Page 112',-- Description
     127,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_113',       -- C Name
     'Write Protect Program Flash Page 113',-- Description
     127,              -- Bit Mask
     113               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_114',       -- C Name
     'Write Protect Program Flash Page 114',-- Description
     127,              -- Bit Mask
     114               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_115',       -- C Name
     'Write Protect Program Flash Page 115',-- Description
     127,              -- Bit Mask
     115               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_116',       -- C Name
     'Write Protect Program Flash Page 116',-- Description
     127,              -- Bit Mask
     116               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_117',       -- C Name
     'Write Protect Program Flash Page 117',-- Description
     127,              -- Bit Mask
     117               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_118',       -- C Name
     'Write Protect Program Flash Page 118',-- Description
     127,              -- Bit Mask
     118               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_119',       -- C Name
     'Write Protect Program Flash Page 119',-- Description
     127,              -- Bit Mask
     119               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_120',       -- C Name
     'Write Protect Program Flash Page 120',-- Description
     127,              -- Bit Mask
     120               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_121',       -- C Name
     'Write Protect Program Flash Page 121',-- Description
     127,              -- Bit Mask
     121               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_122',       -- C Name
     'Write Protect Program Flash Page 122',-- Description
     127,              -- Bit Mask
     122               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_123',       -- C Name
     'Write Protect Program Flash Page 123',-- Description
     127,              -- Bit Mask
     123               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_124',       -- C Name
     'Write Protect Program Flash Page 124',-- Description
     127,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_125',       -- C Name
     'Write Protect Program Flash Page 125',-- Description
     127,              -- Bit Mask
     125               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_126',       -- C Name
     'Write Protect Program Flash Page 126',-- Description
     127,              -- Bit Mask
     126               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_127',       -- C Name
     'Write Protect Program Flash Page 127',-- Description
     127,              -- Bit Mask
     127               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     131071,           -- Address
     251,              -- Default Value
     11                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LS48MHZ',        -- C Name
     'Low Speed USB mode with 48 MHz system clock bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS24X4',        -- C Name
     'System clock at 24 MHz USB CLKEN divide-by is set to 4',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS48X8',        -- C Name
     'System clock at 48 MHz USB CLKEN divide-by is set to 8',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);


insert into DEVICES values (
     null,
     262,              -- Device ID
     4,                -- Family ID
     'PIC18F43K20',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '18',             -- C Name
     'VBOR set to 1.8 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     696,              -- Device ID
     4,                -- Family ID
     'PIC18F43K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE0',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RE0',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTD2',         -- C Name
     'P2B is on RD2',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     233,              -- Device ID
     4,                -- Family ID
     'PIC18F44J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16382,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     623,              -- Device ID
     4,                -- Family ID
     'PIC18F44J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16384,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     16382,            -- Address
     207,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     16383,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     611,              -- Device ID
     4,                -- Family ID
     'PIC18F44J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16384,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     16382,            -- Address
     207,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     16383,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     260,              -- Device ID
     4,                -- Family ID
     'PIC18F44K20',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '18',             -- C Name
     'VBOR set to 1.8 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     688,              -- Device ID
     4,                -- Family ID
     'PIC18F44K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE0',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RE0',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTD2',         -- C Name
     'P2B is on RD2',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     225,              -- Device ID
     4,                -- Family ID
     'PIC18F45J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     624,              -- Device ID
     4,                -- Family ID
     'PIC18F45J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32768,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     32766,            -- Address
     223,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     31,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     31,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     31,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     31,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     31,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     31,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     31,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     31,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     31,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     31,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     31,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     31,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     31,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     31,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     31,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     31,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     31,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     31,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     31,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     31,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     31,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     31,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     31,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     31,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     31,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     31,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     31,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     31,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     31,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     31,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     31,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     31,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     32767,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     612,              -- Device ID
     4,                -- Family ID
     'PIC18F45J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32768,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     32766,            -- Address
     223,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     31,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     31,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     31,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     31,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     31,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     31,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     31,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     31,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     31,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     31,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     31,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     31,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     31,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     31,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     31,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     31,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     31,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     31,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     31,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     31,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     31,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     31,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     31,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     31,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     31,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     31,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     31,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     31,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     31,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     31,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     31,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     31,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     32767,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     258,              -- Device ID
     4,                -- Family ID
     'PIC18F45K20',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '18',             -- C Name
     'VBOR set to 1.8 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     680,              -- Device ID
     4,                -- Family ID
     'PIC18F45K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE0',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RE0',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTD2',         -- C Name
     'P2B is on RD2',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     779,              -- Device ID
     4,                -- Family ID
     'PIC18F45K80',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECAN TX and RX pins are located on RC6 and RC7, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     625,              -- Device ID
     4,                -- Family ID
     'PIC18F46J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     717,              -- Device ID
     4,                -- Family ID
     'PIC18F46J13',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     '96MHz PLL Prescaler Selection (PLLSEL=0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLSEL',         -- C Name
     'PLL Selection Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL96',          -- C Name
     'Selects 96MHz PLL',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL4X',          -- C Name
     'Selects 4x PLL', -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     243,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     613,              -- Device ID
     4,                -- Family ID
     'PIC18F46J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     709,              -- Device ID
     4,                -- Family ID
     'PIC18F46J53',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     251,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     251,              -- Default Value
     11                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LS48MHZ',        -- C Name
     'Low Speed USB mode with 48 MHz system clock bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS24X4',        -- C Name
     'System clock at 24 MHz USB CLKEN divide-by is set to 4',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS48X8',        -- C Name
     'System clock at 48 MHz USB CLKEN divide-by is set to 8',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);


insert into DEVICES values (
     null,
     256,              -- Device ID
     4,                -- Family ID
     'PIC18F46K20',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '18',             -- C Name
     'VBOR set to 1.8 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000h-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000h-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     672,              -- Device ID
     4,                -- Family ID
     'PIC18F46K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3896              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE0',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RE0',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTD2',         -- C Name
     'P2B is on RD2',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     776,              -- Device ID
     4,                -- Family ID
     'PIC18F46K80',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECAN TX and RX pins are located on RC6 and RC7, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     719,              -- Device ID
     4,                -- Family ID
     'PIC18F47J13',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     '96MHz PLL Prescaler Selection (PLLSEL=0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLSEL',         -- C Name
     'PLL Selection Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL96',          -- C Name
     'Selects 96MHz PLL',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL4X',          -- C Name
     'Selects 4x PLL', -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     131070,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     127,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     127,              -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     127,              -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     127,              -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     127,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     127,              -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     127,              -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     127,              -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     127,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     127,              -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     127,              -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     127,              -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     127,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     127,              -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     127,              -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     127,              -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     127,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     127,              -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     127,              -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     127,              -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     127,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     127,              -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     127,              -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     127,              -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     127,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     127,              -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     127,              -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     127,              -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     127,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     127,              -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     127,              -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     127,              -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     127,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     127,              -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     127,              -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     127,              -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     127,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     127,              -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     127,              -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     127,              -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     127,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     127,              -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     127,              -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     127,              -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     127,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     127,              -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     127,              -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     127,              -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     127,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     127,              -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     127,              -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     127,              -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     127,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     127,              -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     127,              -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     127,              -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     127,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     127,              -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     127,              -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     127,              -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     127,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     127,              -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     127,              -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     127,              -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_64',        -- C Name
     'Write Protect Program Flash Page 64',-- Description
     127,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_65',        -- C Name
     'Write Protect Program Flash Page 65',-- Description
     127,              -- Bit Mask
     65                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_66',        -- C Name
     'Write Protect Program Flash Page 66',-- Description
     127,              -- Bit Mask
     66                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_67',        -- C Name
     'Write Protect Program Flash Page 67',-- Description
     127,              -- Bit Mask
     67                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_68',        -- C Name
     'Write Protect Program Flash Page 68',-- Description
     127,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_69',        -- C Name
     'Write Protect Program Flash Page 69',-- Description
     127,              -- Bit Mask
     69                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_70',        -- C Name
     'Write Protect Program Flash Page 70',-- Description
     127,              -- Bit Mask
     70                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_71',        -- C Name
     'Write Protect Program Flash Page 71',-- Description
     127,              -- Bit Mask
     71                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_72',        -- C Name
     'Write Protect Program Flash Page 72',-- Description
     127,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_73',        -- C Name
     'Write Protect Program Flash Page 73',-- Description
     127,              -- Bit Mask
     73                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_74',        -- C Name
     'Write Protect Program Flash Page 74',-- Description
     127,              -- Bit Mask
     74                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_75',        -- C Name
     'Write Protect Program Flash Page 75',-- Description
     127,              -- Bit Mask
     75                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_76',        -- C Name
     'Write Protect Program Flash Page 76',-- Description
     127,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_77',        -- C Name
     'Write Protect Program Flash Page 77',-- Description
     127,              -- Bit Mask
     77                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_78',        -- C Name
     'Write Protect Program Flash Page 78',-- Description
     127,              -- Bit Mask
     78                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_79',        -- C Name
     'Write Protect Program Flash Page 79',-- Description
     127,              -- Bit Mask
     79                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_80',        -- C Name
     'Write Protect Program Flash Page 80',-- Description
     127,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_81',        -- C Name
     'Write Protect Program Flash Page 81',-- Description
     127,              -- Bit Mask
     81                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_82',        -- C Name
     'Write Protect Program Flash Page 82',-- Description
     127,              -- Bit Mask
     82                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_83',        -- C Name
     'Write Protect Program Flash Page 83',-- Description
     127,              -- Bit Mask
     83                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_84',        -- C Name
     'Write Protect Program Flash Page 84',-- Description
     127,              -- Bit Mask
     84                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_85',        -- C Name
     'Write Protect Program Flash Page 85',-- Description
     127,              -- Bit Mask
     85                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_86',        -- C Name
     'Write Protect Program Flash Page 86',-- Description
     127,              -- Bit Mask
     86                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_87',        -- C Name
     'Write Protect Program Flash Page 87',-- Description
     127,              -- Bit Mask
     87                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_88',        -- C Name
     'Write Protect Program Flash Page 88',-- Description
     127,              -- Bit Mask
     88                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_89',        -- C Name
     'Write Protect Program Flash Page 89',-- Description
     127,              -- Bit Mask
     89                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_90',        -- C Name
     'Write Protect Program Flash Page 90',-- Description
     127,              -- Bit Mask
     90                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_91',        -- C Name
     'Write Protect Program Flash Page 91',-- Description
     127,              -- Bit Mask
     91                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_92',        -- C Name
     'Write Protect Program Flash Page 92',-- Description
     127,              -- Bit Mask
     92                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_93',        -- C Name
     'Write Protect Program Flash Page 93',-- Description
     127,              -- Bit Mask
     93                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_94',        -- C Name
     'Write Protect Program Flash Page 94',-- Description
     127,              -- Bit Mask
     94                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_95',        -- C Name
     'Write Protect Program Flash Page 95',-- Description
     127,              -- Bit Mask
     95                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_96',        -- C Name
     'Write Protect Program Flash Page 96',-- Description
     127,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_97',        -- C Name
     'Write Protect Program Flash Page 97',-- Description
     127,              -- Bit Mask
     97                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_98',        -- C Name
     'Write Protect Program Flash Page 98',-- Description
     127,              -- Bit Mask
     98                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_99',        -- C Name
     'Write Protect Program Flash Page 99',-- Description
     127,              -- Bit Mask
     99                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_100',       -- C Name
     'Write Protect Program Flash Page 100',-- Description
     127,              -- Bit Mask
     100               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_101',       -- C Name
     'Write Protect Program Flash Page 101',-- Description
     127,              -- Bit Mask
     101               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_102',       -- C Name
     'Write Protect Program Flash Page 102',-- Description
     127,              -- Bit Mask
     102               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_103',       -- C Name
     'Write Protect Program Flash Page 103',-- Description
     127,              -- Bit Mask
     103               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_104',       -- C Name
     'Write Protect Program Flash Page 104',-- Description
     127,              -- Bit Mask
     104               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_105',       -- C Name
     'Write Protect Program Flash Page 105',-- Description
     127,              -- Bit Mask
     105               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_106',       -- C Name
     'Write Protect Program Flash Page 106',-- Description
     127,              -- Bit Mask
     106               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_107',       -- C Name
     'Write Protect Program Flash Page 107',-- Description
     127,              -- Bit Mask
     107               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_108',       -- C Name
     'Write Protect Program Flash Page 108',-- Description
     127,              -- Bit Mask
     108               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_109',       -- C Name
     'Write Protect Program Flash Page 109',-- Description
     127,              -- Bit Mask
     109               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_110',       -- C Name
     'Write Protect Program Flash Page 110',-- Description
     127,              -- Bit Mask
     110               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_111',       -- C Name
     'Write Protect Program Flash Page 111',-- Description
     127,              -- Bit Mask
     111               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_112',       -- C Name
     'Write Protect Program Flash Page 112',-- Description
     127,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_113',       -- C Name
     'Write Protect Program Flash Page 113',-- Description
     127,              -- Bit Mask
     113               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_114',       -- C Name
     'Write Protect Program Flash Page 114',-- Description
     127,              -- Bit Mask
     114               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_115',       -- C Name
     'Write Protect Program Flash Page 115',-- Description
     127,              -- Bit Mask
     115               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_116',       -- C Name
     'Write Protect Program Flash Page 116',-- Description
     127,              -- Bit Mask
     116               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_117',       -- C Name
     'Write Protect Program Flash Page 117',-- Description
     127,              -- Bit Mask
     117               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_118',       -- C Name
     'Write Protect Program Flash Page 118',-- Description
     127,              -- Bit Mask
     118               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_119',       -- C Name
     'Write Protect Program Flash Page 119',-- Description
     127,              -- Bit Mask
     119               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_120',       -- C Name
     'Write Protect Program Flash Page 120',-- Description
     127,              -- Bit Mask
     120               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_121',       -- C Name
     'Write Protect Program Flash Page 121',-- Description
     127,              -- Bit Mask
     121               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_122',       -- C Name
     'Write Protect Program Flash Page 122',-- Description
     127,              -- Bit Mask
     122               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_123',       -- C Name
     'Write Protect Program Flash Page 123',-- Description
     127,              -- Bit Mask
     123               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_124',       -- C Name
     'Write Protect Program Flash Page 124',-- Description
     127,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_125',       -- C Name
     'Write Protect Program Flash Page 125',-- Description
     127,              -- Bit Mask
     125               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_126',       -- C Name
     'Write Protect Program Flash Page 126',-- Description
     127,              -- Bit Mask
     126               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_127',       -- C Name
     'Write Protect Program Flash Page 127',-- Description
     127,              -- Bit Mask
     127               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     131071,           -- Address
     243,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     711,              -- Device ID
     4,                -- Family ID
     'PIC18F47J53',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     251,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     131070,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     127,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     127,              -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     127,              -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     127,              -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     127,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     127,              -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     127,              -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     127,              -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     127,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     127,              -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     127,              -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     127,              -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     127,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     127,              -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     127,              -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     127,              -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     127,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     127,              -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     127,              -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     127,              -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     127,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     127,              -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     127,              -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     127,              -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     127,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     127,              -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     127,              -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     127,              -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     127,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     127,              -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     127,              -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     127,              -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     127,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     127,              -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     127,              -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     127,              -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     127,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     127,              -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     127,              -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     127,              -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     127,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     127,              -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     127,              -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     127,              -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     127,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     127,              -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     127,              -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     127,              -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     127,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     127,              -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     127,              -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     127,              -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     127,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     127,              -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     127,              -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     127,              -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     127,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     127,              -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     127,              -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     127,              -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     127,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     127,              -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     127,              -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     127,              -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_64',        -- C Name
     'Write Protect Program Flash Page 64',-- Description
     127,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_65',        -- C Name
     'Write Protect Program Flash Page 65',-- Description
     127,              -- Bit Mask
     65                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_66',        -- C Name
     'Write Protect Program Flash Page 66',-- Description
     127,              -- Bit Mask
     66                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_67',        -- C Name
     'Write Protect Program Flash Page 67',-- Description
     127,              -- Bit Mask
     67                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_68',        -- C Name
     'Write Protect Program Flash Page 68',-- Description
     127,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_69',        -- C Name
     'Write Protect Program Flash Page 69',-- Description
     127,              -- Bit Mask
     69                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_70',        -- C Name
     'Write Protect Program Flash Page 70',-- Description
     127,              -- Bit Mask
     70                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_71',        -- C Name
     'Write Protect Program Flash Page 71',-- Description
     127,              -- Bit Mask
     71                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_72',        -- C Name
     'Write Protect Program Flash Page 72',-- Description
     127,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_73',        -- C Name
     'Write Protect Program Flash Page 73',-- Description
     127,              -- Bit Mask
     73                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_74',        -- C Name
     'Write Protect Program Flash Page 74',-- Description
     127,              -- Bit Mask
     74                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_75',        -- C Name
     'Write Protect Program Flash Page 75',-- Description
     127,              -- Bit Mask
     75                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_76',        -- C Name
     'Write Protect Program Flash Page 76',-- Description
     127,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_77',        -- C Name
     'Write Protect Program Flash Page 77',-- Description
     127,              -- Bit Mask
     77                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_78',        -- C Name
     'Write Protect Program Flash Page 78',-- Description
     127,              -- Bit Mask
     78                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_79',        -- C Name
     'Write Protect Program Flash Page 79',-- Description
     127,              -- Bit Mask
     79                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_80',        -- C Name
     'Write Protect Program Flash Page 80',-- Description
     127,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_81',        -- C Name
     'Write Protect Program Flash Page 81',-- Description
     127,              -- Bit Mask
     81                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_82',        -- C Name
     'Write Protect Program Flash Page 82',-- Description
     127,              -- Bit Mask
     82                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_83',        -- C Name
     'Write Protect Program Flash Page 83',-- Description
     127,              -- Bit Mask
     83                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_84',        -- C Name
     'Write Protect Program Flash Page 84',-- Description
     127,              -- Bit Mask
     84                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_85',        -- C Name
     'Write Protect Program Flash Page 85',-- Description
     127,              -- Bit Mask
     85                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_86',        -- C Name
     'Write Protect Program Flash Page 86',-- Description
     127,              -- Bit Mask
     86                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_87',        -- C Name
     'Write Protect Program Flash Page 87',-- Description
     127,              -- Bit Mask
     87                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_88',        -- C Name
     'Write Protect Program Flash Page 88',-- Description
     127,              -- Bit Mask
     88                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_89',        -- C Name
     'Write Protect Program Flash Page 89',-- Description
     127,              -- Bit Mask
     89                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_90',        -- C Name
     'Write Protect Program Flash Page 90',-- Description
     127,              -- Bit Mask
     90                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_91',        -- C Name
     'Write Protect Program Flash Page 91',-- Description
     127,              -- Bit Mask
     91                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_92',        -- C Name
     'Write Protect Program Flash Page 92',-- Description
     127,              -- Bit Mask
     92                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_93',        -- C Name
     'Write Protect Program Flash Page 93',-- Description
     127,              -- Bit Mask
     93                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_94',        -- C Name
     'Write Protect Program Flash Page 94',-- Description
     127,              -- Bit Mask
     94                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_95',        -- C Name
     'Write Protect Program Flash Page 95',-- Description
     127,              -- Bit Mask
     95                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_96',        -- C Name
     'Write Protect Program Flash Page 96',-- Description
     127,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_97',        -- C Name
     'Write Protect Program Flash Page 97',-- Description
     127,              -- Bit Mask
     97                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_98',        -- C Name
     'Write Protect Program Flash Page 98',-- Description
     127,              -- Bit Mask
     98                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_99',        -- C Name
     'Write Protect Program Flash Page 99',-- Description
     127,              -- Bit Mask
     99                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_100',       -- C Name
     'Write Protect Program Flash Page 100',-- Description
     127,              -- Bit Mask
     100               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_101',       -- C Name
     'Write Protect Program Flash Page 101',-- Description
     127,              -- Bit Mask
     101               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_102',       -- C Name
     'Write Protect Program Flash Page 102',-- Description
     127,              -- Bit Mask
     102               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_103',       -- C Name
     'Write Protect Program Flash Page 103',-- Description
     127,              -- Bit Mask
     103               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_104',       -- C Name
     'Write Protect Program Flash Page 104',-- Description
     127,              -- Bit Mask
     104               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_105',       -- C Name
     'Write Protect Program Flash Page 105',-- Description
     127,              -- Bit Mask
     105               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_106',       -- C Name
     'Write Protect Program Flash Page 106',-- Description
     127,              -- Bit Mask
     106               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_107',       -- C Name
     'Write Protect Program Flash Page 107',-- Description
     127,              -- Bit Mask
     107               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_108',       -- C Name
     'Write Protect Program Flash Page 108',-- Description
     127,              -- Bit Mask
     108               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_109',       -- C Name
     'Write Protect Program Flash Page 109',-- Description
     127,              -- Bit Mask
     109               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_110',       -- C Name
     'Write Protect Program Flash Page 110',-- Description
     127,              -- Bit Mask
     110               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_111',       -- C Name
     'Write Protect Program Flash Page 111',-- Description
     127,              -- Bit Mask
     111               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_112',       -- C Name
     'Write Protect Program Flash Page 112',-- Description
     127,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_113',       -- C Name
     'Write Protect Program Flash Page 113',-- Description
     127,              -- Bit Mask
     113               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_114',       -- C Name
     'Write Protect Program Flash Page 114',-- Description
     127,              -- Bit Mask
     114               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_115',       -- C Name
     'Write Protect Program Flash Page 115',-- Description
     127,              -- Bit Mask
     115               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_116',       -- C Name
     'Write Protect Program Flash Page 116',-- Description
     127,              -- Bit Mask
     116               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_117',       -- C Name
     'Write Protect Program Flash Page 117',-- Description
     127,              -- Bit Mask
     117               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_118',       -- C Name
     'Write Protect Program Flash Page 118',-- Description
     127,              -- Bit Mask
     118               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_119',       -- C Name
     'Write Protect Program Flash Page 119',-- Description
     127,              -- Bit Mask
     119               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_120',       -- C Name
     'Write Protect Program Flash Page 120',-- Description
     127,              -- Bit Mask
     120               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_121',       -- C Name
     'Write Protect Program Flash Page 121',-- Description
     127,              -- Bit Mask
     121               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_122',       -- C Name
     'Write Protect Program Flash Page 122',-- Description
     127,              -- Bit Mask
     122               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_123',       -- C Name
     'Write Protect Program Flash Page 123',-- Description
     127,              -- Bit Mask
     123               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_124',       -- C Name
     'Write Protect Program Flash Page 124',-- Description
     127,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_125',       -- C Name
     'Write Protect Program Flash Page 125',-- Description
     127,              -- Bit Mask
     125               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_126',       -- C Name
     'Write Protect Program Flash Page 126',-- Description
     127,              -- Bit Mask
     126               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_127',       -- C Name
     'Write Protect Program Flash Page 127',-- Description
     127,              -- Bit Mask
     127               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     131071,           -- Address
     251,              -- Default Value
     11                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LS48MHZ',        -- C Name
     'Low Speed USB mode with 48 MHz system clock bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS24X4',        -- C Name
     'System clock at 24 MHz USB CLKEN divide-by is set to 4',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS48X8',        -- C Name
     'System clock at 48 MHz USB CLKEN divide-by is set to 8',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);


insert into DEVICES values (
     null,
     456,              -- Device ID
     4,                -- Family ID
     'PIC18F63J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     8184,             -- Start of Config Bits
     8190,             -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     8184,             -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     8185,             -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     8186,             -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     8187,             -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     8188,             -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     8189,             -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     448,              -- Device ID
     4,                -- Family ID
     'PIC18F63J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     8184,             -- Start of Config Bits
     8190,             -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     8184,             -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     8185,             -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     8186,             -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     8187,             -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     8188,             -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     8189,             -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     457,              -- Device ID
     4,                -- Family ID
     'PIC18F64J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16382,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     449,              -- Device ID
     4,                -- Family ID
     'PIC18F64J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16382,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     169,              -- Device ID
     4,                -- Family ID
     'PIC18F65J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     243,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     459,              -- Device ID
     4,                -- Family ID
     'PIC18F65J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     170,              -- Device ID
     4,                -- Family ID
     'PIC18F65J15',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     49144,            -- Start of Config Bits
     49150,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     49144,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     49145,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     49146,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     49147,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     49148,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     49149,            -- Address
     243,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     520,              -- Device ID
     4,                -- Family ID
     'PIC18F65J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     247,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL, CLKO on RA6, ECPLL used by USB',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with CLKO on RA6, EC used by USB',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled, HSPLL used by USB',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator, HS used by USB',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSC, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     451,              -- Device ID
     4,                -- Family ID
     'PIC18F65J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     255,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     664,              -- Device ID
     4,                -- Family ID
     'PIC18F65K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-017FF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 01800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-017FF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 01800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     778,              -- Device ID
     4,                -- Family ID
     'PIC18F65K80',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     143,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECAN TX and RX pins are located on RE5 and RE4, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T0CKMX',         -- C Name
     'Timer0 Clock Input Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'Timer0 gets its clock input from the RB5/T0CKI pin on 64-pin packages',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTG',          -- C Name
     'Timer0 gets its clock input from the RG4/T0CKI pin on 64-pin packages',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CKMX',         -- C Name
     'Timer3 Clock Input Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTG',          -- C Name
     'Timer3 gets its clock input from the RG2/T3CKI pin on 64-pin packages',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'Timer3 gets its clock input from the RB5/T3CKI pin on 64-pin packages',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     658,              -- Device ID
     4,                -- Family ID
     'PIC18F65K90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-017FF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 01800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-017FF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 01800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     171,              -- Device ID
     4,                -- Family ID
     'PIC18F66J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     243,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     546,              -- Device ID
     4,                -- Family ID
     'PIC18F66J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator, PLL enabled, CLKO on RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator, CLKO  on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     172,              -- Device ID
     4,                -- Family ID
     'PIC18F66J15',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     243,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     547,              -- Device ID
     4,                -- Family ID
     'PIC18F66J16',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     225,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     244,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator, PLL enabled, CLKO on RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator, CLKO  on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     522,              -- Device ID
     4,                -- Family ID
     'PIC18F66J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL, CLKO on RA6, ECPLL used by USB',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with CLKO on RA6, EC used by USB',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled, HSPLL used by USB',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator, HS used by USB',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSC, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     523,              -- Device ID
     4,                -- Family ID
     'PIC18F66J55',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     247,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL, CLKO on RA6, ECPLL used by USB',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with CLKO on RA6, EC used by USB',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled, HSPLL used by USB',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator, HS used by USB',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSC, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     249,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     192,              -- Device ID
     4,                -- Family ID
     'PIC18F66J60',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     248,              -- Device ID
     4,                -- Family ID
     'PIC18F66J65',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     640,              -- Device ID
     4,                -- Family ID
     'PIC18F66J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     2,                -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7',            -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     642,              -- Device ID
     4,                -- Family ID
     'PIC18F66J93',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     2,                -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7',            -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     662,              -- Device ID
     4,                -- Family ID
     'PIC18F66K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3862              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     775,              -- Device ID
     4,                -- Family ID
     'PIC18F66K80',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     143,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECAN TX and RX pins are located on RE5 and RE4, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T0CKMX',         -- C Name
     'Timer0 Clock Input Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'Timer0 gets its clock input from the RB5/T0CKI pin on 64-pin packages',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTG',          -- C Name
     'Timer0 gets its clock input from the RG4/T0CKI pin on 64-pin packages',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CKMX',         -- C Name
     'Timer3 Clock Input Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTG',          -- C Name
     'Timer3 gets its clock input from the RG2/T3CKI pin on 64-pin packages',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'Timer3 gets its clock input from the RB5/T3CKI pin on 64-pin packages',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     656,              -- Device ID
     4,                -- Family ID
     'PIC18F66K90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3828              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     173,              -- Device ID
     4,                -- Family ID
     'PIC18F67J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     243,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     548,              -- Device ID
     4,                -- Family ID
     'PIC18F67J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator, PLL enabled, CLKO on RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator, CLKO  on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     524,              -- Device ID
     4,                -- Family ID
     'PIC18F67J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     247,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL, CLKO on RA6, ECPLL used by USB',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with CLKO on RA6, EC used by USB',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled, HSPLL used by USB',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator, HS used by USB',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSC, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     249,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     249,              -- Device ID
     4,                -- Family ID
     'PIC18F67J60',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     641,              -- Device ID
     4,                -- Family ID
     'PIC18F67J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     2,                -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7',            -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     643,              -- Device ID
     4,                -- Family ID
     'PIC18F67J93',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     2,                -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7',            -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     652,              -- Device ID
     4,                -- Family ID
     'PIC18F67K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     128,              -- Write FLASH Block Size
     128,              -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3862              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Table Write Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Table Write Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Table Write Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Table Write Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT4',          -- C Name
     'Table Read Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT5',          -- C Name
     'Table Read Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT6',          -- C Name
     'Table Read Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT7',          -- C Name
     'Table Read Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     648,              -- Device ID
     4,                -- Family ID
     'PIC18F67K90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     128,              -- Write FLASH Block Size
     128,              -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3828              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Table Write Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Table Write Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Table Write Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Table Write Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT4',          -- C Name
     'Table Read Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT5',          -- C Name
     'Table Read Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT6',          -- C Name
     'Table Read Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT7',          -- C Name
     'Table Read Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     460,              -- Device ID
     4,                -- Family ID
     'PIC18F83J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     8184,             -- Start of Config Bits
     8190,             -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     8184,             -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     8185,             -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     8186,             -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     8187,             -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     8188,             -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode, 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode, 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode, 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     8189,             -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     452,              -- Device ID
     4,                -- Family ID
     'PIC18F83J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     8184,             -- Start of Config Bits
     8190,             -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     8184,             -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     8185,             -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     8186,             -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     8187,             -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     8188,             -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     8189,             -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     461,              -- Device ID
     4,                -- Family ID
     'PIC18F84J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16382,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode, 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode, 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode, 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     453,              -- Device ID
     4,                -- Family ID
     'PIC18F84J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16382,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     175,              -- Device ID
     4,                -- Family ID
     'PIC18F85J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     463,              -- Device ID
     4,                -- Family ID
     'PIC18F85J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode, 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode, 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode, 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     184,              -- Device ID
     4,                -- Family ID
     'PIC18F85J15',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     49144,            -- Start of Config Bits
     49150,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     49144,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     49145,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     49146,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     49147,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     49148,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     49149,            -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     525,              -- Device ID
     4,                -- Family ID
     'PIC18F85J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     247,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL, CLKO on RA6, ECPLL used by USB',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with CLKO on RA6, EC used by USB',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled, HSPLL used by USB',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator, HS used by USB',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSC, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states on the external bus are disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states on the external bus are enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PMPMX',          -- C Name
     'PMP Pin Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'PMP pins placed on EMB',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'PMP pins placed else where',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     455,              -- Device ID
     4,                -- Family ID
     'PIC18F85J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     667,              -- Device ID
     4,                -- Family ID
     'PIC18F85K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Shift bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ABW',            -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     '20-bit address bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     '16-bit address bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     '12-bit address bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     '8-bit address bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     139               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RE6/RE5/RE4/RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RH7/RH6/RH5/RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-017FF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 01800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-017FF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 01800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     661,              -- Device ID
     4,                -- Family ID
     'PIC18F85K90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     139               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RE6/RE5/RE4/RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RH7/RH6/RH5/RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-017FF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 01800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-017FF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 01800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     185,              -- Device ID
     4,                -- Family ID
     'PIC18F86J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     551,              -- Device ID
     4,                -- Family ID
     'PIC18F86J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator, PLL enabled, CLKO on RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator, CLKO  on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states on the external bus are disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states on the external bus are enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PMPMX',          -- C Name
     'PMP Pin Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'PMP port pins connected to EMB (PORTD and PORTE)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'PMP port pins not connected to EMB (PORTA, PORTF and PORTH)',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     186,              -- Device ID
     4,                -- Family ID
     'PIC18F86J15',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     552,              -- Device ID
     4,                -- Family ID
     'PIC18F86J16',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     225,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     244,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator, PLL enabled, CLKO on RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator, CLKO  on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states on the external bus are disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states on the external bus are enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PMPMX',          -- C Name
     'PMP Pin Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'PMP port pins connected to EMB (PORTD and PORTE)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'PMP port pins not connected to EMB (PORTA, PORTF and PORTH)',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     527,              -- Device ID
     4,                -- Family ID
     'PIC18F86J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL, CLKO on RA6, ECPLL used by USB',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with CLKO on RA6, EC used by USB',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled, HSPLL used by USB',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator, HS used by USB',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSC, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states on the external bus are disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states on the external bus are enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PMPMX',          -- C Name
     'PMP Pin Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'PMP pins placed on EMB',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'PMP pins placed else where',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     528,              -- Device ID
     4,                -- Family ID
     'PIC18F86J55',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     247,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL, CLKO on RA6, ECPLL used by USB',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with CLKO on RA6, EC used by USB',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled, HSPLL used by USB',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator, HS used by USB',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSC, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states on the external bus are disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states on the external bus are enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PMPMX',          -- C Name
     'PMP Pin Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'PMP pins placed on EMB',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'PMP pins placed else where',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     193,              -- Device ID
     4,                -- Family ID
     'PIC18F86J60',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode (80-pin and 100-pin devices) or with RB3 in Extended Microcontroller mode (100-pin devices only)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     250,              -- Device ID
     4,                -- Family ID
     'PIC18F86J65',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode (80-pin and 100-pin devices) or with RB3 in Extended Microcontroller mode (100-pin devices only)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     642,              -- Device ID
     4,                -- Family ID
     'PIC18F86J72',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     2,                -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7 <Microcontroller> / RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     644,              -- Device ID
     4,                -- Family ID
     'PIC18F86J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     242,              -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7',            -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     646,              -- Device ID
     4,                -- Family ID
     'PIC18F86J93',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     242,              -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7',            -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     665,              -- Device ID
     4,                -- Family ID
     'PIC18F86K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3862              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Shift bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ABW',            -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     '20-bit address bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     '16-bit address bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     '12-bit address bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     '8-bit address bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     139               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RE6/RE5/RE4/RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RH7/RH6/RH5/RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     659,              -- Device ID
     4,                -- Family ID
     'PIC18F86K90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3828              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     139               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RE6/RE5/RE4/RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RH7/RH6/RH5/RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     187,              -- Device ID
     4,                -- Family ID
     'PIC18F87J10',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLK function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     553,              -- Device ID
     4,                -- Family ID
     'PIC18F87J11',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator, PLL enabled, CLKO on RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator, CLKO  on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states on the external bus are disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states on the external bus are enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PMPMX',          -- C Name
     'PMP Pin Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'PMP port pins connected to EMB (PORTD and PORTE)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'PMP port pins not connected to EMB (PORTA, PORTF and PORTH)',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     529,              -- Device ID
     4,                -- Family ID
     'PIC18F87J50',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3904              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     247,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL, CLKO on RA6, ECPLL used by USB',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with CLKO on RA6, EC used by USB',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled, HSPLL used by USB',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator, HS used by USB',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSC, CLKO on RA6 and Port function on RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC, Port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled, address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled, address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode - External bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode - 12-bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode - 16-bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode - 20-bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states on the external bus are disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states on the external bus are enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode or with RB3 in Extended Microcontroller mode',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCPx MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PMPMX',          -- C Name
     'PMP Pin Multiplex bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'PMP pins placed on EMB',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'PMP pins placed else where',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP Address Masking Mode Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5-Bit Address Masking mode enable',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     251,              -- Device ID
     4,                -- Family ID
     'PIC18F87J60',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode (80-pin and 100-pin devices) or with RB3 in Extended Microcontroller mode (100-pin devices only)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     643,              -- Device ID
     4,                -- Family ID
     'PIC18F87J72',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     2,                -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7 <Microcontroller> / RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     645,              -- Device ID
     4,                -- Family ID
     'PIC18F87J90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     242,              -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7',            -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     647,              -- Device ID
     4,                -- Family ID
     'PIC18F87J93',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3924              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled-Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC Oscillator with PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC Oscillator with clock out on RA6',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSC with PLL enabled, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'Internal oscillator, CLKOUT on RA6 and port function on RA7',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSC with PLL enabled, port function on RA6 and RA7',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'Internal oscillator, port function on RA6 and RA7 ',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'Secondary Clock Source T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator configured for low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 oscillator configured for higher power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     242,              -- Default Value
     2                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCSOSC',        -- C Name
     'RTCC Reference Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI as reference clock',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTOSC/INTRC as reference clock',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     241,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'RE7',            -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);


insert into DEVICES values (
     null,
     654,              -- Device ID
     4,                -- Family ID
     'PIC18F87K22',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     128,              -- Write FLASH Block Size
     128,              -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3862              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Shift bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address Shifting enabled',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address Shifting disabled',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ABW',            -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     '20-bit address bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     '16-bit address bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     '12-bit address bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     '8-bit address bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-bit external bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-bit external bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     139               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RE6/RE5/RE4/RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RH7/RH6/RH5/RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Table Write Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Table Write Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Table Write Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Table Write Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT4',          -- C Name
     'Table Read Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT5',          -- C Name
     'Table Read Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT6',          -- C Name
     'Table Read Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT7',          -- C Name
     'Table Read Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     650,              -- Device ID
     4,                -- Family ID
     'PIC18F87K90',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     128,              -- Write FLASH Block Size
     128,              -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3828              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SRETEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOSCREF',        -- C Name
     'RTCC uses SOSC', -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     139,              -- Default Value
     139               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'RC1',            -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'RE7-Microcontroller Mode/RB3-All other modes',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RE6/RE5/RE4/RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'Enhanced CCP1/3 [P1B/P1C/P3B/P3C] muxed with RH7/RH6/RH5/RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Table Write Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Table Write Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Table Write Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Table Write Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT4',          -- C Name
     'Table Read Protect 10000-13FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT5',          -- C Name
     'Table Read Protect 14000-17FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT6',          -- C Name
     'Table Read Protect 18000-1BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRT7',          -- C Name
     'Table Read Protect 1C000-1FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBRTB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     194,              -- Device ID
     4,                -- Family ID
     'PIC18F96J60',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65534,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled; address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled; address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode, external bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode,12-Bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode,16-Bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode, 20-Bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-Bit Data Width mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-Bit Data Width mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode (80-pin and 100-pin devices) or with RB3 in Extended Microcontroller mode (100-pin devices only)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     252,              -- Device ID
     4,                -- Family ID
     'PIC18F96J65',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     98296,            -- Start of Config Bits
     98302,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     98296,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     98297,            -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     98298,            -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     98299,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     98300,            -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled; address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled; address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode, external bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode,12-Bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode,16-Bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode, 20-Bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-Bit Data Width mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-Bit Data Width mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     98301,            -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode (80-pin and 100-pin devices) or with RB3 in Extended Microcontroller mode (100-pin devices only)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     253,              -- Device ID
     4,                -- Family ID
     'PIC18F97J60',    -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131070,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3712              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     244               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     199,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC1:FOSC0 as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     248,              -- Default Value
     248               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EASHFT',         -- C Name
     'External Address Bus Shift Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Address shifting enabled; address on external bus is offset to start at 000000h',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Address shifting disabled; address on external bus reflects the PC value',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'External Memory Bus'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MM',             -- C Name
     'Microcontroller mode, external bus disabled',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM12',           -- C Name
     'Extended Microcontroller mode,12-Bit Address mode',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM16',           -- C Name
     'Extended Microcontroller mode,16-Bit Address mode',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XM20',           -- C Name
     'Extended Microcontroller mode, 20-Bit Address mode',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BW',             -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '16-Bit Data Width mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '8-Bit Data Width mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait states for operations on external memory bus disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait states for operations on external memory bus enabled and selected by MEMCON<5:4>',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     247,              -- Default Value
     247               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 MUX bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP2/P2A is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP2/P2A is multiplexed with RE7 in Microcontroller mode (80-pin and 100-pin devices) or with RB3 in Extended Microcontroller mode (100-pin devices only)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RE6 and RE5; ECCP3 outputs (P3B/P3C) are multiplexed with RE4 and RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ECCP1 outputs (P1B/P1C) are multiplexed with RH7 and RH6; ECCP3 outputs (P3B/P3C) are multiplexed with RH5 and RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ETHLED',         -- C Name
     'Ethernet LED Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'RA0/RA1 are multiplexed with LEDA/LEDB when Ethernet module is enabled and function as I/O when Ethernet is disabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA0/RA1 function as I/O regardless of Ethernet module status',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     36,               -- Device ID
     4,                -- Family ID
     'PIC18F242',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled/Clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause RESET',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause RESET',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     64,               -- Device ID
     4,                -- Family ID
     'PIC18F248',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled/Clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     32,               -- Device ID
     4,                -- Family ID
     'PIC18F252',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled/Clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause RESET',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause RESET',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from Table Reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from Table Reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     66,               -- Device ID
     4,                -- Family ID
     'PIC18F258',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled/Clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from Table Reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from Table Reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     37,               -- Device ID
     4,                -- Family ID
     'PIC18F442',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled/Clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause RESET',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause RESET',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     65,               -- Device ID
     4,                -- Family ID
     'PIC18F448',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled/Clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     33,               -- Device ID
     4,                -- Family ID
     'PIC18F452',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled/Clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause RESET',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause RESET',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from Table Reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from Table Reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     67,               -- Device ID
     4,                -- Family ID
     'PIC18F458',      -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled/Clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator',  -- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from Table Reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from Table Reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     63,               -- Device ID
     4,                -- Family ID
     'PIC18F1220',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FSCM',           -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'Reserved',       -- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     128,              -- Default Value
     128               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RA5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5 input pin enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (00200-0007FFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (00200-0007FFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (00200-0007FFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (00200-000F7Fh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (00200-0007FFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (00200-0007FFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     240,              -- Device ID
     4,                -- Family ID
     'PIC18F1230',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728768,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal oscillator, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal oscillator, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     14,               -- Default Value
     14                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWMPIN',         -- C Name
     'PWM Output Pins Reset State Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWM outputs disabled upon Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWM outputs drive active states upon Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPOL',           -- C Name
     'Low-Side Transistors Polarity bit (Even PWM Output Polarity Control bit)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM0, PWM2 and PWM4 are active-high (default)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM0, PWM2 and PWM4 are active-low',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HPOL',           -- C Name
     'High Side Transistors Polarity bit (Odd PWM Output Polarity Control bit)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM1, PWM3 and PWM5 are active-high (default)',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM1, PWM3 and PWM5 are active-low',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     129,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FLTAMX',         -- C Name
     'FLTA Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'FLTA input is muxed onto RA5',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA7',            -- C Name
     'FLTA input is muxed onto RA7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1OSCMX',        -- C Name
     'T1OSO/T1CKI MUX bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'T1OSO/T1CKI pin resides on RA6',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'T1OSO/T1CKI pin resides on RB2',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RA5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5 input pin enabled, MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     129,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB512',          -- C Name
     '512 Words (1024 Bytes) Boot Block size',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '512 Words (1024 Bytes) Boot Block size',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '512 Words (1024 Bytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB256',          -- C Name
     '256 Words (512 Bytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0 (000400-0007FF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1 (000800-000FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protection bit (Boot Block Memory Area)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Code Protection bit (Data EEPROM)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0 (000400-0007FF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1 (000800-000FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Write Protection bit (Configuration Registers)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Write Protection bit (Boot Block Memory Area)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Write Protection bit (Data EEPROM)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0 (000400-0007FF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1 (000800-000FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protection bit (Boot Block Memory Area)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     62,               -- Device ID
     4,                -- Family ID
     'PIC18F1320',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FSCM',           -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'Reserved',       -- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     128,              -- Default Value
     128               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RA5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5 input pin enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (00200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (00200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (00200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (00200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (00200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (00200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     241,              -- Device ID
     4,                -- Family ID
     'PIC18F1330',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728768,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal oscillator, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal oscillator, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     14,               -- Default Value
     14                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWMPIN',         -- C Name
     'PWM Output Pins Reset State Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWM outputs disabled upon Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWM outputs drive active states upon Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPOL',           -- C Name
     'Low-Side Transistors Polarity bit (Even PWM Output Polarity Control bit)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM0, PWM2 and PWM4 are active-high (default)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM0, PWM2 and PWM4 are active-low',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HPOL',           -- C Name
     'High Side Transistors Polarity bit (Odd PWM Output Polarity Control bit)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM1, PWM3 and PWM5 are active-high (default)',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM1, PWM3 and PWM5 are active-low',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     129,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FLTAMX',         -- C Name
     'FLTA Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA5',            -- C Name
     'FLTA input is muxed onto RA5',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RA7',            -- C Name
     'FLTA input is muxed onto RA7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1OSCMX',        -- C Name
     'T1OSO/T1CKI MUX bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'T1OSO/T1CKI pin resides on RA6',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'T1OSO/T1CKI pin resides on RB2',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RA5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA5 input pin enabled, MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     129,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K Words (2048 Bytes) Boot Block size',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '1K Words (2048 Bytes) Boot Block size',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB512',          -- C Name
     '512 Words (1024 Bytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB256',          -- C Name
     '256 Words (512 Bytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0 (000800-000FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1 (001000-001FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protection bit (Boot Block Memory Area)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Code Protection bit (Data EEPROM)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0 (000800-000FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1 (001000-001FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Write Protection bit (Configuration Registers)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Write Protection bit (Boot Block Memory Area)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Write Protection bit (Data EEPROM)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0 (000800-000FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1 (001000-001FFF)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protection bit (Boot Block Memory Area)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     44,               -- Device ID
     4,                -- Family ID
     'PIC18F2220',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FSCM',           -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBAD',           -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ANA',            -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR disabled; RE3 input is enabled in 40-pin devices only (PIC18F4X20)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     267,              -- Device ID
     4,                -- Family ID
     'PIC18F2221',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum Setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum Setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ANA',            -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     253               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB512',          -- C Name
     ' 512 Word',      -- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     ' 512 Word',      -- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     ' 512 Word',      -- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB256',          -- C Name
     ' 256 Word',      -- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bitProtect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     40,               -- Device ID
     4,                -- Family ID
     'PIC18F2320',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FSCM',           -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBAD',           -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ANA',            -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR disabled; RE3 input is enabled in 40-pin devices only (PIC18F4X20)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (001000-0017FFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (001000-0017FFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (001800-001FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (001800-001FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (001000-0017FFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (001000-0017FFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (001800-001FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (001800-001FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (001000-0017FFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (001000-0017FFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (001800-001FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (001800-001FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     265,              -- Device ID
     4,                -- Family ID
     'PIC18F2321',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum Setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum Setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ANA',            -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     253               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1024 Word',      -- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '1024 Word',      -- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB512',          -- C Name
     ' 512 Word',      -- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB256',          -- C Name
     ' 256 Word',      -- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bitProtect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     71,               -- Device ID
     4,                -- Family ID
     'PIC18F2331',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal oscillator block, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO',          -- C Name
     'Internal oscillator block, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC2',            -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'Reserved',       -- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDPS',           -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WINEN',          -- C Name
     'Watchdog Timer Window Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT window disabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT window enabledbled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     60,               -- Default Value
     60                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWMPIN',         -- C Name
     'PWM output pins Reset state control'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWM outputs disabled upon Reset (default)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWM outputs drive active states upon Reset',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPOL',           -- C Name
     'Low-Side Transistors Polarity'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM0, 2, 4 and 6 are active-high',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM0, 2, 4 and 6 are active-low',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HPOL',           -- C Name
     'High-Side Transistors Polarity'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM1, 3, 5 and 7 are active-high',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM1, 3, 5 and 7 are active-low',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1OSCMX',        -- C Name
     'Timer1 Oscillator MUX'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power Timer1 operation when microcontroller is in Sleep mode',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Standard (legacy) Timer1 oscillator operation',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     157,              -- Default Value
     157               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     139,              -- Device ID
     4,                -- Family ID
     'PIC18F2410',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     138,              -- Device ID
     4,                -- Family ID
     'PIC18F2420',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     277,              -- Device ID
     4,                -- Family ID
     'PIC18F2423',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65520,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     70,               -- Device ID
     4,                -- Family ID
     'PIC18F2431',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal oscillator block, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO',          -- C Name
     'Internal oscillator block, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC2',            -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'Reserved',       -- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDPS',           -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WINEN',          -- C Name
     'Watchdog Timer Window Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT window disabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT window enabledbled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     60,               -- Default Value
     60                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWMPIN',         -- C Name
     'PWM output pins Reset state control'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWM outputs disabled upon Reset (default)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWM outputs drive active states upon Reset',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPOL',           -- C Name
     'Low-Side Transistors Polarity'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM0, 2, 4 and 6 are active-high',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM0, 2, 4 and 6 are active-low',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HPOL',           -- C Name
     'High-Side Transistors Polarity'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM1, 3, 5 and 7 are active-high',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM1, 3, 5 and 7 are active-low',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1OSCMX',        -- C Name
     'Timer1 Oscillator MUX'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power Timer1 operation when microcontroller is in Sleep mode',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Standard (legacy) Timer1 oscillator operation',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     157,              -- Default Value
     157               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (002000-002FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (002000-002FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (003000-003FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (003000-003FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (002000-002FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (002000-002FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (003000-003FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (003000-003FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (002000-002FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (002000-002FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (003000-003FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (003000-003FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     36,               -- Device ID
     4,                -- Family ID
     'PIC18F2439',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     12288,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     640               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     34,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause RESET',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause RESET',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200h-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200h-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200h-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200h-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     289,              -- Device ID
     4,                -- Family ID
     'PIC18F2450',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1280              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '21',             -- C Name
     '2.1V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '28',             -- C Name
     '2.8V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '43',             -- C Name
     '4.3V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '46',             -- C Name
     '4.6V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     237               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2KW Boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1KW Boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     96                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     147,              -- Device ID
     4,                -- Family ID
     'PIC18F2455',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     24576,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     229               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     339,              -- Device ID
     4,                -- Family ID
     'PIC18F2458',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     24576,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     229               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     215,              -- Device ID
     4,                -- Family ID
     'PIC18F2480',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     213               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) boot block',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) boot block',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     137,              -- Device ID
     4,                -- Family ID
     'PIC18F2510',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     103,              -- Device ID
     4,                -- Family ID
     'PIC18F2515',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3968              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     136,              -- Device ID
     4,                -- Family ID
     'PIC18F2520',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     273,              -- Device ID
     4,                -- Family ID
     'PIC18F2523',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65520,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     102,              -- Device ID
     4,                -- Family ID
     'PIC18F2525',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3968              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     32,               -- Device ID
     4,                -- Family ID
     'PIC18F2539',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     24576,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1408              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     34,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause RESET',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause RESET',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200h-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200h-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200h-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200h-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     146,              -- Device ID
     4,                -- Family ID
     'PIC18F2550',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     229               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     338,              -- Device ID
     4,                -- Family ID
     'PIC18F2553',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     229               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     214,              -- Device ID
     4,                -- Family ID
     'PIC18F2580',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     213               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) boot block',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) boot block',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     119,              -- Device ID
     4,                -- Family ID
     'PIC18F2585',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '4K words (8K bytes) Boot Block',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     101,              -- Device ID
     4,                -- Family ID
     'PIC18F2610',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3968              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     100,              -- Device ID
     4,                -- Family ID
     'PIC18F2620',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3968              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     118,              -- Device ID
     4,                -- Family ID
     'PIC18F2680',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '4K words (8K bytes) Boot Block',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     312,              -- Device ID
     4,                -- Family ID
     'PIC18F2682',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     81920,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '4K words (8K bytes) Boot Block',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     313,              -- Device ID
     4,                -- Family ID
     'PIC18F2685',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '4K words (8K bytes) Boot Block',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     45,               -- Device ID
     4,                -- Family ID
     'PIC18F4220',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FSCM',           -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBAD',           -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ANA',            -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR disabled; RE3 input is enabled in 40-pin devices only (PIC18F4X20)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     266,              -- Device ID
     4,                -- Family ID
     'PIC18F4221',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     4096,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum Setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum Setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ANA',            -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     253               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB512',          -- C Name
     ' 512 Word',      -- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     ' 512 Word',      -- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     ' 512 Word',      -- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB256',          -- C Name
     ' 256 Word',      -- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bitProtect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     41,               -- Device ID
     4,                -- Family ID
     'PIC18F4320',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FSCM',           -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal/External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal/External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBAD',           -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ANA',            -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR disabled; RE3 input is enabled in 40-pin devices only (PIC18F4X20)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (001000-0017FFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (001000-0017FFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (001800-001FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (001800-001FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (001000-0017FFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (001000-0017FFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (001800-001FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (001800-001FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-0007FFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-0007FFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (000800-000FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (000800-000FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (001000-0017FFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (001000-0017FFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (001800-001FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (001800-001FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     264,              -- Device ID
     4,                -- Family ID
     'PIC18F4321',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS Oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT Oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP Oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum Setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum Setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB3',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ANA',            -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     253               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1024 Word',      -- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '1024 Word',      -- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB512',          -- C Name
     ' 512 Word',      -- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB256',          -- C Name
     ' 256 Word',      -- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bitProtect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     69,               -- Device ID
     4,                -- Family ID
     'PIC18F4331',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal oscillator block, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO',          -- C Name
     'Internal oscillator block, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC2',            -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'Reserved',       -- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDPS',           -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WINEN',          -- C Name
     'Watchdog Timer Window Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT window disabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT window enabledbled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     60,               -- Default Value
     60                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWMPIN',         -- C Name
     'PWM output pins Reset state control'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWM outputs disabled upon Reset (default)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWM outputs drive active states upon Reset',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPOL',           -- C Name
     'Low-Side Transistors Polarity'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM0, 2, 4 and 6 are active-high',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM0, 2, 4 and 6 are active-low',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HPOL',           -- C Name
     'High-Side Transistors Polarity'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM1, 3, 5 and 7 are active-high',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM1, 3, 5 and 7 are active-low',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1OSCMX',        -- C Name
     'Timer1 Oscillator MUX'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power Timer1 operation when microcontroller is in Sleep mode',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Standard (legacy) Timer1 oscillator operation',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     157,              -- Default Value
     157               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FLTAMX',         -- C Name
     'FLTA MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'FLTA input is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RD4',            -- C Name
     'FLTA input is multiplexed with RD4',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SSPMX',          -- C Name
     'SSP I/O MUX bit' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC7',            -- C Name
     'SCK/SCL clocks and SDA/SDI data are multiplexed with RC5 and RC4, respectively. SDO output is multiplexed with RC7.',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RD1',            -- C Name
     'SCK/SCL clocks and SDA/SDI data are multiplexed with RD3 and RD2, respectively. SDO output is multiplexed with RD1.',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWM4MX',         -- C Name
     'PWM4 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB5',            -- C Name
     'PWM4 output is multiplexed with RB5',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RD5',            -- C Name
     'PWM4 output is multiplexed with RD5',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EXCLKMX',        -- C Name
     'TMR0/T5CKI External clock MUX bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC3',            -- C Name
     'TMR0/T5CKI external clock input is multiplexed with RC3',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RD0',            -- C Name
     'TMR0/T5CKI external clock input is multiplexed with RD0',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     135,              -- Device ID
     4,                -- Family ID
     'PIC18F4410',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     134,              -- Device ID
     4,                -- Family ID
     'PIC18F4420',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     269,              -- Device ID
     4,                -- Family ID
     'PIC18F4423',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65520,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     68,               -- Device ID
     4,                -- Family ID
     'PIC18F4431',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     207,              -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal oscillator block, CLKO function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO',          -- C Name
     'Internal oscillator block, port function on RA6 and port function on RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (clock frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC2',            -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Internal External Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Internal External Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'Reserved',       -- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDPS',           -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WINEN',          -- C Name
     'Watchdog Timer Window Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT window disabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT window enabledbled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     60,               -- Default Value
     60                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWMPIN',         -- C Name
     'PWM output pins Reset state control'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWM outputs disabled upon Reset (default)',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWM outputs drive active states upon Reset',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPOL',           -- C Name
     'Low-Side Transistors Polarity'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM0, 2, 4 and 6 are active-high',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM0, 2, 4 and 6 are active-low',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HPOL',           -- C Name
     'High-Side Transistors Polarity'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'PWM1, 3, 5 and 7 are active-high',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'PWM1, 3, 5 and 7 are active-low',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1OSCMX',        -- C Name
     'Timer1 Oscillator MUX'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power Timer1 operation when microcontroller is in Sleep mode',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Standard (legacy) Timer1 oscillator operation',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     157,              -- Default Value
     157               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FLTAMX',         -- C Name
     'FLTA MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC1',            -- C Name
     'FLTA input is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RD4',            -- C Name
     'FLTA input is multiplexed with RD4',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SSPMX',          -- C Name
     'SSP I/O MUX bit' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC7',            -- C Name
     'SCK/SCL clocks and SDA/SDI data are multiplexed with RC5 and RC4, respectively. SDO output is multiplexed with RC7.',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RD1',            -- C Name
     'SCK/SCL clocks and SDA/SDI data are multiplexed with RD3 and RD2, respectively. SDO output is multiplexed with RD1.',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWM4MX',         -- C Name
     'PWM4 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RB5',            -- C Name
     'PWM4 output is multiplexed with RB5',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RD5',            -- C Name
     'PWM4 output is multiplexed with RD5',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EXCLKMX',        -- C Name
     'TMR0/T5CKI External clock MUX bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC3',            -- C Name
     'TMR0/T5CKI external clock input is multiplexed with RC3',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RD0',            -- C Name
     'TMR0/T5CKI external clock input is multiplexed with RD0',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (002000-002FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (002000-002FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (003000-003FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (003000-003FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (002000-002FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (002000-002FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (003000-003FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (003000-003FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFF) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFF) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (002000-002FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (002000-002FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (003000-003FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (003000-003FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     37,               -- Device ID
     4,                -- Family ID
     'PIC18F4439',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     12288,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     640               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     34,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause RESET',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause RESET',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200h-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200h-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200h-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200h-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     288,              -- Device ID
     4,                -- Family ID
     'PIC18F4450',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1280              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '21',             -- C Name
     '2.1V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '28',             -- C Name
     '2.8V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '43',             -- C Name
     '4.3V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '46',             -- C Name
     '4.6V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     237               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2KW Boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1KW Boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ICPRT',          -- C Name
     'Dedicated In-Circuit Debug/Programming Port (ICPORT) Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ICPORT enabled', -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ICPORT disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     96                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) or (001000-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) or (000000-000FFFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     145,              -- Device ID
     4,                -- Family ID
     'PIC18F4455',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     24576,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     229               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ICPRT',          -- C Name
     'Dedicated In-Circuit Debug/Programming Port (ICPORT) Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ICPORT enabled', -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ICPORT disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     337,              -- Device ID
     4,                -- Family ID
     'PIC18F4458',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     24576,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     229               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ICPRT',          -- C Name
     'Dedicated In-Circuit Debug/Programming Port (ICPORT) Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ICPORT enabled', -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ICPORT disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     213,              -- Device ID
     4,                -- Family ID
     'PIC18F4480',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     213               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) boot block',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) boot block',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     133,              -- Device ID
     4,                -- Family ID
     'PIC18F4510',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     99,               -- Device ID
     4,                -- Family ID
     'PIC18F4515',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3968              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     132,              -- Device ID
     4,                -- Family ID
     'PIC18F4520',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     265,              -- Device ID
     4,                -- Family ID
     'PIC18F4523',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65520,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     98,               -- Device ID
     4,                -- Family ID
     'PIC18F4525',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3968              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     33,               -- Device ID
     4,                -- Family ID
     'PIC18F4539',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     24576,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1408              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     34,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     1,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack Full/Underflow will cause RESET',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack Full/Underflow will not cause RESET',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background Debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-001FFFh) not code protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-001FFFh) code protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200h-001FFFh) not write protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200h-001FFFh) write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200h-001FFFh) not protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200h-001FFFh) protected from Table Reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from Table Reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from Table Reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) protected from Table Reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     144,              -- Device ID
     4,                -- Family ID
     'PIC18F4550',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     229               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ICPRT',          -- C Name
     'Dedicated In-Circuit Debug/Programming Port (ICPORT) Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ICPORT enabled', -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ICPORT disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     336,              -- Device ID
     4,                -- Family ID
     'PIC18F4553',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'System Clock Postscaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     '[Primary Oscillator Src: /4][96 MHz PLL Src: /6]',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL4',      -- C Name
     '[Primary Oscillator Src: /3][96 MHz PLL Src: /4]',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL3',      -- C Name
     '[Primary Oscillator Src: /2][96 MHz PLL Src: /3]',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1_PLL2',      -- C Name
     '[Primary Oscillator Src: /1][96 MHz PLL Src: /2]',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'USB clock source comes from the 96 MHz PLL divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'USB clock source comes directly from the primary oscillator block with no postscale',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     5,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL_HS',       -- C Name
     'HS oscillator, PLL enabled (HSPLL)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator (HS)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_HS',      -- C Name
     'Internal oscillator, HS oscillator used by USB (INTHS)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_XT',      -- C Name
     'Internal oscillator, XT used by USB (INTXT)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC_EC',      -- C Name
     'Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCIO_EC',    -- C Name
     'Internal oscillator, port function on RA6, EC used by USB (INTIO)',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL_EC',       -- C Name
     'EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLLIO_EC',     -- C Name
     'EC oscillator, PLL enabled, port function on RA6 (ECPIO)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC_EC',          -- C Name
     'EC oscillator, CLKO function on RA6 (EC)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO_EC',        -- C Name
     'EC oscillator, port function on RA6 (ECIO)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XTPLL_XT',       -- C Name
     'XT oscillator, PLL enabled (XTPLL)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT_XT',          -- C Name
     'XT oscillator (XT)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON_ACTIVE',      -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SOFT',           -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'VREGEN',         -- C Name
     'USB Voltage Regulator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB voltage regulator enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB voltage regulator disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR pin disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     229               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ICPRT',          -- C Name
     'Dedicated In-Circuit Debug/Programming Port (ICPORT) Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'ICPORT enabled', -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'ICPORT disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) are not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) are write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM is not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM is write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) is protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) is protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) is protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) is not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) is protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) is not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) is protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     212,              -- Device ID
     4,                -- Family ID
     'PIC18F4580',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     32,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     213               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) boot block',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) boot block',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     117,              -- Device ID
     4,                -- Family ID
     'PIC18F4585',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '4K words (8K bytes) Boot Block',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     97,               -- Device ID
     4,                -- Family ID
     'PIC18F4610',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3968              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     64,               -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     96,               -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     96,               -- Device ID
     4,                -- Family ID
     'PIC18F4620',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3968              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKOUT function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKOUT function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     116,              -- Device ID
     4,                -- Family ID
     'PIC18F4680',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '4K words (8K bytes) Boot Block',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     314,              -- Device ID
     4,                -- Family ID
     'PIC18F4682',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     81920,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '4K words (8K bytes) Boot Block',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     315,              -- Device ID
     4,                -- Family ID
     'PIC18F4685',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '11XX External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '101X External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOHW',           -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BOACTIVE',       -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORENCTRL',     -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'VBOR set to 2.1V',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'VBOR set to 2.8V',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'VBOR set to 4.3V',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'VBOR set to 4.6V',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     130,              -- Default Value
     134               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<4:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<4:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer 1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '4K words (8K bytes) Boot Block',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '2K words (4K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1K words (2K bytes) Boot Block',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


-- PIC18F6310 does not support self-programming.
-- PIC18F6390 does not support self-programming.
-- PIC18F6393 does not support self-programming.
-- PIC18F6410 does not support self-programming.
-- PIC18F6490 does not support self-programming.
-- PIC18F6493 does not support self-programming.
insert into DEVICES values (
     null,
     89,               -- Device ID
     4,                -- Family ID
     'PIC18F6520',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     87,               -- Device ID
     4,                -- Family ID
     'PIC18F6525',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3840              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     47,               -- Default Value
     47                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'RC-OSC2 as RA6', -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSSWPLL',        -- C Name
     'HS oscillator with SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOSWPLL',      -- C Name
     'EC oscillator with OSC2 configured as RA6 and SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOPLL',        -- C Name
     'EC oscillator with OSC2 configured as RA6 and HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 Mux bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'Multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'Multiplexed with RB3 or RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Enable bit' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to in-circuit debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     154,              -- Device ID
     4,                -- Family ID
     'PIC18F6527',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     255,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     129,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     83,               -- Device ID
     4,                -- Family ID
     'PIC18F6585',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     47,               -- Default Value
     47                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'RC-OSC2 as RA6', -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSSWPLL',        -- C Name
     'HS oscillator with SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOSWPLL',      -- C Name
     'EC oscillator with OSC2 configured as RA6 and SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOPLL',        -- C Name
     'EC oscillator with OSC2 configured as RA6 and HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Osc. Switch Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Voltage'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR enable'     -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Program'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to in-circuit debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 000800-0003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 0004000-007FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 008000-00BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 004000-007FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 004000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     51,               -- Device ID
     4,                -- Family ID
     'PIC18F6620',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3840              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     3,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     85,               -- Device ID
     4,                -- Family ID
     'PIC18F6621',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3840              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     47,               -- Default Value
     47                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'RC-OSC2 as RA6', -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSSWPLL',        -- C Name
     'HS oscillator with SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOSWPLL',      -- C Name
     'EC oscillator with OSC2 configured as RA6 and SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOPLL',        -- C Name
     'EC oscillator with OSC2 configured as RA6 and HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 Mux bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'Multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'Multiplexed with RB3 or RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Enable bit' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to in-circuit debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh)  code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     156,              -- Device ID
     4,                -- Family ID
     'PIC18F6622',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     255,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     129,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     158,              -- Device ID
     4,                -- Family ID
     'PIC18F6627',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     255,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     590,              -- Device ID
     4,                -- Family ID
     'PIC18F6628',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     255,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     81,               -- Device ID
     4,                -- Family ID
     'PIC18F6680',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     47,               -- Default Value
     47                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'RC-OSC2 as RA6', -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSSWPLL',        -- C Name
     'HS oscillator with SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOSWPLL',      -- C Name
     'EC oscillator with OSC2 configured as RA6 and SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOPLL',        -- C Name
     'EC oscillator with OSC2 configured as RA6 and HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Osc. Switch Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Voltage'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR enable'     -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Program'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to in-circuit debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 000800-0003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 0004000-007FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 008000-00BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 00C000-00FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 004000-007FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 004000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     49,               -- Device ID
     4,                -- Family ID
     'PIC18F6720',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3840              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     3,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR6',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR7',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     160,              -- Device ID
     4,                -- Family ID
     'PIC18F6722',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     255,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (01BFFF-018000h) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (01BFFF-018000h) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Write Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (01BFFF-018000h) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (01BFFF-018000h) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Write Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR6',          -- C Name
     'Table Read Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR7',          -- C Name
     'Table Read Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     592,              -- Device ID
     4,                -- Family ID
     'PIC18F6723',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     255,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP2 input/output is multiplexed with RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (01BFFF-018000h) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (01BFFF-018000h) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Write Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (01BFFF-018000h) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (01BFFF-018000h) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Write Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR6',          -- C Name
     'Table Read Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR7',          -- C Name
     'Table Read Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


-- PIC18F8310 does not support self-programming.
-- PIC18F8390 does not support self-programming.
-- PIC18F8393 does not support self-programming.
-- PIC18F8410 does not support self-programming.
-- PIC18F8490 does not support self-programming.
-- PIC18F8493 does not support self-programming.
insert into DEVICES values (
     null,
     88,               -- Device ID
     4,                -- Family ID
     'PIC18F8520',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     2048              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits (MEMCOM<5:4>)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     86,               -- Device ID
     4,                -- Family ID
     'PIC18F8525',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3840              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     47,               -- Default Value
     47                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'RC-OSC2 as RA6', -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSSWPLL',        -- C Name
     'HS oscillator with SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOSWPLL',      -- C Name
     'EC oscillator with OSC2 configured as RA6 and SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOPLL',        -- C Name
     'EC oscillator with OSC2 configured as RA6 and HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by WAIT1:WAIT0 bits (MEMCOM<5:4>)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 Mux bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'Multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'Multiplexed with RB3 or RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP1 (P1B/P1C) and ECCP3 (P3B/P3C) PWM outputs are multiplexed with RE6 through RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'ECCP1 (P1B/P1C) and ECCP3 (P3B/P3C) PWM outputs are multiplexed with RH7 through RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Enable bit' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to in-circuit debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     155,              -- Device ID
     4,                -- Family ID
     'PIC18F8527',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Data Memory Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADDRBW',         -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR20BIT',      -- C Name
     '20-bit Address Bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR16BIT',      -- C Name
     '16-bit Address Bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR12BIT',      -- C Name
     '12-bit Address Bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR8BIT',       -- C Name
     '8-bit Address Bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DATABW',         -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA16BIT',      -- C Name
     '16-bit External Bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA8BIT',       -- C Name
     '8-bit External Bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections are unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'ECCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RE6, RE5, RE4 and RE3 respectively',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RH7, RH6, RH5 and RH4 respectively',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     7                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     82,               -- Device ID
     4,                -- Family ID
     'PIC18F8585',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     49152,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     47,               -- Default Value
     47                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'RC-OSC2 as RA6', -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSSWPLL',        -- C Name
     'HS oscillator with SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOSWPLL',      -- C Name
     'EC oscillator with OSC2 configured as RA6 and SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOPLL',        -- C Name
     'EC oscillator with OSC2 configured as RA6 and HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Osc. Switch Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Voltage'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Mode'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by WAIT1:WAIT0 bits (MEMCOM<5:4>)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'P1B, P1C are multiplexed with RE6, RE5',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'P1B, P1C are multiplexed with RH7, RH6',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR enable'     -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Program'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to in-circuit debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 000800-0003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 0004000-007FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 008000-00BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 004000-007FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 004000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     50,               -- Device ID
     4,                -- Family ID
     'PIC18F8620',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3840              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits (MEMCOM<5:4>)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     3,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     84,               -- Device ID
     4,                -- Family ID
     'PIC18F8621',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3840              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     47,               -- Default Value
     47                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'RC-OSC2 as RA6', -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSSWPLL',        -- C Name
     'HS oscillator with SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOSWPLL',      -- C Name
     'EC oscillator with OSC2 configured as RA6 and SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOPLL',        -- C Name
     'EC oscillator with OSC2 configured as RA6 and HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscaler Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by WAIT1:WAIT0 bits (MEMCOM<5:4>)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'ECCP2 Mux bit'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'Multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'Multiplexed with RB3 or RE7',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP1 (P1B/P1C) and ECCP3 (P3B/P3C) PWM outputs are multiplexed with RE6 through RE3',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'ECCP1 (P1B/P1C) and ECCP3 (P3B/P3C) PWM outputs are multiplexed with RH7 through RH4',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Enable bit' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-Voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-Voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to in-circuit debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh)  code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     157,              -- Device ID
     4,                -- Family ID
     'PIC18F8622',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Data Memory Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADDRBW',         -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR20BIT',      -- C Name
     '20-bit Address Bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR16BIT',      -- C Name
     '16-bit Address Bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR12BIT',      -- C Name
     '12-bit Address Bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR8BIT',       -- C Name
     '8-bit Address Bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DATABW',         -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA16BIT',      -- C Name
     '16-bit External Bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA8BIT',       -- C Name
     '8-bit External Bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections are unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'ECCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RE6, RE5, RE4 and RE3 respectively',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RH7, RH6, RH5 and RH4 respectively',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     159,              -- Device ID
     4,                -- Family ID
     'PIC18F8627',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Data Memory Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADDRBW',         -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR20BIT',      -- C Name
     '20-bit Address Bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR16BIT',      -- C Name
     '16-bit Address Bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR12BIT',      -- C Name
     '12-bit Address Bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR8BIT',       -- C Name
     '8-bit Address Bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DATABW',         -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA16BIT',      -- C Name
     '16-bit External Bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA8BIT',       -- C Name
     '8-bit External Bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections are unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'ECCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RE6, RE5, RE4 and RE3 respectively',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RH7, RH6, RH5 and RH4 respectively',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     591,              -- Device ID
     4,                -- Family ID
     'PIC18F8628',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     98304,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Data Memory Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADDRBW',         -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR20BIT',      -- C Name
     '20-bit Address Bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR16BIT',      -- C Name
     '16-bit Address Bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR12BIT',      -- C Name
     '12-bit Address Bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR8BIT',       -- C Name
     '8-bit Address Bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DATABW',         -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA16BIT',      -- C Name
     '16-bit External Bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA8BIT',       -- C Name
     '8-bit External Bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections are unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'ECCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RE6, RE5, RE4 and RE3 respectively',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RH7, RH6, RH5 and RH4 respectively',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     80,               -- Device ID
     4,                -- Family ID
     'PIC18F8680',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3328              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     47,               -- Default Value
     47                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'RC-OSC2 as RA6', -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSSWPLL',        -- C Name
     'HS oscillator with SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOSWPLL',      -- C Name
     'EC oscillator with OSC2 configured as RA6 and SW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIOPLL',        -- C Name
     'EC oscillator with OSC2 configured as RA6 and HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with HW enabled 4x PLL',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator with OSC2 configured as RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator with OSC2 configured as divide by 4 clock output',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Osc. Switch Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Voltage'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '20',             -- C Name
     'VBOR set to 2.0V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Mode'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Wait'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by WAIT1:WAIT0 bits (MEMCOM<5:4>)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP Mux'        -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'P1B, P1C are multiplexed with RE6, RE5',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'P1B, P1C are multiplexed with RH7, RH6',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR enable'     -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input enabled, MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low Voltage Program'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to in-circuit debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 000800-0003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 0004000-007FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 008000-00BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 00C000-00FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh)  code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 004000-007FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-003FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 004000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     48,               -- Device ID
     4,                -- Family ID
     'PIC18F8720',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3840              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     39                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'RC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator with PLL enabled; clock frequency = (4 x FOSC)',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO',           -- C Name
     'EC oscillator w/ OSC2 configured as RA6',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'RC oscillator w/ OSC2 configured as divide-by-4 clock output',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSCS',           -- C Name
     'Oscillator System Clock Switch Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator system clock switch option is disabled (main oscillator is source)',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 Oscillator system clock switch option is enabled (oscillator switching is enabled)',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOR',            -- C Name
     'Brown-out Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '25',             -- C Name
     'VBOR set to 2.5V',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7V',-- Description
     12,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '42',             -- C Name
     'VBOR set to 4.2V',-- Description
     12,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '45',             -- C Name
     'VBOR set to 4.5V',-- Description
     12,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     131,              -- Default Value
     131               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits (MEMCOM<5:4>)',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     3,                -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MUX',        -- C Name
     'CCP2 Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     133               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVR',           -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Low-Voltage ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-voltage ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Low-voltage ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled. RB6 and RB7 configured as general purpose I/O pins.',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled. RB6 and RB7 are dedicated to In-Circuit Debug.',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR6',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR7',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     161,              -- Device ID
     4,                -- Family ID
     'PIC18F8722',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Data Memory Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADDRBW',         -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR20BIT',      -- C Name
     '20-bit Address Bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR16BIT',      -- C Name
     '16-bit Address Bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR12BIT',      -- C Name
     '12-bit Address Bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR8BIT',       -- C Name
     '8-bit Address Bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DATABW',         -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA16BIT',      -- C Name
     '16-bit External Bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA8BIT',       -- C Name
     '8-bit External Bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections are unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'ECCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RE6, RE5, RE4 and RE3 respectively',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RH7, RH6, RH5 and RH4 respectively',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (01BFFF-018000h) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (01BFFF-018000h) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Write Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (01BFFF-018000h) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (01BFFF-018000h) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Write Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR6',          -- C Name
     'Table Read Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR7',          -- C Name
     'Table Read Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     593,              -- Device ID
     4,                -- Family ID
     'PIC18F8723',     -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3936              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     7,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     12,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKO function on RA6, port function on RA7',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block, port function on RA6 and RA7',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECIO6',          -- C Name
     'EC oscillator, port function on RA6',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKO function on RA6',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRT',           -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Minimum setting',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '',               -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     'Maximum setting',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDT',            -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on the SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     3145732,          -- Address
     243,              -- Default Value
     243               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MODE',           -- C Name
     'Processor Data Memory Mode Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MC',             -- C Name
     'Microcontroller mode',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MP',             -- C Name
     'Microprocessor mode',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MPB',            -- C Name
     'Microprocessor with Boot Block mode',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EM',             -- C Name
     'Extended Microcontroller mode',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADDRBW',         -- C Name
     'Address Bus Width Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR20BIT',      -- C Name
     '20-bit Address Bus',-- Description
     48,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR16BIT',      -- C Name
     '16-bit Address Bus',-- Description
     48,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR12BIT',      -- C Name
     '12-bit Address Bus',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ADDR8BIT',       -- C Name
     '8-bit Address Bus',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DATABW',         -- C Name
     'Data Bus Width Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA16BIT',      -- C Name
     '16-bit External Bus mode',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DATA8BIT',       -- C Name
     '8-bit External Bus mode',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WAIT',           -- C Name
     'External Bus Data Wait Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Wait selections are unavailable for table reads and table writes',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Wait selections for table reads and table writes are determined by the WAIT1:WAIT0 bits',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     131,              -- Default Value
     135               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTBE',         -- C Name
     'ECCP2 is multiplexed with RB3 in Extended Microcontroller, Microprocessor or Microprocessor with Boot Block mode. Or with RE7 in Microcontroller mode.',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ECCPMX',         -- C Name
     'ECCP MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RE6, RE5, RE4 and RE3 respectively',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTH',          -- C Name
     'ECCP1/3 (P1B/P1C/P3B/P3C) are multiplexed onto RH7, RH6, RH5 and RH4 respectively',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Timer1 configured for low-power operation',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Timer1 configured for higher power operation',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RG5 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RG5 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     245               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB8K',           -- C Name
     '4K words (8 Kbytes) Boot Block size',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB4K',           -- C Name
     '2K words (4 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '1K word (2 Kbytes) Boot Block size',-- Description
     48,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP4',            -- C Name
     'Code Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not code-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) code-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP5',            -- C Name
     'Code Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not code-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) code-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP6',            -- C Name
     'Code Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (01BFFF-018000h) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (01BFFF-018000h) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP7',            -- C Name
     'Code Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT4',           -- C Name
     'Write Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not write-protected',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) write-protected',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT5',           -- C Name
     'Write Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT6',           -- C Name
     'Write Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (01BFFF-018000h) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (01BFFF-018000h) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT7',           -- C Name
     'Write Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800, 001000 or 002000-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection bit Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection bit Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR4',          -- C Name
     'Table Read Protection bit Block 4'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 4 (010000-013FFFh) not protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 4 (010000-013FFFh) protected from table reads executed in other blocks',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR5',          -- C Name
     'Table Read Protection bit Block 5'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 5 (014000-017FFFh) not protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 5 (014000-017FFFh) protected from table reads executed in other blocks',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR6',          -- C Name
     'Table Read Protection bit Block 6'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 6 (018000-01BFFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 6 (018000-01BFFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR7',          -- C Name
     'Table Read Protection bit Block 7'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 7 (01C000-01FFFFh) not protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 7 (01C000-01FFFFh) protected from table reads executed in other blocks',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-007FFF, 000FFF or 001FFFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     636,              -- Device ID
     4,                -- Family ID
     'PIC18LF13K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     256               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '111X External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'EC (low)',       -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTL',      -- C Name
     'EC, CLKOUT function on OSC2 (low)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'EC (medium)',    -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTM',      -- C Name
     'EC, CLKOUT function on OSC2 (medium)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCCLKOUT',      -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERC',            -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '0110 External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'EC (high)',      -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTH',      -- C Name
     'EC, CLKOUT function on OSC2 (high)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCCLKOUT',      -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     '4 X PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL is under software control',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PCLKEN',         -- C Name
     'Primary Clock Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock is under software control',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'VBOR set to 1.9 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect.',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     136,              -- Default Value
     136               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RA3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     77                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '1kW boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '512W boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     568,              -- Device ID
     4,                -- Family ID
     'PIC18LF13K50',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     8,                -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     56                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV4',        -- C Name
     'CPU System Clock divided by 4',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV3',        -- C Name
     'CPU System Clock divided by 3',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV2',        -- C Name
     'CPU System Clock divided by 2',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOCLKDIV',       -- C Name
     'No CPU System Clock divide',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB clock comes from the OSC1/OSC2 divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB clock comes directly from the OSC1/OSC2 oscillator block; no divide',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '111X External RC oscillator, CLKOUT function on OSC2',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'EC (low)',       -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTL',      -- C Name
     'EC, CLKOUT function on OSC2 (low)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'EC (medium)',    -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTM',      -- C Name
     'EC, CLKOUT function on OSC2 (medium)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCCLKOUT',      -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERC',            -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '0110 External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'EC (high)',      -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTH',      -- C Name
     'EC, CLKOUT function on OSC2 (high)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCCLKOUT',      -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     '4 X PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL is under software control',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PCLKEN',         -- C Name
     'Primary Clock Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock is under software control',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'VBOR set to 1.9 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect.',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     136,              -- Default Value
     136               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RA3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     77                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '1kW boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '512W boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     635,              -- Device ID
     4,                -- Family ID
     'PIC18LF14K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '111X External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'EC (low)',       -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTL',      -- C Name
     'EC, CLKOUT function on OSC2 (low)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'EC (medium)',    -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTM',      -- C Name
     'EC, CLKOUT function on OSC2 (medium)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCCLKOUT',      -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERC',            -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '0110 External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'EC (high)',      -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTH',      -- C Name
     'EC, CLKOUT function on OSC2 (high)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCCLKOUT',      -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     '4 X PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL is under software control',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PCLKEN',         -- C Name
     'Primary Clock Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock is under software control',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'VBOR set to 1.9 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect.',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     136,              -- Default Value
     136               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled, RA3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     77                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '2kW boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '1kW boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     569,              -- Device ID
     4,                -- Family ID
     'PIC18LF14K50',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     16,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     0,                -- Default Value
     207               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV4',        -- C Name
     'CPU System Clock divided by 4',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV3',        -- C Name
     'CPU System Clock divided by 3',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'CLKDIV2',        -- C Name
     'CPU System Clock divided by 2',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOCLKDIV',       -- C Name
     'No CPU System Clock divide',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'USBDIV',         -- C Name
     'USB Clock Selection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'USB clock comes from the OSC1/OSC2 divided by 2',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'USB clock comes directly from the OSC1/OSC2 oscillator block; no divide',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     39,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '111X External RC oscillator, CLKOUT function on OSC2',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECL',            -- C Name
     'EC (low)',       -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTL',      -- C Name
     'EC, CLKOUT function on OSC2 (low)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECM',            -- C Name
     'EC (medium)',    -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTM',      -- C Name
     'EC, CLKOUT function on OSC2 (medium)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRCCLKOUT',      -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'IRC',            -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERC',            -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '',               -- C Name
     '0110 External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECH',            -- C Name
     'EC (high)',      -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECCLKOUTH',      -- C Name
     'EC, CLKOUT function on OSC2 (high)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ERCCLKOUT',      -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLEN',          -- C Name
     '4 X PLL Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL is under software control',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PCLKEN',         -- C Name
     'Primary Clock Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock is under software control',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PWRT disabled',  -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PWRT enabled',   -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '19',             -- C Name
     'VBOR set to 1.9 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '22',             -- C Name
     'VBOR set to 2.2 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '27',             -- C Name
     'VBOR set to 2.7 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '30',             -- C Name
     'VBOR set to 3.0 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect.',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     30,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     30,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     30,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     30,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     30,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     30,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     30,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     30,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     30,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     30,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     30,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     30,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     30,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     30,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     30,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     30,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     136,              -- Default Value
     136               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC starts clocking the CPU without waiting for the oscillator to stablize.',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The system clock is held off until the HFINTOSC is stable.',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR pin enabled; RA3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'RA3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     77                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     '2kW boot block size',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     '1kW boot block size',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled, RA0 and RA1 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled, RA0 and RA1 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     699,              -- Device ID
     4,                -- Family ID
     'PIC18LF23K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC6',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RC6',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P2B is on RB5',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     234,              -- Device ID
     4,                -- Family ID
     'PIC18LF24J10',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16382,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     255,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     247,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     255,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     255,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     626,              -- Device ID
     4,                -- Family ID
     'PIC18LF24J11',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16384,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     16382,            -- Address
     207,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     16383,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     614,              -- Device ID
     4,                -- Family ID
     'PIC18LF24J50',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16384,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     247,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     16382,            -- Address
     207,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     16383,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     691,              -- Device ID
     4,                -- Family ID
     'PIC18LF24K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC6',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RC6',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P2B is on RB5',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     226,              -- Device ID
     4,                -- Family ID
     'PIC18LF25J10',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     255,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     247,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     255,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     255,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     627,              -- Device ID
     4,                -- Family ID
     'PIC18LF25J11',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32768,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     32766,            -- Address
     223,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     31,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     31,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     31,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     31,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     31,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     31,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     31,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     31,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     31,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     31,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     31,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     31,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     31,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     31,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     31,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     31,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     31,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     31,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     31,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     31,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     31,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     31,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     31,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     31,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     31,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     31,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     31,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     31,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     31,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     31,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     31,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     31,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     32767,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     615,              -- Device ID
     4,                -- Family ID
     'PIC18LF25J50',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32768,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     247,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     32766,            -- Address
     223,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     31,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     31,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     31,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     31,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     31,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     31,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     31,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     31,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     31,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     31,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     31,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     31,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     31,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     31,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     31,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     31,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     31,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     31,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     31,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     31,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     31,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     31,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     31,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     31,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     31,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     31,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     31,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     31,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     31,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     31,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     31,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     31,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     32767,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     683,              -- Device ID
     4,                -- Family ID
     'PIC18LF25K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC6',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RC6',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P2B is on RB5',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     787,              -- Device ID
     4,                -- Family ID
     'PIC18LF25K80',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECAN TX and RX pins are located on RC6 and RC7, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     628,              -- Device ID
     4,                -- Family ID
     'PIC18LF26J11',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     729,              -- Device ID
     4,                -- Family ID
     'PIC18LF26J13',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     '96MHz PLL Prescaler Selection (PLLSEL=0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLSEL',         -- C Name
     'PLL Selection Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL96',          -- C Name
     'Selects 96MHz PLL',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL4X',          -- C Name
     'Selects 4x PLL', -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     243,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     616,              -- Device ID
     4,                -- Family ID
     'PIC18LF26J50',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     721,              -- Device ID
     4,                -- Family ID
     'PIC18LF26J53',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     251,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     251,              -- Default Value
     11                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LS48MHZ',        -- C Name
     'Low Speed USB mode with 48 MHz system clock bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS24X4',        -- C Name
     'System clock at 24 MHz USB CLKEN divide-by is set to 4',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS48X8',        -- C Name
     'System clock at 48 MHz USB CLKEN divide-by is set to 8',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);


insert into DEVICES values (
     null,
     675,              -- Device ID
     4,                -- Family ID
     'PIC18LF26K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3896              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC6',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RC6',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P2B is on RB5',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     784,              -- Device ID
     4,                -- Family ID
     'PIC18LF26K80',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECAN TX and RX pins are located on RC6 and RC7, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     731,              -- Device ID
     4,                -- Family ID
     'PIC18LF27J13',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     '96MHz PLL Prescaler Selection (PLLSEL=0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLSEL',         -- C Name
     'PLL Selection Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL96',          -- C Name
     'Selects 96MHz PLL',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL4X',          -- C Name
     'Selects 4x PLL', -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     131070,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     127,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     127,              -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     127,              -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     127,              -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     127,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     127,              -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     127,              -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     127,              -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     127,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     127,              -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     127,              -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     127,              -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     127,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     127,              -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     127,              -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     127,              -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     127,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     127,              -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     127,              -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     127,              -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     127,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     127,              -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     127,              -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     127,              -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     127,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     127,              -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     127,              -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     127,              -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     127,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     127,              -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     127,              -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     127,              -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     127,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     127,              -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     127,              -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     127,              -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     127,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     127,              -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     127,              -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     127,              -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     127,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     127,              -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     127,              -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     127,              -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     127,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     127,              -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     127,              -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     127,              -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     127,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     127,              -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     127,              -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     127,              -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     127,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     127,              -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     127,              -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     127,              -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     127,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     127,              -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     127,              -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     127,              -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     127,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     127,              -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     127,              -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     127,              -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_64',        -- C Name
     'Write Protect Program Flash Page 64',-- Description
     127,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_65',        -- C Name
     'Write Protect Program Flash Page 65',-- Description
     127,              -- Bit Mask
     65                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_66',        -- C Name
     'Write Protect Program Flash Page 66',-- Description
     127,              -- Bit Mask
     66                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_67',        -- C Name
     'Write Protect Program Flash Page 67',-- Description
     127,              -- Bit Mask
     67                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_68',        -- C Name
     'Write Protect Program Flash Page 68',-- Description
     127,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_69',        -- C Name
     'Write Protect Program Flash Page 69',-- Description
     127,              -- Bit Mask
     69                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_70',        -- C Name
     'Write Protect Program Flash Page 70',-- Description
     127,              -- Bit Mask
     70                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_71',        -- C Name
     'Write Protect Program Flash Page 71',-- Description
     127,              -- Bit Mask
     71                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_72',        -- C Name
     'Write Protect Program Flash Page 72',-- Description
     127,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_73',        -- C Name
     'Write Protect Program Flash Page 73',-- Description
     127,              -- Bit Mask
     73                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_74',        -- C Name
     'Write Protect Program Flash Page 74',-- Description
     127,              -- Bit Mask
     74                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_75',        -- C Name
     'Write Protect Program Flash Page 75',-- Description
     127,              -- Bit Mask
     75                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_76',        -- C Name
     'Write Protect Program Flash Page 76',-- Description
     127,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_77',        -- C Name
     'Write Protect Program Flash Page 77',-- Description
     127,              -- Bit Mask
     77                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_78',        -- C Name
     'Write Protect Program Flash Page 78',-- Description
     127,              -- Bit Mask
     78                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_79',        -- C Name
     'Write Protect Program Flash Page 79',-- Description
     127,              -- Bit Mask
     79                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_80',        -- C Name
     'Write Protect Program Flash Page 80',-- Description
     127,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_81',        -- C Name
     'Write Protect Program Flash Page 81',-- Description
     127,              -- Bit Mask
     81                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_82',        -- C Name
     'Write Protect Program Flash Page 82',-- Description
     127,              -- Bit Mask
     82                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_83',        -- C Name
     'Write Protect Program Flash Page 83',-- Description
     127,              -- Bit Mask
     83                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_84',        -- C Name
     'Write Protect Program Flash Page 84',-- Description
     127,              -- Bit Mask
     84                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_85',        -- C Name
     'Write Protect Program Flash Page 85',-- Description
     127,              -- Bit Mask
     85                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_86',        -- C Name
     'Write Protect Program Flash Page 86',-- Description
     127,              -- Bit Mask
     86                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_87',        -- C Name
     'Write Protect Program Flash Page 87',-- Description
     127,              -- Bit Mask
     87                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_88',        -- C Name
     'Write Protect Program Flash Page 88',-- Description
     127,              -- Bit Mask
     88                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_89',        -- C Name
     'Write Protect Program Flash Page 89',-- Description
     127,              -- Bit Mask
     89                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_90',        -- C Name
     'Write Protect Program Flash Page 90',-- Description
     127,              -- Bit Mask
     90                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_91',        -- C Name
     'Write Protect Program Flash Page 91',-- Description
     127,              -- Bit Mask
     91                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_92',        -- C Name
     'Write Protect Program Flash Page 92',-- Description
     127,              -- Bit Mask
     92                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_93',        -- C Name
     'Write Protect Program Flash Page 93',-- Description
     127,              -- Bit Mask
     93                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_94',        -- C Name
     'Write Protect Program Flash Page 94',-- Description
     127,              -- Bit Mask
     94                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_95',        -- C Name
     'Write Protect Program Flash Page 95',-- Description
     127,              -- Bit Mask
     95                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_96',        -- C Name
     'Write Protect Program Flash Page 96',-- Description
     127,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_97',        -- C Name
     'Write Protect Program Flash Page 97',-- Description
     127,              -- Bit Mask
     97                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_98',        -- C Name
     'Write Protect Program Flash Page 98',-- Description
     127,              -- Bit Mask
     98                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_99',        -- C Name
     'Write Protect Program Flash Page 99',-- Description
     127,              -- Bit Mask
     99                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_100',       -- C Name
     'Write Protect Program Flash Page 100',-- Description
     127,              -- Bit Mask
     100               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_101',       -- C Name
     'Write Protect Program Flash Page 101',-- Description
     127,              -- Bit Mask
     101               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_102',       -- C Name
     'Write Protect Program Flash Page 102',-- Description
     127,              -- Bit Mask
     102               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_103',       -- C Name
     'Write Protect Program Flash Page 103',-- Description
     127,              -- Bit Mask
     103               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_104',       -- C Name
     'Write Protect Program Flash Page 104',-- Description
     127,              -- Bit Mask
     104               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_105',       -- C Name
     'Write Protect Program Flash Page 105',-- Description
     127,              -- Bit Mask
     105               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_106',       -- C Name
     'Write Protect Program Flash Page 106',-- Description
     127,              -- Bit Mask
     106               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_107',       -- C Name
     'Write Protect Program Flash Page 107',-- Description
     127,              -- Bit Mask
     107               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_108',       -- C Name
     'Write Protect Program Flash Page 108',-- Description
     127,              -- Bit Mask
     108               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_109',       -- C Name
     'Write Protect Program Flash Page 109',-- Description
     127,              -- Bit Mask
     109               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_110',       -- C Name
     'Write Protect Program Flash Page 110',-- Description
     127,              -- Bit Mask
     110               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_111',       -- C Name
     'Write Protect Program Flash Page 111',-- Description
     127,              -- Bit Mask
     111               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_112',       -- C Name
     'Write Protect Program Flash Page 112',-- Description
     127,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_113',       -- C Name
     'Write Protect Program Flash Page 113',-- Description
     127,              -- Bit Mask
     113               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_114',       -- C Name
     'Write Protect Program Flash Page 114',-- Description
     127,              -- Bit Mask
     114               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_115',       -- C Name
     'Write Protect Program Flash Page 115',-- Description
     127,              -- Bit Mask
     115               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_116',       -- C Name
     'Write Protect Program Flash Page 116',-- Description
     127,              -- Bit Mask
     116               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_117',       -- C Name
     'Write Protect Program Flash Page 117',-- Description
     127,              -- Bit Mask
     117               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_118',       -- C Name
     'Write Protect Program Flash Page 118',-- Description
     127,              -- Bit Mask
     118               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_119',       -- C Name
     'Write Protect Program Flash Page 119',-- Description
     127,              -- Bit Mask
     119               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_120',       -- C Name
     'Write Protect Program Flash Page 120',-- Description
     127,              -- Bit Mask
     120               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_121',       -- C Name
     'Write Protect Program Flash Page 121',-- Description
     127,              -- Bit Mask
     121               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_122',       -- C Name
     'Write Protect Program Flash Page 122',-- Description
     127,              -- Bit Mask
     122               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_123',       -- C Name
     'Write Protect Program Flash Page 123',-- Description
     127,              -- Bit Mask
     123               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_124',       -- C Name
     'Write Protect Program Flash Page 124',-- Description
     127,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_125',       -- C Name
     'Write Protect Program Flash Page 125',-- Description
     127,              -- Bit Mask
     125               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_126',       -- C Name
     'Write Protect Program Flash Page 126',-- Description
     127,              -- Bit Mask
     126               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_127',       -- C Name
     'Write Protect Program Flash Page 127',-- Description
     127,              -- Bit Mask
     127               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     131071,           -- Address
     243,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     723,              -- Device ID
     4,                -- Family ID
     'PIC18LF27J53',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     251,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     131070,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     127,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     127,              -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     127,              -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     127,              -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     127,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     127,              -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     127,              -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     127,              -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     127,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     127,              -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     127,              -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     127,              -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     127,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     127,              -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     127,              -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     127,              -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     127,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     127,              -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     127,              -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     127,              -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     127,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     127,              -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     127,              -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     127,              -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     127,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     127,              -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     127,              -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     127,              -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     127,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     127,              -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     127,              -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     127,              -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     127,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     127,              -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     127,              -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     127,              -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     127,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     127,              -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     127,              -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     127,              -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     127,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     127,              -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     127,              -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     127,              -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     127,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     127,              -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     127,              -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     127,              -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     127,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     127,              -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     127,              -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     127,              -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     127,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     127,              -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     127,              -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     127,              -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     127,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     127,              -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     127,              -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     127,              -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     127,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     127,              -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     127,              -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     127,              -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_64',        -- C Name
     'Write Protect Program Flash Page 64',-- Description
     127,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_65',        -- C Name
     'Write Protect Program Flash Page 65',-- Description
     127,              -- Bit Mask
     65                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_66',        -- C Name
     'Write Protect Program Flash Page 66',-- Description
     127,              -- Bit Mask
     66                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_67',        -- C Name
     'Write Protect Program Flash Page 67',-- Description
     127,              -- Bit Mask
     67                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_68',        -- C Name
     'Write Protect Program Flash Page 68',-- Description
     127,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_69',        -- C Name
     'Write Protect Program Flash Page 69',-- Description
     127,              -- Bit Mask
     69                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_70',        -- C Name
     'Write Protect Program Flash Page 70',-- Description
     127,              -- Bit Mask
     70                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_71',        -- C Name
     'Write Protect Program Flash Page 71',-- Description
     127,              -- Bit Mask
     71                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_72',        -- C Name
     'Write Protect Program Flash Page 72',-- Description
     127,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_73',        -- C Name
     'Write Protect Program Flash Page 73',-- Description
     127,              -- Bit Mask
     73                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_74',        -- C Name
     'Write Protect Program Flash Page 74',-- Description
     127,              -- Bit Mask
     74                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_75',        -- C Name
     'Write Protect Program Flash Page 75',-- Description
     127,              -- Bit Mask
     75                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_76',        -- C Name
     'Write Protect Program Flash Page 76',-- Description
     127,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_77',        -- C Name
     'Write Protect Program Flash Page 77',-- Description
     127,              -- Bit Mask
     77                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_78',        -- C Name
     'Write Protect Program Flash Page 78',-- Description
     127,              -- Bit Mask
     78                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_79',        -- C Name
     'Write Protect Program Flash Page 79',-- Description
     127,              -- Bit Mask
     79                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_80',        -- C Name
     'Write Protect Program Flash Page 80',-- Description
     127,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_81',        -- C Name
     'Write Protect Program Flash Page 81',-- Description
     127,              -- Bit Mask
     81                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_82',        -- C Name
     'Write Protect Program Flash Page 82',-- Description
     127,              -- Bit Mask
     82                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_83',        -- C Name
     'Write Protect Program Flash Page 83',-- Description
     127,              -- Bit Mask
     83                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_84',        -- C Name
     'Write Protect Program Flash Page 84',-- Description
     127,              -- Bit Mask
     84                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_85',        -- C Name
     'Write Protect Program Flash Page 85',-- Description
     127,              -- Bit Mask
     85                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_86',        -- C Name
     'Write Protect Program Flash Page 86',-- Description
     127,              -- Bit Mask
     86                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_87',        -- C Name
     'Write Protect Program Flash Page 87',-- Description
     127,              -- Bit Mask
     87                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_88',        -- C Name
     'Write Protect Program Flash Page 88',-- Description
     127,              -- Bit Mask
     88                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_89',        -- C Name
     'Write Protect Program Flash Page 89',-- Description
     127,              -- Bit Mask
     89                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_90',        -- C Name
     'Write Protect Program Flash Page 90',-- Description
     127,              -- Bit Mask
     90                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_91',        -- C Name
     'Write Protect Program Flash Page 91',-- Description
     127,              -- Bit Mask
     91                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_92',        -- C Name
     'Write Protect Program Flash Page 92',-- Description
     127,              -- Bit Mask
     92                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_93',        -- C Name
     'Write Protect Program Flash Page 93',-- Description
     127,              -- Bit Mask
     93                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_94',        -- C Name
     'Write Protect Program Flash Page 94',-- Description
     127,              -- Bit Mask
     94                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_95',        -- C Name
     'Write Protect Program Flash Page 95',-- Description
     127,              -- Bit Mask
     95                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_96',        -- C Name
     'Write Protect Program Flash Page 96',-- Description
     127,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_97',        -- C Name
     'Write Protect Program Flash Page 97',-- Description
     127,              -- Bit Mask
     97                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_98',        -- C Name
     'Write Protect Program Flash Page 98',-- Description
     127,              -- Bit Mask
     98                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_99',        -- C Name
     'Write Protect Program Flash Page 99',-- Description
     127,              -- Bit Mask
     99                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_100',       -- C Name
     'Write Protect Program Flash Page 100',-- Description
     127,              -- Bit Mask
     100               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_101',       -- C Name
     'Write Protect Program Flash Page 101',-- Description
     127,              -- Bit Mask
     101               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_102',       -- C Name
     'Write Protect Program Flash Page 102',-- Description
     127,              -- Bit Mask
     102               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_103',       -- C Name
     'Write Protect Program Flash Page 103',-- Description
     127,              -- Bit Mask
     103               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_104',       -- C Name
     'Write Protect Program Flash Page 104',-- Description
     127,              -- Bit Mask
     104               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_105',       -- C Name
     'Write Protect Program Flash Page 105',-- Description
     127,              -- Bit Mask
     105               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_106',       -- C Name
     'Write Protect Program Flash Page 106',-- Description
     127,              -- Bit Mask
     106               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_107',       -- C Name
     'Write Protect Program Flash Page 107',-- Description
     127,              -- Bit Mask
     107               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_108',       -- C Name
     'Write Protect Program Flash Page 108',-- Description
     127,              -- Bit Mask
     108               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_109',       -- C Name
     'Write Protect Program Flash Page 109',-- Description
     127,              -- Bit Mask
     109               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_110',       -- C Name
     'Write Protect Program Flash Page 110',-- Description
     127,              -- Bit Mask
     110               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_111',       -- C Name
     'Write Protect Program Flash Page 111',-- Description
     127,              -- Bit Mask
     111               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_112',       -- C Name
     'Write Protect Program Flash Page 112',-- Description
     127,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_113',       -- C Name
     'Write Protect Program Flash Page 113',-- Description
     127,              -- Bit Mask
     113               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_114',       -- C Name
     'Write Protect Program Flash Page 114',-- Description
     127,              -- Bit Mask
     114               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_115',       -- C Name
     'Write Protect Program Flash Page 115',-- Description
     127,              -- Bit Mask
     115               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_116',       -- C Name
     'Write Protect Program Flash Page 116',-- Description
     127,              -- Bit Mask
     116               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_117',       -- C Name
     'Write Protect Program Flash Page 117',-- Description
     127,              -- Bit Mask
     117               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_118',       -- C Name
     'Write Protect Program Flash Page 118',-- Description
     127,              -- Bit Mask
     118               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_119',       -- C Name
     'Write Protect Program Flash Page 119',-- Description
     127,              -- Bit Mask
     119               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_120',       -- C Name
     'Write Protect Program Flash Page 120',-- Description
     127,              -- Bit Mask
     120               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_121',       -- C Name
     'Write Protect Program Flash Page 121',-- Description
     127,              -- Bit Mask
     121               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_122',       -- C Name
     'Write Protect Program Flash Page 122',-- Description
     127,              -- Bit Mask
     122               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_123',       -- C Name
     'Write Protect Program Flash Page 123',-- Description
     127,              -- Bit Mask
     123               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_124',       -- C Name
     'Write Protect Program Flash Page 124',-- Description
     127,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_125',       -- C Name
     'Write Protect Program Flash Page 125',-- Description
     127,              -- Bit Mask
     125               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_126',       -- C Name
     'Write Protect Program Flash Page 126',-- Description
     127,              -- Bit Mask
     126               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_127',       -- C Name
     'Write Protect Program Flash Page 127',-- Description
     127,              -- Bit Mask
     127               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     131071,           -- Address
     251,              -- Default Value
     11                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LS48MHZ',        -- C Name
     'Low Speed USB mode with 48 MHz system clock bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS24X4',        -- C Name
     'System clock at 24 MHz USB CLKEN divide-by is set to 4',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS48X8',        -- C Name
     'System clock at 48 MHz USB CLKEN divide-by is set to 8',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);


insert into DEVICES values (
     null,
     697,              -- Device ID
     4,                -- Family ID
     'PIC18LF43K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     8192,             -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     512               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE0',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RE0',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTD2',         -- C Name
     'P2B is on RD2',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0001FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0001FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000200-000FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000200-000FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (001000-001FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (001000-001FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0001FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0001FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     235,              -- Device ID
     4,                -- Family ID
     'PIC18LF44J10',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16382,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     255,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     247,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     255,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     255,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     629,              -- Device ID
     4,                -- Family ID
     'PIC18LF44J11',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16384,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     16382,            -- Address
     207,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     16383,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     617,              -- Device ID
     4,                -- Family ID
     'PIC18LF44J50',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     16376,            -- Start of Config Bits
     16384,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     16376,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     16377,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     16378,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     16379,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     16380,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     16381,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     16382,            -- Address
     207,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     16383,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     689,              -- Device ID
     4,                -- Family ID
     'PIC18LF44K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     16384,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     768               -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE0',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RE0',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTD2',         -- C Name
     'P2B is on RD2',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     3,                -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     227,              -- Device ID
     4,                -- Family ID
     'PIC18LF45J10',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32766,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1024              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     255,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT enabled',    -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled (control is placed on SWDTEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Reset on stack overflow/underflow enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Reset on stack overflow/underflow disabled',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debugger Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Background debugger disabled; RB6 and RB7 configured as general purpose I/O pins',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Background debugger enabled; RB6 and RB7 are dedicated to In-Circuit Debug',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     247,              -- Default Value
     252               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     255,              -- Default Value
     199               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC oscillator, PLL enabled and under software control, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC oscillator, CLKO function on OSC2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS oscillator, PLL enabled and under software control',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS oscillator',  -- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC2',          -- C Name
     'Default/Reset System Clock Select bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Clock selected by FOSC as system clock is enabled when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'INTRC enabled as system clock when OSCCON<1:0> = 00',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Two-Speed Start-up (Internal/External Oscillator Switchover) Control bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Two-Speed Start-up enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Two-Speed Start-up disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     255,              -- Default Value
     241               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DEFAULT',        -- C Name
     'CCP2 is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ALTERNATE',      -- C Name
     'CCP2 is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     630,              -- Device ID
     4,                -- Family ID
     'PIC18LF45J11',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32768,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     32766,            -- Address
     223,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     31,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     31,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     31,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     31,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     31,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     31,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     31,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     31,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     31,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     31,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     31,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     31,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     31,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     31,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     31,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     31,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     31,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     31,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     31,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     31,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     31,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     31,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     31,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     31,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     31,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     31,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     31,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     31,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     31,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     31,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     31,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     31,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     32767,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     618,              -- Device ID
     4,                -- Family ID
     'PIC18LF45J50',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     32760,            -- Start of Config Bits
     32768,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     32760,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     32761,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     32762,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     32763,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     32764,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     32765,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     32766,            -- Address
     223,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     31,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     31,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     31,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     31,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     31,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     31,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     31,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     31,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     31,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     31,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     31,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     31,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     31,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     31,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     31,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     31,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     31,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     31,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     31,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     31,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     31,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     31,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     31,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     31,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     31,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     31,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     31,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     31,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     31,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     31,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     31,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     31,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     32767,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     681,              -- Device ID
     4,                -- Family ID
     'PIC18LF45K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15728896,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     1536              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE0',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RE0',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTD2',         -- C Name
     'P2B is on RD2',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-001FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-001FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (002000-003FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (002000-003FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (004000-005FFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (004000-005FFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (006000-007FFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (006000-007FFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     786,              -- Device ID
     4,                -- Family ID
     'PIC18LF45K80',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECAN TX and RX pins are located on RC6 and RC7, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     631,              -- Device ID
     4,                -- Family ID
     'PIC18LF46J11',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     225,              -- Default Value
     225               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     733,              -- Device ID
     4,                -- Family ID
     'PIC18LF46J13',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     '96MHz PLL Prescaler Selection (PLLSEL=0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLSEL',         -- C Name
     'PLL Selection Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL96',          -- C Name
     'Selects 96MHz PLL',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL4X',          -- C Name
     'Selects 4x PLL', -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     243,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     619,              -- Device ID
     4,                -- Family ID
     'PIC18LF46J50',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3776              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     239,              -- Default Value
     239               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     223,              -- Default Value
     223               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T1DIG',          -- C Name
     'T1OSCEN Enforcement'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Secondary Oscillator clock source may be selected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Secondary Oscillator clock source may not be selected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LPT1OSC',        -- C Name
     'Low-Power Timer1 Oscillator'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'High-power operation',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Low-power operation',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     249,              -- Default Value
     249               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Page WPFP<5:0> through Configuration Words erase/write protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Page 0 through WPFP<5:0> erase/write protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     241,              -- Default Value
     1                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<5:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<5:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     725,              -- Device ID
     4,                -- Family ID
     'PIC18LF46J53',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     65528,            -- Start of Config Bits
     65536,            -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     65528,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     65529,            -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     65530,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     65531,            -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     65532,            -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     65533,            -- Address
     251,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     65534,            -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     63,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     63,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     63,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     63,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     63,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     63,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     63,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     63,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     63,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     63,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     63,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     63,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     63,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     63,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     63,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     63,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     63,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     63,               -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     63,               -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     63,               -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     63,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     63,               -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     63,               -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     63,               -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     63,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     63,               -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     63,               -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     63,               -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     63,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     63,               -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     63,               -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     63,               -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     63,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     63,               -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     63,               -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     63,               -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     63,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     63,               -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     63,               -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     63,               -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     63,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     63,               -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     63,               -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     63,               -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     63,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     63,               -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     63,               -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     63,               -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     63,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     63,               -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     63,               -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     63,               -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     63,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     63,               -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     63,               -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     63,               -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     63,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     63,               -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     63,               -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     63,               -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     63,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     63,               -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     63,               -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     63,               -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     65535,            -- Address
     251,              -- Default Value
     11                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LS48MHZ',        -- C Name
     'Low Speed USB mode with 48 MHz system clock bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS24X4',        -- C Name
     'System clock at 24 MHz USB CLKEN divide-by is set to 4',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS48X8',        -- C Name
     'System clock at 48 MHz USB CLKEN divide-by is set to 8',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);


insert into DEVICES values (
     null,
     673,              -- Device ID
     4,                -- Family ID
     'PIC18LF46K22',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3896              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     37,               -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator Selection bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     '111X External RC oscillator, CLKOUT function on RA6',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLPIO6',        -- C Name
     'EC oscillator (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECLP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (low power, <500 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMPIO6',        -- C Name
     'EC oscillator (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECMP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (medium power, 500 kHz-16 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO7',         -- C Name
     'Internal oscillator block, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO67',        -- C Name
     'Internal oscillator block',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO6',          -- C Name
     'External RC oscillator',-- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHPIO6',        -- C Name
     'EC oscillator (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECHP',           -- C Name
     'EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSMP',           -- C Name
     'HS oscillator (medium power 4-16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSHP',           -- C Name
     'HS oscillator (high power > 16 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     '4X PLL Enable'   -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator used directly',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator multiplied by 4',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PRICLKEN',       -- C Name
     'Primary clock enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Primary clock can be disabled by software',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Primary clock is always enabled',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Fail-Safe Clock Monitor disabled',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Fail-Safe Clock Monitor enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal/External Oscillator Switchover bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Oscillator Switchover mode disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Oscillator Switchover mode enabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     31,               -- Default Value
     31                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power-up Timer Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Power up timer disabled',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Power up timer enabled',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown-out Reset Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Brown-out Reset enabled in hardware only (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Brown-out Reset enabled and controlled by software (SBOREN is enabled)',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Brown-out Reset disabled in hardware and software',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown Out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '190',            -- C Name
     'VBOR set to 1.90 V nominal',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '220',            -- C Name
     'VBOR set to 2.20 V nominal',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '250',            -- C Name
     'VBOR set to 2.50 V nominal',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '285',            -- C Name
     'VBOR set to 2.85 V nominal',-- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     63,               -- Default Value
     63                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer Enable bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT is always enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWON',           -- C Name
     'WDT is controlled by SWDTEN bit of the WDTCON register',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT is disabled in sleep, otherwise enabled. SWDTEN bit has no effect',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Watch dog timer is always disabled. SWDTEN has no effect.',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Timer Postscale Select bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     60,               -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     60,               -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     60,               -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     60,               -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     60,               -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     60,               -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     60,               -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     60,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     60,               -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     60,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     60,               -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     60,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     60,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     60,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     60,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     60,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     191,              -- Default Value
     191               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP2MX',         -- C Name
     'CCP2 MUX bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC1',         -- C Name
     'CCP2 input/output is multiplexed with RC1',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB3',         -- C Name
     'CCP2 input/output is multiplexed with RB3',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PBADEN',         -- C Name
     'PORTB A/D Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PORTB<5:0> pins are configured as analog input channels on Reset',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PORTB<5:0> pins are configured as digital I/O on Reset',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CCP3MX',         -- C Name
     'P3A/CCP3 Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'P3A/CCP3 input/output is multiplexed with RB5',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE0',         -- C Name
     'P3A/CCP3 input/output is mulitplexed with RE0',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'HFOFST',         -- C Name
     'HFINTOSC Fast Start-up'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'HFINTOSC output and ready status are not delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'HFINTOSC output and ready status are delayed by the oscillator stable status',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CMX',          -- C Name
     'Timer3 Clock input mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'T3CKI is on RC0',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB5',         -- C Name
     'T3CKI is on RB5',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'P2BMX',          -- C Name
     'ECCP2 B output mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTD2',         -- C Name
     'P2B is on RD2',  -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC0',         -- C Name
     'P2B is on RC0',  -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'MCLR Pin Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EXTMCLR',        -- C Name
     'MCLR pin enabled, RE3 input pin disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTMCLR',        -- C Name
     'RE3 input pin enabled; MCLR disabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     133,              -- Default Value
     197               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Full/Underflow Reset Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Stack full/underflow will cause Reset',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Stack full/underflow will not cause Reset',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LVP',            -- C Name
     'Single-Supply ICSP Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Single-Supply ICSP enabled if MCLRE is also 1',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Single-Supply ICSP disabled',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Instruction set extension and Indexed Addressing mode enabled',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Instruction set extension and Indexed Addressing mode disabled (Legacy mode)',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DEBUG',          -- C Name
     'Background Debug'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not code-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) code-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not code-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) code-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not code-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) code-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Boot Block Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot block (000000-0007FFh) not code-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot block (000000-0007FFh) code-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EEPROM Code Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not code-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM code-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Write Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not write-protected',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) write-protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Write Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not write-protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) write-protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Write Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not write-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) write-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Write Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not write-protected',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) write-protected',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Configuration Register Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration registers (300000-3000FFh) not write-protected',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration registers (300000-3000FFh) write-protected',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Boot Block Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not write-protected',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) write-protected',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EEPROM Write Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Data EEPROM not write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Data EEPROM write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protection Block 0'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 0 (000800-003FFFh) not protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 0 (000800-003FFFh) protected from table reads executed in other blocks',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protection Block 1'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 1 (004000-007FFFh) not protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 1 (004000-007FFFh) protected from table reads executed in other blocks',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protection Block 2'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 2 (008000-00BFFFh) protected from table reads executed in other blocks',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protection Block 3'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Block 3 (00C000-00FFFFh) protected from table reads executed in other blocks',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Boot Block Table Read Protection bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Boot Block (000000-0007FFh) not protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Boot Block (000000-0007FFh) protected from table reads executed in other blocks',-- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     783,              -- Device ID
     4,                -- Family ID
     'PIC18LF46K80',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     137,              -- Default Value
     137               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTC',          -- C Name
     'ECAN TX and RX pins are located on RC6 and RC7, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     735,              -- Device ID
     4,                -- Family ID
     'PIC18LF47J13',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     '96MHz PLL Prescaler Selection (PLLSEL=0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     244,              -- Default Value
     12                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6)',  -- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL',         -- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS',             -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLSEL',         -- C Name
     'PLL Selection Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL96',          -- C Name
     'Selects 96MHz PLL',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PLL4X',          -- C Name
     'Selects 4x PLL', -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     131070,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     127,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     127,              -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     127,              -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     127,              -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     127,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     127,              -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     127,              -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     127,              -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     127,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     127,              -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     127,              -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     127,              -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     127,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     127,              -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     127,              -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     127,              -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     127,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     127,              -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     127,              -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     127,              -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     127,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     127,              -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     127,              -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     127,              -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     127,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     127,              -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     127,              -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     127,              -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     127,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     127,              -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     127,              -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     127,              -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     127,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     127,              -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     127,              -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     127,              -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     127,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     127,              -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     127,              -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     127,              -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     127,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     127,              -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     127,              -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     127,              -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     127,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     127,              -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     127,              -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     127,              -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     127,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     127,              -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     127,              -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     127,              -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     127,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     127,              -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     127,              -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     127,              -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     127,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     127,              -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     127,              -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     127,              -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     127,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     127,              -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     127,              -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     127,              -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_64',        -- C Name
     'Write Protect Program Flash Page 64',-- Description
     127,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_65',        -- C Name
     'Write Protect Program Flash Page 65',-- Description
     127,              -- Bit Mask
     65                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_66',        -- C Name
     'Write Protect Program Flash Page 66',-- Description
     127,              -- Bit Mask
     66                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_67',        -- C Name
     'Write Protect Program Flash Page 67',-- Description
     127,              -- Bit Mask
     67                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_68',        -- C Name
     'Write Protect Program Flash Page 68',-- Description
     127,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_69',        -- C Name
     'Write Protect Program Flash Page 69',-- Description
     127,              -- Bit Mask
     69                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_70',        -- C Name
     'Write Protect Program Flash Page 70',-- Description
     127,              -- Bit Mask
     70                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_71',        -- C Name
     'Write Protect Program Flash Page 71',-- Description
     127,              -- Bit Mask
     71                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_72',        -- C Name
     'Write Protect Program Flash Page 72',-- Description
     127,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_73',        -- C Name
     'Write Protect Program Flash Page 73',-- Description
     127,              -- Bit Mask
     73                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_74',        -- C Name
     'Write Protect Program Flash Page 74',-- Description
     127,              -- Bit Mask
     74                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_75',        -- C Name
     'Write Protect Program Flash Page 75',-- Description
     127,              -- Bit Mask
     75                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_76',        -- C Name
     'Write Protect Program Flash Page 76',-- Description
     127,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_77',        -- C Name
     'Write Protect Program Flash Page 77',-- Description
     127,              -- Bit Mask
     77                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_78',        -- C Name
     'Write Protect Program Flash Page 78',-- Description
     127,              -- Bit Mask
     78                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_79',        -- C Name
     'Write Protect Program Flash Page 79',-- Description
     127,              -- Bit Mask
     79                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_80',        -- C Name
     'Write Protect Program Flash Page 80',-- Description
     127,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_81',        -- C Name
     'Write Protect Program Flash Page 81',-- Description
     127,              -- Bit Mask
     81                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_82',        -- C Name
     'Write Protect Program Flash Page 82',-- Description
     127,              -- Bit Mask
     82                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_83',        -- C Name
     'Write Protect Program Flash Page 83',-- Description
     127,              -- Bit Mask
     83                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_84',        -- C Name
     'Write Protect Program Flash Page 84',-- Description
     127,              -- Bit Mask
     84                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_85',        -- C Name
     'Write Protect Program Flash Page 85',-- Description
     127,              -- Bit Mask
     85                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_86',        -- C Name
     'Write Protect Program Flash Page 86',-- Description
     127,              -- Bit Mask
     86                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_87',        -- C Name
     'Write Protect Program Flash Page 87',-- Description
     127,              -- Bit Mask
     87                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_88',        -- C Name
     'Write Protect Program Flash Page 88',-- Description
     127,              -- Bit Mask
     88                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_89',        -- C Name
     'Write Protect Program Flash Page 89',-- Description
     127,              -- Bit Mask
     89                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_90',        -- C Name
     'Write Protect Program Flash Page 90',-- Description
     127,              -- Bit Mask
     90                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_91',        -- C Name
     'Write Protect Program Flash Page 91',-- Description
     127,              -- Bit Mask
     91                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_92',        -- C Name
     'Write Protect Program Flash Page 92',-- Description
     127,              -- Bit Mask
     92                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_93',        -- C Name
     'Write Protect Program Flash Page 93',-- Description
     127,              -- Bit Mask
     93                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_94',        -- C Name
     'Write Protect Program Flash Page 94',-- Description
     127,              -- Bit Mask
     94                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_95',        -- C Name
     'Write Protect Program Flash Page 95',-- Description
     127,              -- Bit Mask
     95                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_96',        -- C Name
     'Write Protect Program Flash Page 96',-- Description
     127,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_97',        -- C Name
     'Write Protect Program Flash Page 97',-- Description
     127,              -- Bit Mask
     97                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_98',        -- C Name
     'Write Protect Program Flash Page 98',-- Description
     127,              -- Bit Mask
     98                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_99',        -- C Name
     'Write Protect Program Flash Page 99',-- Description
     127,              -- Bit Mask
     99                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_100',       -- C Name
     'Write Protect Program Flash Page 100',-- Description
     127,              -- Bit Mask
     100               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_101',       -- C Name
     'Write Protect Program Flash Page 101',-- Description
     127,              -- Bit Mask
     101               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_102',       -- C Name
     'Write Protect Program Flash Page 102',-- Description
     127,              -- Bit Mask
     102               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_103',       -- C Name
     'Write Protect Program Flash Page 103',-- Description
     127,              -- Bit Mask
     103               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_104',       -- C Name
     'Write Protect Program Flash Page 104',-- Description
     127,              -- Bit Mask
     104               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_105',       -- C Name
     'Write Protect Program Flash Page 105',-- Description
     127,              -- Bit Mask
     105               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_106',       -- C Name
     'Write Protect Program Flash Page 106',-- Description
     127,              -- Bit Mask
     106               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_107',       -- C Name
     'Write Protect Program Flash Page 107',-- Description
     127,              -- Bit Mask
     107               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_108',       -- C Name
     'Write Protect Program Flash Page 108',-- Description
     127,              -- Bit Mask
     108               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_109',       -- C Name
     'Write Protect Program Flash Page 109',-- Description
     127,              -- Bit Mask
     109               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_110',       -- C Name
     'Write Protect Program Flash Page 110',-- Description
     127,              -- Bit Mask
     110               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_111',       -- C Name
     'Write Protect Program Flash Page 111',-- Description
     127,              -- Bit Mask
     111               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_112',       -- C Name
     'Write Protect Program Flash Page 112',-- Description
     127,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_113',       -- C Name
     'Write Protect Program Flash Page 113',-- Description
     127,              -- Bit Mask
     113               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_114',       -- C Name
     'Write Protect Program Flash Page 114',-- Description
     127,              -- Bit Mask
     114               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_115',       -- C Name
     'Write Protect Program Flash Page 115',-- Description
     127,              -- Bit Mask
     115               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_116',       -- C Name
     'Write Protect Program Flash Page 116',-- Description
     127,              -- Bit Mask
     116               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_117',       -- C Name
     'Write Protect Program Flash Page 117',-- Description
     127,              -- Bit Mask
     117               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_118',       -- C Name
     'Write Protect Program Flash Page 118',-- Description
     127,              -- Bit Mask
     118               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_119',       -- C Name
     'Write Protect Program Flash Page 119',-- Description
     127,              -- Bit Mask
     119               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_120',       -- C Name
     'Write Protect Program Flash Page 120',-- Description
     127,              -- Bit Mask
     120               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_121',       -- C Name
     'Write Protect Program Flash Page 121',-- Description
     127,              -- Bit Mask
     121               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_122',       -- C Name
     'Write Protect Program Flash Page 122',-- Description
     127,              -- Bit Mask
     122               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_123',       -- C Name
     'Write Protect Program Flash Page 123',-- Description
     127,              -- Bit Mask
     123               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_124',       -- C Name
     'Write Protect Program Flash Page 124',-- Description
     127,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_125',       -- C Name
     'Write Protect Program Flash Page 125',-- Description
     127,              -- Bit Mask
     125               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_126',       -- C Name
     'Write Protect Program Flash Page 126',-- Description
     127,              -- Bit Mask
     126               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_127',       -- C Name
     'Write Protect Program Flash Page 127',-- Description
     127,              -- Bit Mask
     127               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     131071,           -- Address
     243,              -- Default Value
     3                 -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     727,              -- Device ID
     4,                -- Family ID
     'PIC18LF47J53',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     1024,             -- Erase FLASH Page Size
     0,                -- Start of FLASH
     131072,           -- End of FLASH
     0,                -- Start of EEPROM
     0,                -- End of EEPROM
     0,                -- Start of User ID
     0,                -- End of User ID
     131064,           -- Start of Config Bits
     131072,           -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3760              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     131064,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled - Controlled by SWDTEN bit',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLDIV',         -- C Name
     'PLL Prescaler Selection'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     'No prescale (4 MHz oscillator input drives PLL directly)',-- Description
     14,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     'Divide by 2 (8 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     'Divide by 3 (12 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     'Divide by 4 (16 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '5',              -- C Name
     'Divide by 5 (20 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '6',              -- C Name
     'Divide by 6 (24 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '10',             -- C Name
     'Divide by 10 (40 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '12',             -- C Name
     'Divide by 12 (48 MHz oscillator input)',-- Description
     14,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CFGPLLEN',       -- C Name
     'PLL Enable Configuration Bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'PLL Disabled',   -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'PLL Enabled',    -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow/Underflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     131065,           -- Address
     247,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPUDIV',         -- C Name
     'CPU System Clock Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC1',           -- C Name
     'No CPU system clock divide',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC2_PLL2',      -- C Name
     'CPU system clock divide by 2',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC3_PLL3',      -- C Name
     'CPU system clock divide by 3',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OSC4_PLL6',      -- C Name
     'CPU system clock divide by 6',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Program memory is not code-protected',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Program memory is code-protected',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     131066,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'OSC',            -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ECPLL',          -- C Name
     'EC+PLL (CLKO-RA6), USB-EC+PLL',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC',             -- C Name
     'EC (CLKO-RA6), USB-EC',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HSPLL',          -- C Name
     'HS+PLL, USB-HS+PLL',-- Description
     7,                -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS',             -- C Name
     'HS, USB-HS',     -- Description
     7,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLLO',     -- C Name
     'INTOSCPLLO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCPLL',      -- C Name
     'INTOSCPLL',      -- Description
     7,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCO',        -- C Name
     'INTOSCO (CLKO-RA6)',-- Description
     7,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSC',         -- C Name
     'INTOSC',         -- Description
     7,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'T1OSC/SOSC Power Selection Bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode selected',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power T1OSC/SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RESERVED',       -- C Name
     'Reserved',       -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CLKOEC',         -- C Name
     'EC Clock Out Enable Bit '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'CLKO output enabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'CLKO output disabled on the RA6 pin',-- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     131067,           -- Address
     255,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     15,               -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     15,               -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     15,               -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     15,               -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3L',       -- Config Name
     131068,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTOSC',       -- C Name
     'DSWDT Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'DSWDT uses INTRC',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'DSWDT uses T1OSC/T1CKI',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RTCOSC',         -- C Name
     'RTCC Clock Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'T1OSCREF',       -- C Name
     'RTCC uses T1OSC/T1CKI',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTOSCREF',      -- C Name
     'RTCC uses INTRC',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSBOREN',        -- C Name
     'Deep Sleep BOR'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTEN',        -- C Name
     'Deep Sleep Watchdog Timer'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'DSWDTPS',        -- C Name
     'Deep Sleep Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'G2',             -- C Name
     '1:2,147,483,648 (25.7 days)',-- Description
     240,              -- Bit Mask
     240               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M536',           -- C Name
     '1:536,870,912 (6.4 days)',-- Description
     240,              -- Bit Mask
     224               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M134',           -- C Name
     '1:134,217,728 (38.5 hours)',-- Description
     240,              -- Bit Mask
     208               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M33',            -- C Name
     '1:33,554,432 (9.6 hours)',-- Description
     240,              -- Bit Mask
     192               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M8',             -- C Name
     '1:8,388,608 (2.4 hours)',-- Description
     240,              -- Bit Mask
     176               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'M2',             -- C Name
     '1:2,097,152 (36 minutes)',-- Description
     240,              -- Bit Mask
     160               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K524',           -- C Name
     '1:524,288 (9 minutes)',-- Description
     240,              -- Bit Mask
     144               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K131',           -- C Name
     '1:131,072 (135 seconds)',-- Description
     240,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'K32',            -- C Name
     '1:32,768 (34 seconds)',-- Description
     240,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8,192 (8.5 seconds)',-- Description
     240,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2,048 (2.1 seconds)',-- Description
     240,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512 (528 ms)', -- Description
     240,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128 (132 ms)', -- Description
     240,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32 (33 ms)',   -- Description
     240,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8 (8.3 ms)',   -- Description
     240,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2 (2.1 ms)',   -- Description
     240,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     131069,           -- Address
     251,              -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IOL1WAY',        -- C Name
     'IOLOCK One-Way Set Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set once',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'The IOLOCK bit (PPSCON<0>) can be set and cleared as needed',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'ADCSEL',         -- C Name
     'ADC 10 or 12 Bit Select'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT10',          -- C Name
     '10 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BIT12',          -- C Name
     '12 - Bit ADC Enabled',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSP7B_EN',      -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 Bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     131070,           -- Address
     255,              -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPFP',           -- C Name
     'Write/Erase Protect Page Start/End Location'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Write Protect Program Flash Page 0',-- Description
     127,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_1',         -- C Name
     'Write Protect Program Flash Page 1',-- Description
     127,              -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_2',         -- C Name
     'Write Protect Program Flash Page 2',-- Description
     127,              -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_3',         -- C Name
     'Write Protect Program Flash Page 3',-- Description
     127,              -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_4',         -- C Name
     'Write Protect Program Flash Page 4',-- Description
     127,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_5',         -- C Name
     'Write Protect Program Flash Page 5',-- Description
     127,              -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_6',         -- C Name
     'Write Protect Program Flash Page 6',-- Description
     127,              -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_7',         -- C Name
     'Write Protect Program Flash Page 7',-- Description
     127,              -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_8',         -- C Name
     'Write Protect Program Flash Page 8',-- Description
     127,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_9',         -- C Name
     'Write Protect Program Flash Page 9',-- Description
     127,              -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_10',        -- C Name
     'Write Protect Program Flash Page 10',-- Description
     127,              -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_11',        -- C Name
     'Write Protect Program Flash Page 11',-- Description
     127,              -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_12',        -- C Name
     'Write Protect Program Flash Page 12',-- Description
     127,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_13',        -- C Name
     'Write Protect Program Flash Page 13',-- Description
     127,              -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_14',        -- C Name
     'Write Protect Program Flash Page 14',-- Description
     127,              -- Bit Mask
     14                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_15',        -- C Name
     'Write Protect Program Flash Page 15',-- Description
     127,              -- Bit Mask
     15                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_16',        -- C Name
     'Write Protect Program Flash Page 16',-- Description
     127,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_17',        -- C Name
     'Write Protect Program Flash Page 17',-- Description
     127,              -- Bit Mask
     17                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_18',        -- C Name
     'Write Protect Program Flash Page 18',-- Description
     127,              -- Bit Mask
     18                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_19',        -- C Name
     'Write Protect Program Flash Page 19',-- Description
     127,              -- Bit Mask
     19                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_20',        -- C Name
     'Write Protect Program Flash Page 20',-- Description
     127,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_21',        -- C Name
     'Write Protect Program Flash Page 21',-- Description
     127,              -- Bit Mask
     21                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_22',        -- C Name
     'Write Protect Program Flash Page 22',-- Description
     127,              -- Bit Mask
     22                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_23',        -- C Name
     'Write Protect Program Flash Page 23',-- Description
     127,              -- Bit Mask
     23                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_24',        -- C Name
     'Write Protect Program Flash Page 24',-- Description
     127,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_25',        -- C Name
     'Write Protect Program Flash Page 25',-- Description
     127,              -- Bit Mask
     25                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_26',        -- C Name
     'Write Protect Program Flash Page 26',-- Description
     127,              -- Bit Mask
     26                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_27',        -- C Name
     'Write Protect Program Flash Page 27',-- Description
     127,              -- Bit Mask
     27                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_28',        -- C Name
     'Write Protect Program Flash Page 28',-- Description
     127,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_29',        -- C Name
     'Write Protect Program Flash Page 29',-- Description
     127,              -- Bit Mask
     29                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_30',        -- C Name
     'Write Protect Program Flash Page 30',-- Description
     127,              -- Bit Mask
     30                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_31',        -- C Name
     'Write Protect Program Flash Page 31',-- Description
     127,              -- Bit Mask
     31                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_32',        -- C Name
     'Write Protect Program Flash Page 32',-- Description
     127,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_33',        -- C Name
     'Write Protect Program Flash Page 33',-- Description
     127,              -- Bit Mask
     33                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_34',        -- C Name
     'Write Protect Program Flash Page 34',-- Description
     127,              -- Bit Mask
     34                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_35',        -- C Name
     'Write Protect Program Flash Page 35',-- Description
     127,              -- Bit Mask
     35                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_36',        -- C Name
     'Write Protect Program Flash Page 36',-- Description
     127,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_37',        -- C Name
     'Write Protect Program Flash Page 37',-- Description
     127,              -- Bit Mask
     37                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_38',        -- C Name
     'Write Protect Program Flash Page 38',-- Description
     127,              -- Bit Mask
     38                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_39',        -- C Name
     'Write Protect Program Flash Page 39',-- Description
     127,              -- Bit Mask
     39                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_40',        -- C Name
     'Write Protect Program Flash Page 40',-- Description
     127,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_41',        -- C Name
     'Write Protect Program Flash Page 41',-- Description
     127,              -- Bit Mask
     41                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_42',        -- C Name
     'Write Protect Program Flash Page 42',-- Description
     127,              -- Bit Mask
     42                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_43',        -- C Name
     'Write Protect Program Flash Page 43',-- Description
     127,              -- Bit Mask
     43                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_44',        -- C Name
     'Write Protect Program Flash Page 44',-- Description
     127,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_45',        -- C Name
     'Write Protect Program Flash Page 45',-- Description
     127,              -- Bit Mask
     45                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_46',        -- C Name
     'Write Protect Program Flash Page 46',-- Description
     127,              -- Bit Mask
     46                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_47',        -- C Name
     'Write Protect Program Flash Page 47',-- Description
     127,              -- Bit Mask
     47                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_48',        -- C Name
     'Write Protect Program Flash Page 48',-- Description
     127,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_49',        -- C Name
     'Write Protect Program Flash Page 49',-- Description
     127,              -- Bit Mask
     49                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_50',        -- C Name
     'Write Protect Program Flash Page 50',-- Description
     127,              -- Bit Mask
     50                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_51',        -- C Name
     'Write Protect Program Flash Page 51',-- Description
     127,              -- Bit Mask
     51                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_52',        -- C Name
     'Write Protect Program Flash Page 52',-- Description
     127,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_53',        -- C Name
     'Write Protect Program Flash Page 53',-- Description
     127,              -- Bit Mask
     53                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_54',        -- C Name
     'Write Protect Program Flash Page 54',-- Description
     127,              -- Bit Mask
     54                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_55',        -- C Name
     'Write Protect Program Flash Page 55',-- Description
     127,              -- Bit Mask
     55                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_56',        -- C Name
     'Write Protect Program Flash Page 56',-- Description
     127,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_57',        -- C Name
     'Write Protect Program Flash Page 57',-- Description
     127,              -- Bit Mask
     57                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_58',        -- C Name
     'Write Protect Program Flash Page 58',-- Description
     127,              -- Bit Mask
     58                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_59',        -- C Name
     'Write Protect Program Flash Page 59',-- Description
     127,              -- Bit Mask
     59                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_60',        -- C Name
     'Write Protect Program Flash Page 60',-- Description
     127,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_61',        -- C Name
     'Write Protect Program Flash Page 61',-- Description
     127,              -- Bit Mask
     61                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_62',        -- C Name
     'Write Protect Program Flash Page 62',-- Description
     127,              -- Bit Mask
     62                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_63',        -- C Name
     'Write Protect Program Flash Page 63',-- Description
     127,              -- Bit Mask
     63                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_64',        -- C Name
     'Write Protect Program Flash Page 64',-- Description
     127,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_65',        -- C Name
     'Write Protect Program Flash Page 65',-- Description
     127,              -- Bit Mask
     65                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_66',        -- C Name
     'Write Protect Program Flash Page 66',-- Description
     127,              -- Bit Mask
     66                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_67',        -- C Name
     'Write Protect Program Flash Page 67',-- Description
     127,              -- Bit Mask
     67                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_68',        -- C Name
     'Write Protect Program Flash Page 68',-- Description
     127,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_69',        -- C Name
     'Write Protect Program Flash Page 69',-- Description
     127,              -- Bit Mask
     69                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_70',        -- C Name
     'Write Protect Program Flash Page 70',-- Description
     127,              -- Bit Mask
     70                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_71',        -- C Name
     'Write Protect Program Flash Page 71',-- Description
     127,              -- Bit Mask
     71                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_72',        -- C Name
     'Write Protect Program Flash Page 72',-- Description
     127,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_73',        -- C Name
     'Write Protect Program Flash Page 73',-- Description
     127,              -- Bit Mask
     73                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_74',        -- C Name
     'Write Protect Program Flash Page 74',-- Description
     127,              -- Bit Mask
     74                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_75',        -- C Name
     'Write Protect Program Flash Page 75',-- Description
     127,              -- Bit Mask
     75                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_76',        -- C Name
     'Write Protect Program Flash Page 76',-- Description
     127,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_77',        -- C Name
     'Write Protect Program Flash Page 77',-- Description
     127,              -- Bit Mask
     77                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_78',        -- C Name
     'Write Protect Program Flash Page 78',-- Description
     127,              -- Bit Mask
     78                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_79',        -- C Name
     'Write Protect Program Flash Page 79',-- Description
     127,              -- Bit Mask
     79                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_80',        -- C Name
     'Write Protect Program Flash Page 80',-- Description
     127,              -- Bit Mask
     80                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_81',        -- C Name
     'Write Protect Program Flash Page 81',-- Description
     127,              -- Bit Mask
     81                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_82',        -- C Name
     'Write Protect Program Flash Page 82',-- Description
     127,              -- Bit Mask
     82                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_83',        -- C Name
     'Write Protect Program Flash Page 83',-- Description
     127,              -- Bit Mask
     83                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_84',        -- C Name
     'Write Protect Program Flash Page 84',-- Description
     127,              -- Bit Mask
     84                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_85',        -- C Name
     'Write Protect Program Flash Page 85',-- Description
     127,              -- Bit Mask
     85                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_86',        -- C Name
     'Write Protect Program Flash Page 86',-- Description
     127,              -- Bit Mask
     86                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_87',        -- C Name
     'Write Protect Program Flash Page 87',-- Description
     127,              -- Bit Mask
     87                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_88',        -- C Name
     'Write Protect Program Flash Page 88',-- Description
     127,              -- Bit Mask
     88                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_89',        -- C Name
     'Write Protect Program Flash Page 89',-- Description
     127,              -- Bit Mask
     89                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_90',        -- C Name
     'Write Protect Program Flash Page 90',-- Description
     127,              -- Bit Mask
     90                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_91',        -- C Name
     'Write Protect Program Flash Page 91',-- Description
     127,              -- Bit Mask
     91                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_92',        -- C Name
     'Write Protect Program Flash Page 92',-- Description
     127,              -- Bit Mask
     92                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_93',        -- C Name
     'Write Protect Program Flash Page 93',-- Description
     127,              -- Bit Mask
     93                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_94',        -- C Name
     'Write Protect Program Flash Page 94',-- Description
     127,              -- Bit Mask
     94                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_95',        -- C Name
     'Write Protect Program Flash Page 95',-- Description
     127,              -- Bit Mask
     95                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_96',        -- C Name
     'Write Protect Program Flash Page 96',-- Description
     127,              -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_97',        -- C Name
     'Write Protect Program Flash Page 97',-- Description
     127,              -- Bit Mask
     97                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_98',        -- C Name
     'Write Protect Program Flash Page 98',-- Description
     127,              -- Bit Mask
     98                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_99',        -- C Name
     'Write Protect Program Flash Page 99',-- Description
     127,              -- Bit Mask
     99                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_100',       -- C Name
     'Write Protect Program Flash Page 100',-- Description
     127,              -- Bit Mask
     100               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_101',       -- C Name
     'Write Protect Program Flash Page 101',-- Description
     127,              -- Bit Mask
     101               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_102',       -- C Name
     'Write Protect Program Flash Page 102',-- Description
     127,              -- Bit Mask
     102               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_103',       -- C Name
     'Write Protect Program Flash Page 103',-- Description
     127,              -- Bit Mask
     103               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_104',       -- C Name
     'Write Protect Program Flash Page 104',-- Description
     127,              -- Bit Mask
     104               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_105',       -- C Name
     'Write Protect Program Flash Page 105',-- Description
     127,              -- Bit Mask
     105               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_106',       -- C Name
     'Write Protect Program Flash Page 106',-- Description
     127,              -- Bit Mask
     106               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_107',       -- C Name
     'Write Protect Program Flash Page 107',-- Description
     127,              -- Bit Mask
     107               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_108',       -- C Name
     'Write Protect Program Flash Page 108',-- Description
     127,              -- Bit Mask
     108               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_109',       -- C Name
     'Write Protect Program Flash Page 109',-- Description
     127,              -- Bit Mask
     109               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_110',       -- C Name
     'Write Protect Program Flash Page 110',-- Description
     127,              -- Bit Mask
     110               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_111',       -- C Name
     'Write Protect Program Flash Page 111',-- Description
     127,              -- Bit Mask
     111               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_112',       -- C Name
     'Write Protect Program Flash Page 112',-- Description
     127,              -- Bit Mask
     112               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_113',       -- C Name
     'Write Protect Program Flash Page 113',-- Description
     127,              -- Bit Mask
     113               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_114',       -- C Name
     'Write Protect Program Flash Page 114',-- Description
     127,              -- Bit Mask
     114               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_115',       -- C Name
     'Write Protect Program Flash Page 115',-- Description
     127,              -- Bit Mask
     115               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_116',       -- C Name
     'Write Protect Program Flash Page 116',-- Description
     127,              -- Bit Mask
     116               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_117',       -- C Name
     'Write Protect Program Flash Page 117',-- Description
     127,              -- Bit Mask
     117               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_118',       -- C Name
     'Write Protect Program Flash Page 118',-- Description
     127,              -- Bit Mask
     118               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_119',       -- C Name
     'Write Protect Program Flash Page 119',-- Description
     127,              -- Bit Mask
     119               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_120',       -- C Name
     'Write Protect Program Flash Page 120',-- Description
     127,              -- Bit Mask
     120               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_121',       -- C Name
     'Write Protect Program Flash Page 121',-- Description
     127,              -- Bit Mask
     121               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_122',       -- C Name
     'Write Protect Program Flash Page 122',-- Description
     127,              -- Bit Mask
     122               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_123',       -- C Name
     'Write Protect Program Flash Page 123',-- Description
     127,              -- Bit Mask
     123               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_124',       -- C Name
     'Write Protect Program Flash Page 124',-- Description
     127,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_125',       -- C Name
     'Write Protect Program Flash Page 125',-- Description
     127,              -- Bit Mask
     125               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_126',       -- C Name
     'Write Protect Program Flash Page 126',-- Description
     127,              -- Bit Mask
     126               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_127',       -- C Name
     'Write Protect Program Flash Page 127',-- Description
     127,              -- Bit Mask
     127               -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPCFG',          -- C Name
     'Write/Erase Protect Configuration Region '-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Configuration Words page not erase/write-protected',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Configuration Words page erase/write-protected',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4H',       -- Config Name
     131071,           -- Address
     251,              -- Default Value
     11                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPDIS',          -- C Name
     'Write Protect Disable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WPFP<6:0>/WPEND region ignored',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WPFP<6:0>/WPEND region erase/write protected',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WPEND',          -- C Name
     'Write/Erase Protect Region Select bit (valid when WPDIS = 0)'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_WPFP',      -- C Name
     'Pages WPFP<6:0> through Configuration Words erase/write protected',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PAGE_0',         -- C Name
     'Pages 0 through WPFP<6:0> erase/write protected',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'LS48MHZ',        -- C Name
     'Low Speed USB mode with 48 MHz system clock bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS24X4',        -- C Name
     'System clock at 24 MHz USB CLKEN divide-by is set to 4',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SYS48X8',        -- C Name
     'System clock at 48 MHz USB CLKEN divide-by is set to 8',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);


insert into DEVICES values (
     null,
     785,              -- Device ID
     4,                -- Family ID
     'PIC18LF65K80',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     32768,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     143,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECAN TX and RX pins are located on RE5 and RE4, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T0CKMX',         -- C Name
     'Timer0 Clock Input Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'Timer0 gets its clock input from the RB5/T0CKI pin on 64-pin packages',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTG',          -- C Name
     'Timer0 gets its clock input from the RG4/T0CKI pin on 64-pin packages',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CKMX',         -- C Name
     'Timer3 Clock Input Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTG',          -- C Name
     'Timer3 gets its clock input from the RG2/T3CKI pin on 64-pin packages',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'Timer3 gets its clock input from the RB5/T3CKI pin on 64-pin packages',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-01FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 02000-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 04000-05FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 06000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);


insert into DEVICES values (
     null,
     782,              -- Device ID
     4,                -- Family ID
     'PIC18LF66K80',   -- Part Name
     2,                -- Bytes Per Word (FLASH)
     64,               -- Write FLASH Block Size
     64,               -- Erase FLASH Page Size
     0,                -- Start of FLASH
     65536,            -- End of FLASH
     15728640,         -- Start of EEPROM
     15729664,         -- End of EEPROM
     2097152,          -- Start of User ID
     2097160,          -- End of User ID
     3145728,          -- Start of Config Bits
     3145742,          -- End of Config Bits
     4194302,          -- Start of Device Id
     4194304,          -- End of Device Id
     65504,            -- Device Id Mask
     0,                -- Start of GPR
     3649              -- End of GPR
);
insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1L',       -- Config Name
     3145728,          -- Address
     93,               -- Default Value
     93                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'RETEN',          -- C Name
     'VREG Sleep Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Ultra low-power regulator is Enabled (Controlled by SRETEN bit)',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Ultra low-power regulator is Disabled (Controlled by REGSLP bit)',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'INTOSCSEL',      -- C Name
     'LF-INTOSC Low-power Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'LF-INTOSC in High-power mode during Sleep',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'LF-INTOSC in Low-power mode during Sleep',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'SOSCSEL',        -- C Name
     'SOSC Power Selection and mode Configuration bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'High Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'Low Power SOSC circuit selected',-- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'DIG',            -- C Name
     'Digital (SCLKI) mode',-- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'XINST',          -- C Name
     'Extended Instruction Set'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG1H',       -- Config Name
     3145729,          -- Address
     8,                -- Default Value
     255               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FOSC',           -- C Name
     'Oscillator'      -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RCIO',           -- C Name
     'External RC oscillator',-- Description
     7,                -- Bit Mask
     7                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'RC',             -- C Name
     'External RC oscillator, CLKOUT function on OSC2',-- Description
     7,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1',            -- C Name
     'EC oscillator (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     13                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC1IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Low power, DC - 160 kHz)',-- Description
     15,               -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2',            -- C Name
     'EC oscillator (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     11                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC2IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (Medium power, 160 kHz - 4 MHz)',-- Description
     15,               -- Bit Mask
     10                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO1',         -- C Name
     'Internal RC oscillator, CLKOUT function on OSC2',-- Description
     15,               -- Bit Mask
     9                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'INTIO2',         -- C Name
     'Internal RC oscillator',-- Description
     15,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3',            -- C Name
     'EC oscillator (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     5                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'EC3IO',          -- C Name
     'EC oscillator, CLKOUT function on OSC2 (High power, 16 MHz - 64 MHz)',-- Description
     15,               -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS1',            -- C Name
     'HS oscillator (Medium power, 4 MHz - 16 MHz)',-- Description
     15,               -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HS2',            -- C Name
     'HS oscillator (High power, 16 MHz - 25 MHz)',-- Description
     15,               -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'XT',             -- C Name
     'XT oscillator',  -- Description
     15,               -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LP',             -- C Name
     'LP oscillator',  -- Description
     15,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PLLCFG',         -- C Name
     'PLL x4 Enable bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'FCMEN',          -- C Name
     'Fail-Safe Clock Monitor'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'IESO',           -- C Name
     'Internal External Oscillator Switch Over Mode'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2L',       -- Config Name
     3145730,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'PWRTEN',         -- C Name
     'Power Up Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BOREN',          -- C Name
     'Brown Out Detect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SBORDIS',        -- C Name
     'Enabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     6                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'Enabled while active, disabled in SLEEP, SBOREN disabled',-- Description
     6,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Controlled with SBOREN bit',-- Description
     6,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled in hardware, SBOREN disabled',-- Description
     6,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORV',           -- C Name
     'Brown-out Reset Voltage bits'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '3',              -- C Name
     '1.8V',           -- Description
     24,               -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '2.0V',           -- Description
     24,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '2.7V',           -- Description
     24,               -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '0',              -- C Name
     '3.0V',           -- Description
     24,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BORPWR',         -- C Name
     'BORMV Power level'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ZPBORMV',        -- C Name
     'ZPBORMV instead of BORMV is selected',-- Description
     96,               -- Bit Mask
     96                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'HIGH',           -- C Name
     'BORMV set to high power level',-- Description
     96,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MEDIUM',         -- C Name
     'BORMV set to medium power level',-- Description
     96,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'LOW',            -- C Name
     'BORMV set to low power level',-- Description
     96,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG2H',       -- Config Name
     3145731,          -- Address
     127,              -- Default Value
     127               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTEN',          -- C Name
     'Watchdog Timer'  -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'SWDTDIS',        -- C Name
     'WDT enabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     3                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'WDT controlled by SWDTEN bit setting',-- Description
     3,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'NOSLP',          -- C Name
     'WDT enabled only while device is active and disabled in Sleep mode; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'WDT disabled in hardware; SWDTEN bit disabled',-- Description
     3,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WDTPS',          -- C Name
     'Watchdog Postscaler'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1048576',        -- C Name
     '1:1048576',      -- Description
     124,              -- Bit Mask
     124               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '524288',         -- C Name
     '1:524288',       -- Description
     124,              -- Bit Mask
     76                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '262144',         -- C Name
     '1:262144',       -- Description
     124,              -- Bit Mask
     72                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '131072',         -- C Name
     '1:131072',       -- Description
     124,              -- Bit Mask
     68                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '65536',          -- C Name
     '1:65536',        -- Description
     124,              -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32768',          -- C Name
     '1:32768',        -- Description
     124,              -- Bit Mask
     60                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16384',          -- C Name
     '1:16384',        -- Description
     124,              -- Bit Mask
     56                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8192',           -- C Name
     '1:8192',         -- Description
     124,              -- Bit Mask
     52                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4096',           -- C Name
     '1:4096',         -- Description
     124,              -- Bit Mask
     48                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2048',           -- C Name
     '1:2048',         -- Description
     124,              -- Bit Mask
     44                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1024',           -- C Name
     '1:1024',         -- Description
     124,              -- Bit Mask
     40                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '512',            -- C Name
     '1:512',          -- Description
     124,              -- Bit Mask
     36                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '256',            -- C Name
     '1:256',          -- Description
     124,              -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '128',            -- C Name
     '1:128',          -- Description
     124,              -- Bit Mask
     28                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '64',             -- C Name
     '1:64',           -- Description
     124,              -- Bit Mask
     24                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '32',             -- C Name
     '1:32',           -- Description
     124,              -- Bit Mask
     20                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '16',             -- C Name
     '1:16',           -- Description
     124,              -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '8',              -- C Name
     '1:8',            -- Description
     124,              -- Bit Mask
     12                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '4',              -- C Name
     '1:4',            -- Description
     124,              -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '2',              -- C Name
     '1:2',            -- Description
     124,              -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     '1',              -- C Name
     '1:1',            -- Description
     124,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG3H',       -- Config Name
     3145733,          -- Address
     143,              -- Default Value
     143               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CANMX',          -- C Name
     'ECAN Mux bit'    -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'ECAN TX and RX pins are located on RB2 and RB3, respectively',-- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTE',          -- C Name
     'ECAN TX and RX pins are located on RE5 and RE4, respectively',-- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T0CKMX',         -- C Name
     'Timer0 Clock Input Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'Timer0 gets its clock input from the RB5/T0CKI pin on 64-pin packages',-- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTG',          -- C Name
     'Timer0 gets its clock input from the RG4/T0CKI pin on 64-pin packages',-- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'T3CKMX',         -- C Name
     'Timer3 Clock Input Mux bit'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTG',          -- C Name
     'Timer3 gets its clock input from the RG2/T3CKI pin on 64-pin packages',-- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'PORTB',          -- C Name
     'Timer3 gets its clock input from the RB5/T3CKI pin on 64-pin packages',-- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MSSPMSK',        -- C Name
     'MSSP address masking'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK7',           -- C Name
     '7 Bit address masking mode',-- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'MSK5',           -- C Name
     '5 bit address masking mode',-- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'MCLRE',          -- C Name
     'Master Clear Enable'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'MCLR Enabled, RG5 Disabled',-- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'MCLR Disabled, RG5 Enabled',-- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG4L',       -- Config Name
     3145734,          -- Address
     145,              -- Default Value
     145               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'STVREN',         -- C Name
     'Stack Overflow Reset'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'BBSIZ',          -- C Name
     'Boot Block Size' -- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB2K',           -- C Name
     '2K word Boot Block size',-- Description
     16,               -- Bit Mask
     16                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'BB1K',           -- C Name
     '1K word Boot Block size',-- Description
     16,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5L',       -- Config Name
     3145736,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP0',            -- C Name
     'Code Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP1',            -- C Name
     'Code Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP2',            -- C Name
     'Code Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CP3',            -- C Name
     'Code Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG5H',       -- Config Name
     3145737,          -- Address
     192,              -- Default Value
     192               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPB',            -- C Name
     'Code Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'CPD',            -- C Name
     'Data EE Read Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6L',       -- Config Name
     3145738,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT0',           -- C Name
     'Table Write Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT1',           -- C Name
     'Table Write Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT2',           -- C Name
     'Table Write Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRT3',           -- C Name
     'Table Write Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG6H',       -- Config Name
     3145739,          -- Address
     224,              -- Default Value
     224               -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTC',           -- C Name
     'Config. Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     32,               -- Bit Mask
     32                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     32,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTB',           -- C Name
     'Table Write Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'WRTD',           -- C Name
     'Data EE Write Protect'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     128,              -- Bit Mask
     128               -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     128,              -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7L',       -- Config Name
     3145740,          -- Address
     15,               -- Default Value
     15                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR0',          -- C Name
     'Table Read Protect 00800-03FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     1,                -- Bit Mask
     1                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     1,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR1',          -- C Name
     'Table Read Protect 04000-07FFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     2,                -- Bit Mask
     2                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     2,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR2',          -- C Name
     'Table Read Protect 08000-0BFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     4,                -- Bit Mask
     4                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     4,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTR3',          -- C Name
     'Table Read Protect 0C000-0FFFF'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     8,                -- Bit Mask
     8                 -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     8,                -- Bit Mask
     0                 -- Bit Value
);

insert into CONFIGWORDS values (
     NULL,
     (select max(ROWID) from DEVICES),
     'CONFIG7H',       -- Config Name
     3145741,          -- Address
     64,               -- Default Value
     64                -- Implemented Bits
);
insert into CONFIGFIELDS values (
     NULL,
     (select max(ROWID) from CONFIGWORDS),
     (select max(ROWID) from DEVICES),
     'EBTRB',          -- C Name
     'Table Read Protect Boot'-- Description
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'OFF',            -- C Name
     'Disabled',       -- Description
     64,               -- Bit Mask
     64                -- Bit Value
);

insert into CONFIGSETTINGS values (
     (select max(ROWID) from CONFIGFIELDS),
     (select max(ROWID) from DEVICES),
     'ON',             -- C Name
     'Enabled',        -- Description
     64,               -- Bit Mask
     0                 -- Bit Value
);

commit transaction;
